<?php

$para['index::tip'] = <<<_P
Use this page to launch or install to your browser this instance of
SiteBar Bookmark Server. It is recommended to bookmark one of the links
marked with "*" instead of bookmarking this page. This page can be opened
from SiteBar window by clicking on the top logo.
_P;

$para['index::any_browser'] = <<<_P
Use <a title="SiteBar" href="%s/sitebar.php">SiteBar</a>*
in this window - or open it in a pop-up
<a title="SiteBar" href="%s">SiteBar</a>-like* window.
_P;

$para['index::ie_install'] = <<<_P
<a href="?install=1">Install</a> / <a href="?install=0">Uninstall</a>
to the Explorer Bar and context menu - requires Windows registry change
and system restart for all features. Depending on your rights only
some features might be installed.
<p class="comment">Open SiteBar Explorer Bar from menu View/Explorer Bar or
use <b>Customize...</b> toolbars' function to get the SiteBar Panel toggle
button shown on the toolbar. Right click anywhere on the page or over a link
to add the page or link to the SiteBar.
</p>
_P;

$para['index::ie_search'] = <<<_P
Add <a title="SiteBar" href="javascript:void(_search=open('%s/sitebar.php','_search'))">
SiteBar</a>* temporarily to the Search Explorer Bar.
<p class="comment">Use when you do not have enough rights to use Installer above.</p>
_P;

$para['index::mozilla'] = <<<_P
Add to a Mozilla/Netscape compatible
<a title="SiteBar"
href="javascript:sidebar.addPanel('SiteBar','%s/sitebar.php','')">
sidebar</a> - toggle display using F9.
<p class="comment">Mozilla Firefox users should use the link above to create bookmark
that opens in sidebar when clicked. Mozillazine
<a href="http://forums.mozillazine.org/viewtopic.php?t=36166">topic</a> describes how to
use <a href="http://www.sitebar.org/plugin/firefox/SiteBar.xpi?url=%s">SiteBar</a> sidebar
extension and <a href="http://www.sitebar.org/plugin/firefox/WebLinks_for_SiteBar.xpi?url=%s">WebLinks</a> menu extension
with SiteBar.
</p>
_P;

$para['index::opera'] = <<<_P
Add to Opera's <a title="SiteBar" rel="sidebar" href="%s/sitebar.php">Hotlist</a>
as sidebar.
<p class="comment">Use Ctrl+click instead of Right+click to display folder or link context menu.</p>
_P;

$para['index::myie2_install'] = <<<_P
Download customized
<a href="http://www.sitebar.org/plugin/myie2/?sidebar=%s">sidebar</a>
and/or
<a href="http://www.sitebar.org/plugin/myie2/?toolbar=%s">Add Current Tab to SiteBar</a>
toolbar plugin.
_P;

$para['index::bookmarklet'] = <<<_P
<a href="javascript:%s">Add Page to SiteBar</a>* - right click this link and add
to your favorites/bookmarks toolbar. It will allow you later to add a link to the page currently
viewed in the browser to SiteBar. MS IE users can use installer and context menu instead.
_P;

$para['index::copyright2'] = <<<_P
Copyright &copy; 2003,2004 <a href='http://brablc.com/'>Ondřej Brablc</a>
and the <a href='http://www.sitebar.org/team.php'>SiteBar Team</a>.
Support <a href='http://sourceforge.net/forum/forum.php?forum_id=261003'>forum</a>.
_P;

/* Command window */

$para['command::contact'] = <<<_P
Message:

%s


--
SiteBar installation at %s.
_P;

$para['command::contact_group'] = <<<_P
Group: %s
Message:

%s


--
SiteBar installation at %s.
_P;

$para['command::delete_account'] = <<<_P
<h3>Do you really want to delete your account?</h3>
There will be no way to undo that change!<p>
All your remaining trees will be given to the administrator of the system.
_P;

$para['command::email_link_href'] = <<<_P
<p>Send e-mail via your default
<a href="mailto:?subject=Web site: %s&amp;body=I have found a web site you may be interested in.
 Take a look at: %s
 --
 Sent via SiteBar at %s
 Open Source Bookmark Server http://www.sitebar.org
">e-mail client</a>
_P;

$para['command::email_link'] = <<<_P
I have found a web site you may be interested in.
Take a look at:

    "%s" %s

%s

--
Sent via SiteBar at %s
Open Source Bookmark Server http://www.sitebar.org
_P;

$para['command::verify_email'] = <<<_P
You have requested e-mail validation that allows joining of
groups with auto join regular expressions and allows you to
make use of SiteBar's e-mail features.

Please click on the following link to verify your email:
    %s
_P;

$para['command::import_bk'] = <<<_P
<br>
Local favorites can be exported to a local file using javascript
<a href='javascript:window.external.ImportExportFavorites(false,"")'>function</a>.
_P;

$para['command::export_bk'] = <<<_P
<br>
Exported bookmarks can be imported to local favorties using javascript
<a href='javascript:window.external.ImportExportFavorites(true,"")'>function</a>.
_P;

$para['command::noiconv'] = <<<_P
<br>
Codepage conversion not installed on this SiteBar server.
<br>
_P;

$para['command::security_legend'] = <<<_P
Rights:
<strong>R</strong>ead,
<strong>A</strong>dd,
<strong>M</strong>odify,
<strong>D</strong>elete,
<strong>P</strong>urge,
<strong>G</strong>rant
_P;

$para['command::purge_cache'] = <<<_P
<h3>Do you really want to remove all favicons from the cache?</h3>
_P;

/* User manager */

$para['usermanager::auto_verify_email'] = <<<_P
Your e-mail address matches rules for auto join to following
closed group(s):
    %s.

In order to aprove your membership, your email address must
be verified. Please click on the following link to verify it:
    %s
_P;

$para['usermanager::signup_info'] = <<<_P
User "%s" <%s> signed up to your SiteBar installation at %s.
_P;

/* Skins */
$para['hook::statistics'] = <<<_P
Roots {roots_total}.
Folders {nodes_shown}/{nodes_total}.
Links {links_shown}/{links_total}.
Users {users}.
Groups {groups}.
SQL queries {queries}.
DB/Total time {time_db}/{time_total} sec ({time_pct}%).
_P;


?>
