<?php

$para = array();

$para['index::tip'] = <<<_P
使用這頁去啟動或安裝 SiteBar 到您的瀏覽器中。我們建議您將有標記「*」號的連結加到我的最愛裡頭，方便您更方便地使用 SiteBar。而這一頁是可以從 SiteBar 最頂部的 Logo 中連結得到的。
_P;

$para['index::any_browser'] = <<<_P
在本頁開啟 <a title="SiteBar" href="%s/sitebar.php">SiteBar</a>*，或以 Pop-Up 的形式啟動 <a title="SiteBar" href="%s">SiteBar</a>*。
_P;

$para['index::ie_install'] = <<<_P
從「瀏覽器列」和「右鍵選單」中 <a href="?install=1">安裝</a> / <a href="?install=0">移除</a> - 要令所有功能生效，您
需要更改視窗的登錄檔和重新啟動系統。視乎您的權限，有些功能可能未能安裝。
<p class='comment'>成功安裝後，您可以到「檢視 / 瀏覽器列」開啟您的 SiteBar，或用<b>自訂...</b>工具列功能去顯示「SiteBar Panel toggle button」。您更可以在任何一個網頁頁面或連結上按滑鼠右鍵，並將之加到 SiteBar 之中。</p>
_P;

$para['index::ie_search'] = <<<_P
暫時性地加 <a title="SiteBar" href="javascript:void(_search=open('%s/sitebar.php','_search'))">
SiteBar</a>* 到搜尋列之中。
<p class='comment'>如果您沒有足夠的權限完成以上安裝的話，您可以這樣做。</p>
_P;

$para['index::mozilla'] = <<<_P
<@>
安裝 <a title="SiteBar"
href="javascript:sidebar.addPanel('SiteBar','%s/sitebar.php','')">
sidebar</a> 到 Mozilla/Netscape 相容的瀏覽器中 - 用「F9」啟動。
<p class='comment'>Mozilla Firebird 的用戶必須用以上的連結去新增由 SiteBar 開啟的書籤。</p>
_P;

$para['index::opera'] = <<<_P
以 sidebar 的形式加到 Opera's <a title="SiteBar" rel="sidebar" href="%s/sitebar.php">Hotlist</a> 裡頭。
<p class='comment'>用 Ctrl+click 而不是 Right+click 去顯示資料夾或連結的選項。</p>
_P;

$para['index::myie2_install'] = <<<_P
下載已自訂的 <a href="http://www.sitebar.org/plugin/myie2/?sidebar=%s">sidebar</a> 和 / 或 <a href="http://www.sitebar.org/plugin/myie2/?toolbar=%s">加入目前的標籤到 SiteBar</a> 工具列外掛中。

_P;

$para['index::bookmarklet'] = <<<_P
<a href="javascript:%s">加入目前頁面到 SiteBar</a>* - 在這連結上按下滑鼠右鍵，這樣可以讓您新增目前瀏覽的頁面到 SiteBar 中。MS IE 用戶可選用上面介紹的安裝程式和右鍵選單。
_P;

$para['index::copyright'] = <<<_P
Copyright &copy; 2003-2004 <a href='http://brablc.com/'>Ondřej Brablc</a>
和 <a href='http://www.mindslip.com'>David Szego</a>.
聯絡支援 <a href='mailto:info@sitebar.org'>團隊</a>.
_P;

$para['command::contact'] = <<<_P
訊息：

%s


--
SiteBar 系統安裝 at %s。
_P;

$para['command::contact_group'] = <<<_P
群組：%s
訊息：

%s


--
SiteBar 系統安裝 at %s。
_P;

$para['command::delete_account'] = <<<_P
<h3>您確定要刪除您的帳戶嗎？</h3>
您將不能復原這個變更！<p>
所有目錄樹將會轉移到系統管理員那裡。
_P;

$para['command::email_link_href'] = <<<_P
<p>寄一封電子郵件到預設
<a href='mailto:?subject=Web site: %s&amp;body=我找到一個您可能有興趣的網站。
 到這兒看看： %s
 --
 由 SiteBar at %s 寄出
 開源碼 Bookmark Server http://www.sitebar.org
'>電子郵件用戶端</a>
_P;

$para['command::email_link'] = <<<_P
我找到一個您可能有興趣的網站。
到這兒看看：

    "%s" %s

%s

--
由 SiteBar at %s 寄出
開源碼 Bookmark Server http://www.sitebar.org
_P;

$para['command::verify_email'] = <<<_P
You have requested e-mail validation that allows joining of
groups with auto join regular expressions and allows you to
make use of SiteBar's e-mail features.

Please click on the following link to verify your email:
    %s
_P;

$para['command::label_show_trees'] = <<<_P
「%s」可以是：
<ol>
    <li>空的。
    <li>等於「*」以顯示所有已發佈的目錄樹。
    <li>一個或更多由逗號分隔的根目錄 ids，，以顯示符合 id <sup>1</sup> 的目錄樹。
</ol>
屬於自己的目錄樹會永遠顯示 <br>
<sup>1</sup>) The id is shown for each folder in the status bar as parameter to function
void when you put mouse over the folder.
_P;

$para['command::label_hide_folders'] = <<<_P
「%s」可以是：
<ol>
    <li>空的。
    <li>一個或更多由逗號分隔的根目錄 ids，以隱藏已選 <sup>1</sup> 的資料夾。
</ol>
<sup>1</sup>) The id is shown for each folder in the status bar as parameter to function
void when you put mouse over the folder.
_P;

$para['command::import_bk'] = <<<_P
<br>
您可以匯出本機的書籤成為一個書籤檔案:使用 javascript <a href='javascript:window.external.ImportExportFavorites(false,"")'>function</a>。
_P;

$para['command::export_bk'] = <<<_P
<br>
經匯出的書籤可以匯入到本機書籤之中：使用 javascript <a href='javascript:window.external.ImportExportFavorites(true,"")'>function</a>。
_P;

$para['command::noiconv'] = <<<_P
<br>
這 SiteBar server 並未安裝編碼轉換功能。
<br>
_P;

$para['command::security_legend'] = <<<_P
權限:
<strong>R</strong>ead,
<strong>A</strong>dd,
<strong>M</strong>odify,
<strong>D</strong>elete,
<strong>P</strong>urge,
<strong>G</strong>rant
_P;

$para['usermanager::auto_verify_email'] = <<<_P
您的電郵地址符合以下已關閉的群組的 auto join 規則：
    %s。

您的電郵地址必須先被查證，系統才會認可您的會員資格。請按以下連結查證：%s
_P;

$para['usermanager::signup_info'] = <<<_P
用戶「%s」已登記
到您的 SiteBar 系統安裝 at %s。
_P;

?>
