<?php

$text = array
(
'The Bookmark Server for Personal and Team Use' => '個人及團體用的書籤伺服器',
'SiteBar Homepage' => 'SiteBar 主頁',
'SiteBar Installation & Launcher' => 'SiteBar 的安裝及啟動器',
'Any Browser' => '對於任何瀏覽器',
'Content Bookmarklets' => 'Content Bookmarklets',
'Bookmarklet' => 'Bookmarklet',
'Your Language' => '繁體中文',
'Charset in MS Windows' => 'big5',
'Add Link to SiteBar' => '加入連結到 SiteBar',
'Add Page to SiteBar' => '加入目前頁面到 SiteBar',
'Error' => '錯誤',
'Warning' => '警告',
'Unknown' => '不明',
'Search' => '搜尋',
'Highlight' => '標亮',
'Collapse/Expand All' => '全部收縮 / 展開',
'Reload' => '重新載入',
'Reload with Hidden Folders' => '重新載入及顯示隱藏的資料夾',
'Backup Log In' => '備份登入',
'Backup Log Out' => '備份登出',
'Commander' => '命今台',
'Add Folder' => '加入資料夾',
'Add Link' => '加入連結',
'Contact Admin' => '聯絡管理員',
'Contact Moderator' => '聯絡控制員',
'Copy' => '複製',
'Copy Link' => '複製連結',
'Create Group' => '新增群組',
'Create Tree' => '新增目錄樹',
'Create User' => '新增用戶',
'Custom Order' => '自定次序',
'Delete Folder' => '刪除資料夾',
'Delete Group' => '刪除群組',
'Delete Link' => '刪除連結',
'Delete Account' => '刪除帳戶',
'Delete User' => '刪除用戶',
'Delete Tree' => '刪除目錄樹',
'Display Topic' => '顯示已選主題',
'Email Link' => '電郵這個連結書籤',
'Export Bookmarks' => '匯出書籤',
'Export Description' => '匯出敘述',
'Favicon Management' => '管理 Favicon',
'Folder Properties' => '資料夾選項',
'Group Members' => '群組用戶',
'Group Moderators' => '群組控制員',
'Group Properties' => '群組選項',
'Help' => '說明',
'Hide Folder' => '隱藏資料夾',
'Import Bookmarks' => '匯入書籤',
'Import Description' => '匯入敘述',
'Log In' => '登入',
'Log Out' => '登出',
'Maintain Groups' => '管理群組事項',
'Maintain Users' => '管理用戶事項',
'Maintain Trees' => '管理目錄樹',
'Membership' => '會員資格',
'Modify User' => '修改用戶',
'Order of Trees' => '目錄樹次序',
'Paste' => '貼上',
'Properties' => '選項',
'Purge Cache' => '清除快取',
'Purge Folder' => '清除資料夾',
'Retrieve Link Information' => '取得連結資訊',
'Security' => '設定目錄權限',
'Send Email to Members' => '電郵到會員',
'Send Email to Moderators' => '電郵到控制員',
'Send Email to User' => '電郵到用戶',
'Send Email to All' => '電郵到所有人',
'Show All Icons' => '顯示所有圖示',
'Set Up' => '設定',
'Sign Up' => '新用戶登記',
'SiteBar Settings' => 'SiteBar 選項',
'Undelete' => '反刪除',
'Unhide Trees' => '顯示目錄樹',
'Unhide Subfolders' => '顯示子目錄',
'User Settings' => '用戶設定',
'Personal Data' => '個人資料',
'Validate Links' => '查證連結',
'Validation' => '查證',
'Verify Email' => '查證電郵',
'Verify Email Code' => '查證電郵指令',
'Admin Password' => '管理員密碼',
'Allow Anonymous Contact' => '容許匿名聯絡',
'Allow Contact' => '容許聯絡',
'Allow Given Membership' => '容許群組控制員將你加入該群組',
'Allow Info Mail' => '容許管理員寄 Info Mail 給您',
'Allow Noninteractive Mode' => '容許 Non-interactive 模式',
'Allow Self Add' => '容許管理員新增任何用戶',
'Allow Sign Up' => '容許新用戶登記',
'Auto Join E-Mail RegExp' => 'Auto Join E-Mail RegExp',
'Auto Retrieve Favicon' => '自動取得 Favicon',
'Bookmark File' => '書籤檔案',
'Cached: ' => '快取:',
'Codepage' => '語言編碼',
'Comment' => '注釋',
'Content Only' => 'Content Only',
'Create New Sub Folder' => '新增子資料夾',
'Dead Link' => '不存在連結',
'Decode Using' => '使用以下方式解碼',
'Decorate ACL Folders' => '標記已設定特別權限的資料夾',
'Default Language' => '預設語言',
'Default Search In' => '以...作預設搜尋',
'Default Skin' => '預設面板',
'Delete Content Only' => '只刪除內容',
'Delete Invalid Favicons' => '刪除無效的 Favicons',
'Demo Account' => '示範用帳戶',
'Description' => '敘述',
'Description File' => '敘述檔案',
'Description Import/Export' => '匯入 / 匯出敘述',
'Discover Missing Favicons' => '搜尋不存在的 Favicons',
'E-mail' => '電郵',
'E-mail Verified' => '電郵已查證',
'Encode Using' => '使用以下方式編碼',
'Exclude From Validation' => '排除驗証',
'Extern Commander' => 'External Commander',
'Favicon' => 'Favicon',
'Feedback or Other Comment' => '反饋及其他意見',
'File Type' => '檔案類型',
'Folder Name' => '資料夾名稱',
'From' => '由',
'Group Name' => '群組名稱',
'Help Topic' => '說明主題',
'Language' => '語言',
'Link Description Length' => '連結敘述長度',
'Link Name' => '名稱',
'Mode' => '模式',
'Moderator' => '控制員',
'New Tree Owner' => '目錄樹的新擁有者',
'Old Password' => '舊密碼',
'Only to Verified Emails' => '只是去查證電郵',
'Owner' => '擁有者',
'Parent Folder' => '主目錄',
'Password' => '密碼',
'Paste Mode' => '剪貼模式',
'Personal Mode' => '個人模式',
'Private' => '私人的',
'Publish Folder' => '導出資料夾',
'Real Name' => '真實姓名',
'Remember as Default' => '預設記憶',
'Remember Me' => '記住我的登入狀態',
'Repeat Admin Password' => '重覆管理員密碼',
'Repeat Password' => '重覆密碼',
'Respect Allow Info Mail' => '尊重「容許管理員寄 Info Mail 給您」',
'Select Group' => '選擇群組',
'Select User' => '選擇用戶',
'Show Logo' => '顯示 SiteBar 商標',
'Show Menu Icon' => '顯示選單圖示',
'Show Public Bookmarks' => '顯示共用書籤',
'Show Sponsor' => '顯示贊助者',
'Skin' => '面板',
'Skip Execution Messages' => '略過系統執行訊息',
'Source Folder Name' => '來源資料夾名稱',
'Source Link Name' => '來源連結名稱',
'Target Folder Name' => '目的地資料夾名稱',
'To' => '到',
'Topic' => '主題',
'Tree Name' => '目錄樹名稱',
'Tree Owner' => '目錄樹擁有者',
'URL' => '網址',
'Use Compression' => '使用壓縮',
'Use E-mail Features' => '使用電郵功能',
'Use Favicons' => '使用 Favicons',
'Users Can Create Trees' => '容許用戶新增目錄樹',
'Your E-mail' => '您的電郵',
'Until I close browser' => '直至我關閉瀏覽器',
'12 hours' => '12 小時',
'6 days' => '6 天',
'1 month' => '1 個月',
'Anonymous Guest' => '匿名訪客',
'Guest' => '訪客',
'Message' => '訊息',
'SiteBar Server' => 'SiteBar 伺服器',
'%s - ok.' => '%s - 成功。',
'%s - error!' => '%s - 錯誤！',
'SiteBar: Contact Admin' => 'SiteBar: Contact Admin',
'SiteBar: Contact Group Moderator' => 'SiteBar: Contact Group Moderator',
'SiteBar: Email to all SiteBar Users' => 'SiteBar: Email to all SiteBar Users',
'SiteBar: Email to Group Members' => 'SiteBar: Email to Group Members',
'SiteBar: Email to Group Moderators' => 'SiteBar: Email to Group Moderators',
'SiteBar: Email to SiteBar User' => 'SiteBar: Email to SiteBar User',
'SiteBar: Email Verification' => 'SiteBar: Email Verification',
'SiteBar: New SiteBar User' => 'SiteBar: New SiteBar User',
'SiteBar: Web site' => 'SiteBar: Web site',
'Group' => '群組',
'R' => 'R',
'A' => 'A',
'M' => 'M',
'D' => 'D',
'P' => 'P',
'G' => 'G',
'Ask' => '總是詢問',
'Move or Copy' => '移動或複製',
'Copy (Keep Source)' => '複製 (保留來源)',
'Move (Delete Source)' => '移動 (刪除來源)',
'Auto detection' => '讓系統自動偵測',
'Netscape/Mozilla/MS IE' => 'Netscape/Mozilla/MS IE',
'Opera Hotlist version 2.0' => 'Opera Hotlist version 2.0',
'Admins' => '管理員群',
'Everyone' => '任何人',
'%s&#39;s Bookmarks' => '%s&#39;s 書籤',
'Deleted root %s of %s at %s' => 'Deleted root %s of %s at %s',
'All' => '全部',
'Name' => '姓名',
'Access denied!' => '存取失敗！',
'Cannot delete built in group!' => '不能刪除系統內建群組！',
'Cannot delete user because he is the only moderator of the following group(s): %s!' => '不能刪除用戶，因為他是以下群組的控制員：%s！',
'Cannot export empty description!' => '不能匯出空的敘述！',
'Cannot remove all moderators from a group!' => '不能從群組移除所有控制員！',
'Cannot send email!' => '寄出電子郵件失敗！',
'Database corrupted - missing anonymous account!' => '資料庫損壞 - 缺少匿名帳戶！',
'Duplicate folder name "%s"!' => '資料夾名稱「%s」重覆！',
'Duplicate folder name!' => '資料夾名稱重覆！',
'Duplicate name "%s" in the target folder!' => '目的地資料夾裡的「%s」名稱重覆！',
'Duplicate name "%s"!' => '「%s」名稱重覆！',
'Expected field %s was not filled!' => '欠填「%s」欄目！',
'Field %s must be filled!' => '必須填寫「%s」欄目！',
'Folder has already been deleted!' => '資料夾已經刪除！',
'Folder with id %s does not exist!' => '「id： %s」資料夾不存在！',
'Group has already been deleted!' => '群組已經刪除！',
'Group name "%s" is already used!' => '群組名稱「%s」已被選用！',
'Invalid code, verification disabled!' => '不正確的指令，查證失效！',
'Invalid filename or other upload related problem: %s!' => '不正確的檔案名稱，或其他有關上傳的問題： %s！',
'Link already is in the target folder!' => '目的地資料夾已存在該連結！',
'Link has already been deleted!' => '連結已經刪除！',
'Missing command!' => '缺少指令！',
'No user was selected!' => '未有用戶被選擇！',
'Node number %s has ACL record but does not exist!' => 'Node number %s has ACL record but does not exist!',
'Old password is invalid!' => '舊密碼不正確！',
'Purge folder to remove it permanently!' => '用「清除資料夾」永久移除！',
'The description length exceeds maximum length of %s bytes!' => '敘述內容的長度超出標準 %s 位元組！',
'The e-mail %s does not look correct!' => '電郵 %s 格式錯誤！',
'The password was not repeated correctly!' => '重覆輸入的密碼不正確！',
'There is no content to be deleted!' => '沒有內容可以刪除！',
'There is nothing to be undeleted!' => '沒有東西可以反刪除！',
'This email is already used. Did you forget your password?' => '電郵已被選用。你忘記了你的密碼嗎？',
'Tree has already been deleted!' => '目錄樹已經刪除！',
'Unknown command!' => '指令錯誤！',
'Unknown username or wrong password!' => '用戶名稱或密碼錯誤！',
'Verification e-mail has been sent to your e-mail address!' => '查證電郵已經寄到您的電郵戶口！',
'You have been left as group moderator!' => '您現在成為該群組的控制員！',
'You are the last moderator of used group(s): %s. Account cannot be deleted!' => '您是以下群組的最後一位控制員：%s。帳戶不能被刪除！',
'%s, welcome to the SiteBar!<p>You have been already logged in.' => '%s，歡迎使用 SiteBar！<p>您已經登入了。',
'E-mail %s verified! Any pending memberships were approved.' => '電郵「%s」經已查證！您的會員資格現在正式生效。',
'Link has been added.<p>You must reload your SiteBar in order to see added link!' => '連結已加到目錄當中。<p>請重新載入你的 SiteBar！',
'Imported %s link(s) into %s folder(s) from the bookmark file.' => '完成匯入 %s 個連結到 %s 個目錄中。',
'Successful execution!' => '執行成功！',
'Submit' => '送出',
'Reset' => '重置',
'Reload SiteBar' => '重新載入 SiteBar',
'Close' => '關閉',
'Return' => '返回',
'Backup Return to SiteBar' => 'Fallback Return to SiteBar ',
'Cannot open file!' => '不能開啟檔案！',
'Unknown bookmark file format!' => '不明的書籤檔案格式！',
'File is empty!' => '檔案是空的！',
'Character set overriden from document to %s!' => 'Character set overriden from document to %s!',
'Powered by %s ver. %s' => 'Powered by %s ver. %s',
'Skin created by' => 'Skin created by',
'Skin designed by' => 'Skin designed by',
'Folder found' => '已找到資料夾',
'Link found' => '已找到連結',
'Desc' => 'Desc',
'Find next?' => '搜尋下一個？',
);

?>
