<?php

$topic = array
(
    100 => 'Usage Tips',
        101 => 'Drag &amp; Drop',
        102 => 'Adding Links',
        103 => 'Tool Bar Functions',

    200 => 'Commands',
        210 => 'Session Management',
        220 => 'Installation &amp; Maintenance',
        230 => 'Account Management',
        240 => 'User Management',
        250 => 'Group Management',
        260 => 'Folder Operations',
        270 => 'Link Operations',

    300 => 'Technical Info',
        301 => 'Compatibility',
        302 => 'Security Mechanism',
        303 => 'Skins',
);

?>
