<?php

$text = array
(
'The Bookmark Server for Personal and Team Use' => 'O Servidor de Bookmark para Uso Pessoal e Equipa',
'SiteBar Homepage' => 'SiteBar - Página Pessoal',
'SiteBar Installation & Launcher' => 'SiteBar - Instalação & Lançamento',
'Any Browser' => 'Qualquer Browser',
'Content Bookmarklets' => 'Conteúdo de Bookmarklets',
'Bookmarklet' => 'Bookmarklet',
'Your Language' => 'Português',
'Charset in MS Windows' => 'ISO-8859-1',
'Add Link to SiteBar' => 'Adicionar Link ao SiteBar',
'Add Page to SiteBar' => 'Adicionar Página ao SiteBar',
'Error' => 'Erro',
'Warning' => 'Aviso',
'Unknown' => 'Desconhecido',
'Search' => 'Procurar',
'Highlight' => 'Destacar',
'Collapse/Expand All' => 'Unir/Expandir Todos',
'Reload' => 'Actualizar',
'Reload with Hidden Folders' => 'Actualizar com as Pastas Ocultas',
'Backup Log In' => 'Entrar - Cópia de Segurança',
'Backup Log Out' => 'Sair - Cópia de Segurança',
'Commander' => 'Comando',
'Add Folder' => 'Adicionar Pasta',
'Add Link' => 'Adicionar Link',
'Contact Admin' => 'Contactar Administrador',
'Contact Moderator' => 'Contactar Moderador',
'Copy' => 'Copiar',
'Copy Link' => 'Copiar Link',
'Create Group' => 'Criar Grupo',
'Create Tree' => 'Criar Árvore',
'Create User' => 'Criar Utilizador',
'Custom Order' => 'Ordem Personalizada',
'Delete Folder' => 'Apagar Pasta',
'Delete Group' => 'Apagar Grupo',
'Delete Link' => 'Apagar Link',
'Delete Account' => 'Apagar Conta',
'Delete User' => 'Apagar Utilizador',
'Delete Tree' => 'Apagar Árvore',
'Display Topic' => 'Mostrar Tópico',
'Email Link' => 'Email Link',
'Export Bookmarks' => 'Exportar Bookmarks',
'Export Description' => 'Exportar Descrição',
'Favicon Management' => 'Gerência de Ícones dos Favoritos',
'Folder Properties' => 'Propriedades da Pasta',
'Group Members' => 'Membros do Grupo',
'Group Moderators' => 'Moderadores do Grupo',
'Group Properties' => 'Propriedades do Grupo',
'Help' => 'Ajuda',
'Hide Folder' => 'Ocultar Pasta',
'Import Bookmarks' => 'Importar Bookmarks',
'Import Description' => 'Importar Descrição',
'Log In' => 'Entrar',
'Log Out' => 'Sair',
'Maintain Groups' => 'Manter Grupos',
'Maintain Users' => 'Manter Utilizadores',
'Maintain Trees' => 'Manter Árvores',
'Membership' => 'Sociedade',
'Modify User' => 'Modificar Utilizador',
'Order of Trees' => 'Ordem das Árvores',
'Paste' => 'Colar',
'Properties' => 'Propriedades',
'Purge Cache' => 'Limpar Cache',
'Purge Folder' => 'Limpar Pasta',
'Retrieve Link Information' => 'Recuperar a Informação do Link',
'Security' => 'Segurança',
'Send Email to Members' => 'Enviar E-mail aos Membros',
'Send Email to Moderators' => 'Enviar E-mail aos Moderadores',
'Send Email to User' => 'Enviar E-mail ao Utilizador',
'Send Email to All' => 'Enviar E-mail a Todos',
'Show All Icons' => 'Mostrar Todos os Ícones',
'Set Up' => 'Definir',
'Sign Up' => 'Registo',
'SiteBar Settings' => 'SiteBar Definições',
'Undelete' => 'Anular Apagar',
'Unhide Trees' => 'Não Ocultar Árvores',
'Unhide Subfolders' => 'Não Ocultar SubPastas',
'User Settings' => 'Definições do Utilizador',
'Personal Data' => 'Dados Pessoais',
'Validate Links' => 'Validar Links',
'Validation' => 'Validação',
'Verify Email' => 'Verificar E-mail',
'Verify Email Code' => 'Verificar Código de E-mail',
'Admin Password' => 'Administrador - Senha',
'Allow Anonymous Contact' => 'Permitir Contactos Anónimos',
'Allow Contact' => 'Permitir Contacto',
'Allow Given Membership' => 'Permitir Sociedades',
'Allow Info Mail' => 'Permitir Informação de Mail',
'Allow Noninteractive Mode' => 'Não Permitir o Modo de Interactividade',
'Allow Self Add' => 'Permitir Adicionar-se',
'Allow Sign Up' => 'Permitir Entrar',
'Auto Join E-Mail RegExp' => 'Auto Entrar E-Mail Expirado',
'Auto Retrieve Favicon' => 'Auto Recuperar o Ícone do Favorito',
'Bookmark File' => 'Ficheiro Bookmark',
'Cached: ' => 'Em cache:',
'Codepage' => 'Código da Página',
'Comment' => 'Comentário',
'Content Only' => 'Só o Conteúdo',
'Create New Sub Folder' => 'Criar Nova Sub Pasta',
'Dead Link' => 'Link Morto',
'Decode Using' => 'Usar Descodificador',
'Decorate ACL Folders' => 'Decorar Pastas ACL',
'Default Language' => 'Língua Predefinida',
'Default Search In' => 'Procurar Prédefinido',
'Default Skin' => 'Skin Prédefinido',
'Delete Content Only' => 'Apenas Apagar Conteúdo',
'Delete Invalid Favicons' => 'Apagar Ícones dos Favoritos Inválidos',
'Demo Account' => 'Conta Demo',
'Description' => 'Descrição',
'Description File' => 'Descrição do Ficheiro',
'Description Import/Export' => 'Descrição Importar/Exportar',
'Discover Missing Favicons' => 'Descobrir Ícones dos Favoritos Perdidos',
'E-mail' => 'E-mail',
'E-mail Verified' => 'Verificar E-mail',
'Encode Using' => 'Usar Codificador',
'Exclude From Validation' => 'Excluir da Validação',
'Extern Commander' => 'Comando Externo',
'Favicon' => 'Icóne do Favorito',
'Feedback or Other Comment' => 'Comentário',
'File Type' => 'Tipo de Ficheiro',
'Folder Name' => 'Nome da Pasta',
'From' => 'De',
'Group Name' => 'Nome do Grupo',
'Help Topic' => 'Tópico de Ajuda',
'Ignore Recently Tested' => 'Ignorar o Recentemente Testado',
'Include Subfolders' => 'Incluir SubPastas',
'Keep In Cache' => 'Manter na Cache',
'Language' => 'Língua',
'Link Description Length' => 'Tamanho da Descrição do Link',
'Link Name' => 'Nome do Link',
'Maximal Icon Age' => 'Idade Máxima do Ícone',
'Maximal Icon Size' => 'Tamanho Máximo do Ícone',
'Maximal Icons per User' => 'Máximo de Ícones por Utilizador',
'Maximal Icons Total' => 'Total Máximo de Ícones',
'Mode' => 'Modo',
'Moderator' => 'Moderador',
'New Tree Owner' => 'Novo Proprietário da Árvore',
'Old Password' => 'Senha Antiga',
'Only to Verified Emails' => 'Só para Verificar E-mails',
'Original: ' => 'Original:',
'Owner' => 'Proprietário',
'Parent Folder' => 'Pasta Pai',
'Password' => 'Senha',
'Paste Mode' => 'Modo de Colar',
'Personal Mode' => 'Modo Pessoal',
'Private' => 'Privado',
'Publish Folder' => 'Publicar Pasta',
'Real Name' => 'Nome Real',
'Recent Time Expressed in Seconds' => 'Tempo Recente Expresso em Segundos',
'Remember as Default' => 'Lembrar como Predefinido',
'Remember Me' => 'Lembrar de Mim',
'Rename Duplicate Links' => 'Renomear Links Duplicados',
'Repeat Admin Password' => 'Repetir Senha de Administrador',
'Repeat Password' => 'Repetir Senha',
'Respect Allow Info Mail' => 'Permitir Mail de Informação',
'Select Group' => 'Seleccionar Grupo',
'Select User' => 'Seleccionar Utilizador',
'Sender E-mail' => 'Remetente do E-mail',
'Show Logo' => 'Mostar Logo',
'Show Menu Icon' => 'Mostrar Icóne de Menu',
'Show Public Bookmarks' => 'Mostrar Bookmarks Públicas',
'Show Sponsor' => 'Mostrar Patrocinador',
'Skin' => 'Skin',
'Skip Execution Messages' => 'Excluir Mensagens de Execução',
'Source Folder Name' => 'Nome da Pasta Fonte',
'Source Link Name' => 'Nome do Link',
'Target Folder Name' => 'Nome da Pasta Alvo',
'To' => 'Para',
'Topic' => 'Tópico',
'Tree Name' => 'Nome da Árvore',
'Tree Owner' => 'Proprietário da Árvore',
'URL' => 'URL',
'Use Compression' => 'Usar Compressão',
'Use Conversion Engine' => 'Usar Motor de Conversão',
'Use E-mail Features' => 'Usar Características',
'Use Favicons' => 'Usar Icónes nos Favoritos',
'Use Folder Hiding' => 'Usar Pasta Oculta',
'Use Hit Counter' => 'Usar Contador de Visitas',
'Use Outbound Connection' => 'Usar a Ligação Outbound',
'Use the Favicon Cache' => 'Usar Cache dos Ícones dos Favoritos',
'Users Can Create Trees' => 'Útilizadores Podem Criar Árvores',
'Your E-mail' => 'O Seu E-mail',
'Until I close browser' => 'Até Eu Fechar o Browser',
'12 hours' => '12 horas',
'6 days' => '6 dias',
'1 month' => '1 mês',
'No caching' => 'Sem cache',
'Order of Folders v. Links' => 'Ordenar as Pastas v. Links',
'Links first' => 'Primeiro os Links',
'Folders first' => 'Primeiro as Pastas',
'Default Link Sort Mode' => 'Modo Predefinido de Ordenamento de Links',
'Sort Mode' => 'Modo de Ordenamento',
'User default' => 'Utilizador Predefinido',
'Custom order' => 'Ordem personalizada',
'Alphabetically' => 'Alfabeticamente',
'Most clicked first' => 'Primeiro os mais clicados',
'New/changed links first' => 'Primeiro os links novos/modificados',
'Waiting for visit' => 'À espera de visita',
'Anonymous Guest' => 'Convidado Anónimo',
'Guest' => 'Convidado',
'Message' => 'Mensagem',
'SiteBar Server' => 'SiteBar Servidor',
'%s - ok.' => '%s - ok.',
'%s - error!' => '%s - erro!',
'SiteBar: Contact Admin' => 'SiteBar: Contactar Administrador',
'SiteBar: Contact Group Moderator' => 'SiteBar: Contactar Moderador do Grupo',
'SiteBar: Email to all SiteBar Users' => 'SiteBar: E-mail a todos os Utilizadores do SiteBar',
'SiteBar: Email to Group Members' => 'SiteBar: E-mail aos Membros do Grupo',
'SiteBar: Email to Group Moderators' => 'SiteBar: E-mail aos Moderadores do Grupo',
'SiteBar: Email to SiteBar User' => 'SiteBar: E-mail ao Utilizador do SiteBar',
'SiteBar: Email Verification' => 'SiteBar: Verificação de E-mail',
'SiteBar: New SiteBar User' => 'SiteBar: Novo Utilizador',
'SiteBar: Web site' => 'SiteBar: Website',
'Group' => 'Grupo',
'R' => 'L',
'A' => 'A',
'M' => 'M',
'D' => 'G',
'P' => 'P',
'G' => 'C',
'Ask' => 'Perguntar',
'Move or Copy' => 'Mover ou Copiar',
'Copy (Keep Source)' => 'Copiar (Guarda a Fonte)',
'Move (Delete Source)' => 'Mover (Apaga a Fonte)',
'Auto detection' => 'Detecção automática',
'Netscape/Mozilla/MS IE' => 'Netscape/Mozilla/MS IE',
'Netscape/Mozilla' => 'Netscape/Mozilla',
'MS Internet Explorer' => 'MS Internet Explorer',
'Opera Hotlist version 2.0' => 'Opera Hotlist versão 2.0',
'Admins' => 'Administradores',
'Everyone' => 'Todos',
'%s&#39;s Bookmarks' => '%s&#39;s Bookmarks',
'Deleted root %s of %s at %s' => 'A raiz %s da %s em %s apagada.',
'All' => 'Todos',
'Name' => 'Nome',
'Access denied!' => 'Acesso negado!',
'All links recently validated!' => 'Todos os links recentemente validados!',
'Cannot connect to http://%s:%s!' => 'Não consegue ligação a http://%s:%s! ',
'Cannot delete built in group!' => 'Não pode apagar dentro de um grupo!',
'Cannot delete user because he is the only moderator of the following group(s): %s!' => 'Não pode apagar o utilizador porque ele é o único moderador do(s) seguinte(s) grupo(s): %s!',
'Cannot download %s using https, will try http!' => 'Não consegue transferir o %s usando https, tentará o http!',
'Cannot export empty description!' => 'Não pode exportar uma descrição vazia!',
'Cannot handle %s protocol!' => 'Não consegue manipular o protocolo %s!',
'Cannot move folder to its subfolder!' => 'Não pode mover a pasta para a sua sub-pasta!',
'Cannot remove all moderators from a group!' => 'Não pode remover todos os moderadores de um grupo!',
'Cannot send email!' => 'Não pode mandar e-mail!',
'Connection timed out!' => 'Tempo de ligação terminado!',
'Database corrupted - missing anonymous account!' => 'Base de dados corrupta - perdeu a conta anónima!',
'Duplicate folder name "%s"!' => 'Nome da pasta "%s" duplicado!',
'Duplicate folder name!' => 'Nome da pasta duplicado!',
'Duplicate name "%s" in the target folder!' => 'Nome "%s" duplicado na pasta alvo!',
'Duplicate name "%s"!' => 'Nome "%s" duplicado!',
'Expected field %s was not filled!' => 'O campo esperado %s não foi preenchido!',
'Favicon <img src="%s"> found at url %s.' => 'Ícone do favorito <img src="%s"> encontradado na url %s.',
'Favicon not found!' => 'Ícone do favorito não encontrado!',
'Field %s must be filled!' => 'O campo %s tem de ser preenchido!',
'Folder has already been deleted!' => 'A pasta já foi apagada!',
'Folder with id %s does not exist!' => 'A pasta com id %s não existe!',
'Group has already been deleted!' => 'O grupo já foi apagado!',
'Group name "%s" is already used!' => 'O nome do grupo %s já está a ser usado!',
'Head of the HTML page was not found!' => 'Head da página HTML não foi localizado!',
'HEAD unsupported, trying GET!' => 'HEAD não suportado, a tentar GET!',
'Host or port undefined!' => 'Endereço ou porta não definidos!',
'Icon size %s exceeds maximal size %s!' => 'Tamanho do Ícone %s excede o tamanho máximo %s!',
'Incomplete HTTP response!' => 'Resposta incompleta de HTTP!',
'Invalid code, verification disabled!' => 'Código inválido, verificação desactivada!',
'Invalid regular expresssion!' => 'Expressão regular inválida!',
'Invalid filename or other upload related problem: %s!' => 'Nome do ficheiro inválido ou problema de upload: %s!',
'Link already is in the target folder!' => 'O link já está na pasta alvo!',
'Link has already been deleted!' => 'O link já foi apagado!',
'Missing command!' => 'Comando perdido!',
'No links in the folder!' => 'Nenhum link dentro da pasta!',
'No more than %s redirections allowed!' => 'Não mais de %s redirecções são permitidas!',
'No user was selected!' => 'Nenhum utilizador foi seleccionado!',
'Node number %s has ACL record but does not exist!' => 'Nó número %s tem registro de ACL mas não existe!',
'Old password is invalid!' => 'A senha antiga é inválida!',
'Page not found!' => 'Página não localizada!',
'Page redirected to %s!' => 'Página redireccionada para %s!',
'Purge folder to remove it permanently!' => 'Limpar pasta para removê-la permanentemente!',
'Shortcut icon not found! Trying default favicon location %s.' => 'Atalho do ícone não localizado! A tentar a localização predefinida %s.',
'The description length exceeds maximum length of %s bytes!' => 'O tamanho da descrição excedeu o tamanho máximo de % bytes!',
'The e-mail %s does not look correct!' => 'O e-mail %s não parece correcto!',
'The password was not repeated correctly!' => 'A senha não foi repetida correctamente!',
'There is no content to be deleted!' => 'Não há conteúdo para ser apagado!',
'There is nothing to be undeleted!' => 'Não há nada para ser recuperado!',
'This email is already used. Did you forget your password?' => 'Este e-mail já está a ser usado. Esqueceu-se da sua senha?',
'Tree has already been deleted!' => 'Árvore já foi apagada!',
'Use "%s" command to delete own account!' => 'Use o comando "%s" para apagar a sua própria conta!',
'Unknown command!' => 'Comando desconhecido!',
'Unknown username or wrong password!' => 'Utilizador desconhecido ou senha errada!',
'Verification e-mail has been sent to your e-mail address!' => 'A verificação de e-mail foi enviada para o seu endereço de e-mail!',
'Wrong favicon type/format "%s"!' => 'Tipo/formato do ícone de favorito errado %s!',
'You have been left as group moderator!' => 'Deixou de ser o moderador do grupo!',
'You are the last moderator of used group(s): %s. Account cannot be deleted!' => 'Voçê é o último moderador do(s) grupo(s): %s. A conta não pode ser apagada!',
'%s, welcome to the SiteBar!<p>You have been already logged in.' => 'Bem-vindo ao SiteBar, %s!<p> Já está log in.',
'E-mail %s verified! Any pending memberships were approved.' => 'O E-mail %s verificado! Quaisquer sociedades pendentes foram aprovadas.',
'Link has been added.<p>You must reload your SiteBar in order to see added link!' => 'O Link foi adicionado.<p>Tem the actualizar o SiteBar para ver o link adicionado!',
'Imported %s link(s) into %s folder(s) from the bookmark file.' => 'Importados %s link(s) para %s pasta(s) do ficheiro bookmark.',
'Successful execution!' => 'Execução com sucesso!',
'Submit' => 'Submeter',
'Reset' => 'Restaurar',
'Reload SiteBar' => 'Actualizar SiteBar',
'Close' => 'Fechar',
'Return' => 'Voltar',
'Backup Return to SiteBar' => 'Cópia de Segurança de Voltar para o SiteBar',
'Cannot open file!' => 'Não consegue abrir o ficheiro!',
'Unknown bookmark file format!' => 'Formato do ficheiro de bookmark desconhecido!',
'File is empty!' => 'O ficheiro está vazio!',
'Character set overriden from document to %s!' => 'O caracter anulado do documento para %s!',
'There is no conversion engine available to convert from %s character set!' => 'Não há nenhum motor de conversão disponível para converter do carácter %s definido!',
'Powered by %s ver. %s' => 'Suportado por %s v.%s',
'Skin created by' => 'Skin criado por',
'Skin designed by' => 'Skin desenhado por',
'Folder found' => 'Pasta encontrada',
'Link found' => 'Link encontrado',
'Desc' => 'Descrição',
'Find next?' => 'Localizar o seguinte?',
);

?>
