<?php

$para = array();

$para['index::tip'] = <<<_P
Questa pagina serve per installare o aprire nel proprio browser
un'istanza di SiteBare Bookmark Server. Si raccomanda di creare un
collegamento ai links segnati con un asterisco, invece che crearne uno a
questa pagina. Potete raggiungere questa pagina cliccando sul logo "SiteBar"
nella finestra principale di SiteBar.
_P;

$para['index::any_browser'] = <<<_P
Aprire <a title="SiteBar" href="%s/sitebar.php">SiteBar</a>* in questa finestra - oppure aprire <a title="SiteBar" href="%s">SiteBar</a> in una nuova finestra.
_P;

$para['index::mozilla'] = <<<_P
<@>
Aggiungere <a title="SiteBar"
href="javascript:sidebar.addPanel('SiteBar','%s/sitebar.php','')">
barra laterale</a> a browser Mozilla/Netscape compatibile
 - usare F9 per cambiare.
<p class='comment'>Gli utenti di Mozilla Firebird dovrebbero utilizzare il collegamento
soprastante per creare un bookmark che apra SiteBar.
</p>
_P;

$para['index::opera'] = <<<_P
Aggiungere a Opera <a title="SiteBar" rel="sidebar" href="%s/sitebar.php">Hotlist</a>
come barra laterale.
<p class='comment'>Usare Ctrl+click invece di Right+click per visualizzare il menu contestuale.</p>
_P;

$para['index::myie2_install'] = <<<_P
Scaricare la
<a href="http://www.sitebar.org/plugin/myie2/?sidebar=%s">barra laterale</a>
su misura e/o
<a href="http://www.sitebar.org/plugin/myie2/?toolbar=%s">aggiungre barra corrente a SiteBar</a>
toolbar plugin.
_P;

$para['command::contact'] = <<<_P
Messaggio:

%s


--
Istallazione Sitebar a %s.
_P;

$para['command::contact_group'] = <<<_P
Gruppo: %s
Messaggio:

%s


--
Installazione SiteBar a %s.
_P;

$para['command::delete_account'] = <<<_P
<h3>Vuoi veramente eliminare il tuo account?</h3>
Questa opzione &#232; irreversibile !<p>
Tutti i tuoi link verrano affidati all'amministratore di sistema.
_P;

$para['command::email_link'] = <<<_P
Ho trovato un sito web che potrebbe interessarti.
Dai un'occhiata a:

    "%s" %s

%s

--
Spedito via SiteBar a %s
Open Source Bookmark Server http://www.sitebar.org

_P;

$para['command::import_bk'] = <<<_P
<br>
I Favoriti possono essere esportati in un file locale usando questa
<a href='javascript:window.external.ImportExportFavorites(false,"")'>funzione</a> javascript.
_P;

$para['command::export_bk'] = <<<_P
<br>
I bookmarks esportati possono essere importati a Favoriti usando questa
<a href='javascript:window.external.ImportExportFavorites(true,"")'>funzione</a> javascript.
_P;

$para['command::noiconv'] = <<<_P
<br>
Il convertitore di Codepage non &#232; installato in questo SiteBar server.
<br>
_P;

$para['command::security_legend'] = <<<_P
Diritti:
<strong>R</strong>ead(Lettura),
<strong>A</strong>dd(Aggiunta),
<strong>M</strong>odify(Modifica),
<strong>D</strong>elete(Eliminazione),
<strong>P</strong>urge(Pulizia),
<strong>G</strong>rant(Assegnazione)
_P;

?>
