<?php

$para = array();

$para['index::tip'] = <<<_P
Diese Seite kann dazu verwendet werden, um SiteBar zu starten oder
im Browser zu installieren. Die mit dem "*" versehenen Links können als
Lesezeichen gespeichert werden, um einen schnellen Zugriff auf die SiteBar
zu ermöglichen. Diese Seite kann auch über
das SiteBar Fenster erreicht werden, indem man auf das oberste Logo klickt.
_P;

$para['index::any_browser'] = <<<_P
Verwenden Sie <a title="SiteBar" href="%s/sitebar.php">SiteBar</a>*
in diesem Fenster oder öffnen Sie es in einem
<a title="SiteBar" href="%s">Pop-Up Fenster</a>.
_P;

$para['index::ie_install'] = <<<_P
<a href="?install=1">Installieren</a> / <a href="?install=0">Löschen</a>
sie die SiteBar in/von der Explorer-Leiste und dem Kontext-Menü. Diese Installationsart
erfordert Änderungen an der Registry von Windows und einen Neustart des Internet Explorers,
um alle SiteBar-Features nutzen zu können. Abhängig von den
Zugriffsrechten des Benutzers können möglicherweise nicht alle Features
installiert werden.
<p class='comment'>Öffnen Sie die SiteBar Explorer-Leiste über das Menü
"Ansicht/Explorer-Leiste" oder verwenden Sie den <b>Anpassen...</b>-Befehl der Toolbar, um
den SiteBar-Knopf auf der Toolbar des Explorers zu installieren. Klicken Sie mit rechts
irgendwo auf der Seite oder auf einen Link, um ein Kontextmenü zu erhalten über dass sie ein Lesezeichen zur SiteBar
hinzufügen können.
</p>
_P;

$para['index::ie_search'] = <<<_P
<a title="SiteBar" href="javascript:void(_search=open('%s/sitebar.php','_search'))">
SiteBar</a>* nur temporär zu der Suchleiste des Explorers hinzufügen.
<p class='comment'>Diese Option kann verwendet werden, wenn Sie nicht über ausreichende
Rechte verfügen, um die obige Installationsvariante zu nutzen.</p>
_P;

$para['index::mozilla'] = <<<_P
SiteBar bei einem Mozilla/Netscape kompatiblen Browser in der
<a title="SiteBar"
href="javascript:sidebar.addPanel('SiteBar','%s/sitebar.php','')">
Sidebar</a>  installieren - Die Sidebar kann mit F9 an- oder ausgeschaltet werden.
<p class='comment'>
Benutzer des Mozilla FireFox können den obigen Link verwenden, um
ein Lesezeichen zu erstellen, das eine Seite in der Sidebar öffnet sobald
es angeklickt wird. Im <a href="http://forums.mozillazine.org/viewtopic.php?t=36166">Mozillazine</a> werden auch zwei Plugins für den FireFox-Browser beschrieben. Das <a href="http://www.sitebar.org/plugin/firefox/SiteBar.xpi?url=%s">SiteBar-Plugin</a> installiert die SiteBar automatisch und das <a href="http://www.sitebar.org/plugin/firefox/WebLinks_for_SiteBar.xpi?url=%s">WebLinks-Plugin</a> macht die komplette SiteBar als Menüeintrag beim FireFox verfügbar. Die Weblinks-Funktionalität bietet einen sehr schnellen und komfortablen Zugriff auf die Links.
</p>
_P;

$para['index::opera'] = <<<_P
Zu Opera's <a title="SiteBar" rel="sidebar" href="%s/sitebar.php">Hotlist</a>
als Sidebar hinzufügen.
<p class='comment'>Bei Opera muss Ctrl+Klick anstelle eines Rechtsklicks verwendet
werden, um das Kontextmenü der Sitebar aufzurufen.</p>
_P;

$para['index::myie2_install'] = <<<_P
Spezielles <a href="http://www.sitebar.org/plugin/myie2/?sidebar=%s">Plugin für die Sidebar</a> herunterladen
und/oder ein
<a href="http://www.sitebar.org/plugin/myie2/?toolbar=%s">Plugin für die Toolbar</a>
herunterladen.
_P;

$para['index::bookmarklet'] = <<<_P
<a href="javascript:%s">Seite zur SiteBar hinzufügen</a>* - Dieser Link ermöglicht es
eine derzeit offene Webseite zur SiteBar hinzuzufügen. Am besten wird dieser Link zu den
Lesezeichen des Browsers hinzugefügt (Rechtsklick auf den Link) um möglichst schnell
neue Seiten hinzufügen zu können. Benutzer des Microsoft Internet Explorers können den Link
mit Hilfe des Installers auch zum Kontext-Menü hinzufügen.
_P;

$para['index::copyright2'] = <<<_P
Copyright � 2003,2004 <a href='http://brablc.com/'>Ondřej Brablc</a> und das <a href='http://www.sitebar.org/team.php'>SiteBar Team</a>. Support-<a href='http://sourceforge.net/forum/forum.php?forum_id=261003'>Forum</a>.
_P;

$para['command::contact'] = <<<_P
Nachricht:

%s

--
SiteBar Installation auf dem Server %s.
_P;

$para['command::contact_group'] = <<<_P
Gruppe: %s
Nachricht:

%s


--
SiteBar Installation auf dem Server %s.

_P;

$para['command::delete_account'] = <<<_P
<h3>Wollen Sie Ihr Konto wirklich löschen?</h3>
Es gibt keine Möglichkeit diesen Schritt rückgängig zu machen!<p>
Alle von Ihnen angelegten Bäume werden dem Administrator des Systems übertragen.
_P;

$para['command::email_link_href'] = <<<_P
<p>E-Mail über lokales Programm versenden
<a href='mailto:?subject=Webseite: %s&amp;body=Ich habe eine neue Webseite gefunden, die interessant
 sein könnte.
 Hier ist der entsprechende Link: %s
 --
 Diese automatische Mail wurde über die SiteBar Installation des Servers %s versendet.
 SiteBar ist ein Open-Source-Lesezeichen-Server (http://www.sitebar.org)
'>E-Mail Programm</a>
_P;

$para['command::email_link'] = <<<_P
Ich habe eine neue Webseite gefunden, die interessant sein könnte.
Hier ist der entsprechende Link:

    "%s" %s

%s

--
Diese automatische Mail wurde über die SiteBar Installation des Servers %s versendet.
SiteBar ist ein Open-Source-Lesezeichen-Server (http://www.sitebar.org)
_P;

$para['command::verify_email'] = <<<_P
Diese E-Mail wurde ausgesandt um diese E-mail-Adresse für den
Zugriff auf Auto-Join Gruppen des Sitebar Servers zu ermöglichen.
Nach der Validierung können auch die E-mail-Features des Servers
verwendet werden.

Bitte auf diesen Link klicken um diese E-mail-Adresse zu validieren:
    %s
_P;

$para['command::import_bk'] = <<<_P
<br>
Lokale Favoriten können mit Hilfe von JavaScript in eine Datei exportiert werden.
<a href='javascript:window.external.ImportExportFavorites(false,"")'>Funktion</a>.
_P;

$para['command::export_bk'] = <<<_P
<br>
Exportierte Lesezeichen können über JavaScript zu den lokalen Favoriten hinzugefügt werden.
<a href='javascript:window.external.ImportExportFavorites(true,"")'>Funktion</a>.
_P;

$para['command::noiconv'] = <<<_P
<br>
Die Codepage-Umwandlung ist auf diesem Sitebar-Server nicht verfügbar.
<br>
_P;

$para['command::security_legend'] = <<<_P
Rechte:
<strong>A</strong>nsehen,
<strong>H</strong>inzufügen,
<strong>M</strong>odifizieren,
<strong>L</strong>öschen,
<strong>E</strong>ntfernen,
<strong>G</strong>ewähren
_P;

$para['command::purge_cache'] = <<<_P
<h3>Sollen wirklich alle FavIcons aus dem Cache entfernt werden</h3>
_P;

$para['usermanager::auto_verify_email'] = <<<_P
Ihre E-Mail-Adresse passt zu der Regel für eine Mitgliedschaft in
der/den privaten Gruppe(n) aufgestellt wurde:
    %s.

Um die Mitgliedschaft zu bestätigen, muss die E-Mail-Adresse
verifiziert werden. Hierfür bitte auf den folgenden Link klicken:
    %s
_P;

$para['usermanager::signup_info'] = <<<_P
Benutzer "%s" <%s> hat sich bei dem Sitebar-Server %s angemeldet.
_P;

$para['hook::statistics'] = <<<_P
Roots {roots_total}.
Verzeichnisse {nodes_shown}/{nodes_total}.
Links {links_shown}/{links_total}.
User {users}.
Gruppen {groups}.
SQL Abfragen {queries}.
DB/Total Zeit {time_db}/{time_total} Sek ({time_pct}%).
_P;

?>
