<?php

$text = array
(
'SiteBar Homepage' => 'SiteBar puslapis',
'Any Browser' => 'Bet kokia naršyklė',
'Your Language' => 'Lietuviškai',
'Add Link to SiteBar' => 'Įdėti nuorodą į SiteBar',
'Add Page to SiteBar' => 'Įdėti puslapį į SiteBar',
'Error' => 'Klaida',
'Warning' => 'Pranešimas',
'Unknown' => 'Nežinoma',
'Search' => 'Paieška',
'Collapse/Expand All' => 'Suskleisti/Išskleisti visus',
'Reload' => 'Perkrauti',
'Reload with Hidden Folders' => 'Perkrauti ir rodyti su paslėptais katalogais',
'Add Folder' => 'Pridėti katalogą',
'Add Link' => 'Pridėti nuorodą',
'Contact Admin' => 'Susisiekti su administratoriumi',
'Contact Moderator' => 'Susisiekti su moderatoriumi',
'Copy' => 'Kopijuoti',
'Copy Link' => 'Kopijuoti nuorodą',
'Create Group' => 'Sukurti grupę',
'Create Tree' => 'Sukurti medį',
'Create User' => 'Sukurti vartotoją',
'Custom Order' => 'Spec.suskirstymas',
'Delete Folder' => 'Ištrinti katalogą',
'Delete Group' => 'Ištrinti grupę',
'Delete Link' => 'Ištrinti nuorodą',
'Delete Account' => 'Ištrinti paskyrą',
'Delete User' => 'Ištrinti vartotoją',
'Delete Tree' => 'Ištrinti medį',
'Email Link' => 'Siųsti nuorodą paštu',
'Export Bookmarks' => 'Eksportuoti nuorodas',
'Export Description' => 'Eksportuoti aprašymą',
'Favicon Management' => 'Ikonų valdymas',
'Folder Properties' => 'Katalogo sąvybės',
'Group Members' => 'Grupės nariai',
'Group Moderators' => 'Grupės moderatoriai',
'Group Properties' => 'Grupės sąvybės',
'Help' => 'Pagalba',
'Hide Folder' => 'Paslėpti katalogą',
'Import Bookmarks' => 'Importuoti nuorodas',
'Import Description' => 'Importuoti aprašymą',
'Log In' => 'Prisijungti',
'Log Out' => 'Atsijungti',
'Maintain Groups' => 'Tvarkyti grupes',
'Maintain Users' => 'Tvarkyti vartotojus',
'Maintain Trees' => 'Tvarkyti medžius',
);

?>
