<?php

$help = array();

$help['100'] = <<<_P
您可以從<strong>用戶選單</strong>、資料夾和連結的 <strong>右鍵選單</strong>中使用所有 SiteBar 的功能。用戶選單顯示在 SiteBar 的最底部，而右鍵選單則可從資料夾或連結中按滑鼠右鍵取得。Opera 和蘋果電腦的用戶可用 Ctrl-click 代替。萬一 Ctrl-click 不能被系統用辨認的話，您可以到「用戶設定」中開啟「顯示選單圖示」功能。當您剔選這選項後，資料夾或連結旁邊會顯示一個細小的選單圖示。按下圖示就可以開啟右鍵選單。
<p>
基於用戶權限的不同，右鍵和用戶選單所顯示的子功能會有所不同。有些項目可能被系統失效。指令會在指令視窗中執行。
_P;

$help['101'] = <<<_P
用您的滑鼠按下任何一個資料夾或連結，途中不要放手，將滑鼠游標拉到另一個資料夾上。拖拉成功的話，目的地資料夾將會被標亮。放開滑鼠鍵將所選的連結或資料夾放到被標亮的資料夾中。
<p>
SiteBar team 並未為 Opera 瀏覽器植入 Drag & Drop 功能。Opera 用戶應以 Copy and Paste 代替。
_P;

$help['102'] = <<<_P
使用「bookmarklet」是新增連結最方便的途徑。您可以從 SiteBar 系統的主頁中安裝 bookmarklet，預設主頁是可以從 SiteBar 最頂部的商標連結得到的。如果 Internet Explorer 用戶使用主頁介紹的安裝程式安裝 bookmarklet 的話，就可以用右鍵選單新增連結。
_P;

$help['103'] = <<<_P
<@>
<p><strong>搜尋</strong> - 容許在所有已顯示的連結中搜尋。您可以用以下的字首 (prefixes) 指定搜尋的條件：<strong>url:</strong>, <strong>name:</strong>, <strong>desc:</strong>, <strong>all:</strong>。預設的字首是<strong>name:</strong>。如果系統找到符合搜尋條件的連結或資料夾時，該連結或資料夾會被顏色標亮，而且會有一個伴帶著一些資料的 javascript 確認視窗。用戶可以選擇繼續或停止搜尋。

<p><strong>標亮</strong> - 與搜尋一樣，不過沒有 javascript 告示。

<p><strong>全部收縮 / 展開</strong> - 收縮 / 展開所有節點。當這項目第二次被按時 (當時所有節點已經收縮)，節點就會展開。

<p><strong>重新載入</strong> - 由伺服器重新載入所有連結。
_P;

$help['200'] = <<<_P
指令已分類到幾個合理的群組。請從群組中選擇以得到指令的說明。
_P;

$help['210'] = <<<_P
<p><strong>登入</strong> - 登入用戶到系統，cookies 會記住用戶的登入狀態。您可以指定 cookies 的期滿時間。

<p><strong>登出</strong> - 從系統登出用戶。使用公共電腦時必須登出系統。在登入系統時選擇「直至我關閉瀏覽器」時，瀏覽器關閉後會自行登出系統。

<p><strong>新用戶登記</strong> - 容許訪客登記以使用系統。系統會根據電子郵件去規定用戶是否合格參加一些群組。在這個情況下，用戶的電郵地址需要被系統查證。查證電郵會自動寄到用戶登記的電郵地址當中。系統管理員可以隨時停止新用戶登記。
_P;

$help['220'] = <<<_P
<p><strong>設定</strong> - 這是 SiteBar 安裝過程中，設定好資料庫以後，第一個管理員見到的指令。系統會新增一個管理員帳戶和設定好 SiteBar 的一些基本參數。當「個人模式」啟動後，只有一部分的功能可以設定。

<p><strong>SiteBar 選項</strong> - 管理員可以稍後設定的選項。管理員是管理員群組的其中一員，是在系統安裝過程中「設定」指令新增的用戶。您可以查閱「設定」說明了解電郵功能。日後的版本將會有更多電郵功能。

<p><strong>新增目錄樹</strong> - 視乎 SiteBar 選項中設定，只有管理員和/或電郵已受查證的用戶可以新增目錄樹。當新增一個目錄樹後，該目錄必須同現有的用戶聯繫在一起 (只有管理員可以為其他用戶新增目錄樹)。新增一個團體書籤的標準方法，就是新增一個目錄樹，然後將之分派到控制該群組的用戶，該群組可以在「新增群組」中新增。如此這個用戶就可以擁有已新增目錄樹的權限，和將用戶加入該群組的能力。
_P;

$help['230'] = <<<_P
<p><strong>用戶設定</strong> - 變更用戶選項。當「External Commander」選項被剔除後，指令視窗會在 SiteBar 同一視窗中開啟，而不會另開新視窗。有些指令會永遠在同一視窗中開啟 (「登入」、「登出」、「新用戶登記」和「用戶設定」)。當「略過系統執行訊息」選項被剔選後，指令執行成功後將不會有確認畫面顯示。這個項目會減慢 SiteBar 的顯示。

<p><strong>會員資格</strong> - 用戶可以退出任何群組和加入開放的群組。不過如果用戶是最後一位控制員的話，將不能退出該群組。在這情況下，用戶需要聯絡管理員刪除該群組。

<p><strong>查證電郵</strong> - 容許用戶查證電郵以使用其他的系統功能。
_P;

$help['240'] = <<<_P
<p><strong>管理用戶事項</strong> - 顯示一個用戶列表框和容許以下命令被執行。

<p><strong>修改用戶</strong> - 目前修復一個忘記的密碼唯一的方法，是在此設定一個暫時密碼，將之寄到該用戶再要求用戶更改。管理員可以標記帳戶成示範用帳戶，示範用帳戶不容許用戶更改某些選項，特別是密碼。

<p><strong>刪除用戶</strong> - 刪除用戶和他的會員資格。屬於該會員的目錄樹會被重新分派到另一個用戶。系統不能刪除群組唯一控制員的帳戶。

<p><strong>新增用戶</strong> - 和「新用戶登記」一樣，不過這是為管理員而設。由這選項新增的用戶，其電郵地址會被當作已查證。
_P;

$help['250'] = <<<_P
<p><strong>管理群組事項</strong> - 顯示一個群組列表框和容許以下命令被執行。

<p><strong>群組選項</strong> - 群組控制員能夠進入這個選項。容許更改群組名稱註釋與 Auto Join E-Mail 正規形式。當「Auto Join E-Mail RegExp」被選取而新登記的電郵地址又符合指定形式時，系統會自動寄出一封查證電郵到新登記用戶的電郵戶口當中，查證後該用戶就自動成為群組的一員。當「容許管理員新增任何用戶」被剔選時，電郵是不須被查證而用戶可以自動成為會員。

<p><strong>群組用戶</strong> - 只有控制員才可以選擇那一個用戶成為群組的會員。其他控制員無法不被選取，控制員的身份先要用以下的指令除去。

<p><strong>群組控制員</strong> - 群組控制員能夠進入這個選項。每一個群組最少要有一位群組控制員。

<p><strong>刪除群組</strong> - 只有管理員才能夠進入這個選項，刪除其中一個群組和屬於該群組的所有會員資格。

<p><strong>新增群組</strong> - 只有管理員才能夠進入這個選項，新增一個群組和指定第一位群組控制員。
_P;

$help['260'] = <<<_P
<@>
<p><strong>加入資料夾</strong> - 在資料夾裡新增一個子資料夾。

<p><strong>加入連結</strong> - 在資料夾裡新增一個連結。由 bookmarklet 執行的時候，系統容許用戶選擇目的地資料夾，否則系統就會加入該連結到指令執行的資料夾內。

<p>

<p><strong>資料夾選項</strong> - 指定資料夾的選項 - 包括名稱及敘述。

<p><strong>刪除資料夾</strong> - 刪除資料夾。您可以用「反刪除」指令或新增一個名稱相同的資料夾來反刪除已刪除的資料夾。用戶更可刪除屬於他的根目錄，不過經過執行清除指令後刪除才會生效。

<p><strong>清除資料夾</strong> - 清除先前已刪除的資料夾或已選資料夾內的連結。您將不可能復原經已清除的東西。

<p><strong>反刪除</strong> - 復原先前已刪除的資料夾或連結，除非該物件已經被清除。當一個根目錄被刪後，系統會用灰階圖示顯示，而該目錄只會被目錄樹的擁有者看到。這將從其它群組成員中去除被授予的權根，亦即從另一個保安水平上防止不必要的書籤損失。

<p>

<p><strong>複製</strong> - 複製資料夾和所包含的內容到內部的剪貼簿。

<p><strong>貼上</strong> - 此選項只有效於「複製」或「複製連結」指令被執行後。「貼上」指令確定用戶是否能夠移動該內容或只是複製它並選擇適當的預設值。但是用戶依然能夠選擇複製或是移動。

<p>

<p><strong>匯入書籤</strong> - 從外部檔案匯入書籤到資料夾中。為避免伺服器端 timeout，系統在這個步驟不會對連結進行檢查。

<p><strong>匯出書籤</strong> - 從資料夾中匯出書籤到外部檔案中。支援 Netscape 書籤檔格式和 Opera Hotlist。Mozilla 使用 Netscape 書籤檔格式而 Internet Explorer 可以從這格式中匯出及匯入。

<p><strong>設定目錄權限</strong> - 只為根目錄而設。容許指定整個目錄樹的存取權。欲知道更多相關的資料，請參考「安全管理」部分。
_P;

$help['270'] = <<<_P
<p><strong>電郵這個連結書籤</strong> - 容許電郵一個書籤 (連結)到另一位朋友。已查證電郵的用戶，內部電郵系統可能被運用，否則外部電郵系統就會被啟動。

<p><strong>複製連結</strong> - 複製連結到內部剪貼簿。在資料夾使用「貼上」指令以複製 / 移動連結到節點上。

<p><strong>刪除連結</strong> - 從節點上刪除連結。已刪除的連結可以在主目錄上使用「反刪除」指令反刪除您的連結。


<p><strong>選項</strong> - 修改連結的選項。容許用戶設定成私人的連結。
_P;

$help['300'] = <<<_P
SiteBar 3 在 2.x 系列中完全重寫，代表 SiteBar 的進一步演變。
<p>
SiteBar 3 不再使用任何 JavaScript 去描繪 (render) 書籤的目錄樹。但是系統仍會依賴 JavaScript 去顯示右鍵選單和展開 / 收縮節點，包括圖示的變化。瀏覽器必須支援<a href="http://www.w3.org/TR/DOM-Level-2-Core/">文件物件模型 (Document Object Model) Level 2</a>。好處是非常快速和增加書簽載入。缺點是舊版本的瀏覽器可能只看到書籤的目錄樹被展開而書籤只可以被讀取 (這是仍是從版本 2 的改善，改善在舊版本瀏覽器不能顯示的問題)。
<p>
在伺服器端，資料以最簡單的遞歸資料結構被存放及於目錄樹的修改作出優化。這為選擇項目帶來良好的表現。感謝數據庫的資料表目錄選取有大量連結時都沒有減慢。
_P;

$help['301'] = <<<_P
SiteBar 已經在以下瀏覽器中成功測試過：

<ul>
    <li>Mozilla 1.4, 1.5a
    <li>Mozilla Firebird 0.61, 0.7
    <li>Galeon 1.3.7
    <li>Internet Explorer 6.0
    <li>Opera 7.11, 7.21
</ul>

而使用以下瀏覽器只容許讀取 (read-only)：

<ul>
    <li>Pocket Internet Explorer 2002
    <li>Netscape Navigator 4.78
</ul>
_P;

$help['302'] = <<<_P
當利用到權限時 SiteBar 3 會進行雙重核對。基於用戶的權限，系統只會容許一部分的指令被用戶執行，而每一個發佈了的指令會受系統第二次查證才會被成功執行。
<p>
系統擁有三個基本身份：用戶、控制員和管理員。控制員是在群組建立時或受其他控制員標明的控制員用戶。每位控制員的身份只局限於某一特定的群組內。管理員是管理員群的一員，是系統安裝時「設定」指令創造的第一個用戶。管理員不能成為控制員，不過可以刪除整個群組。
<p>
SiteBar 3 的開發符合不同團隊使用的要求。換句話說同一群組內的用戶可以分享大家的書籤。為了讓團隊的書籤能夠保持私隱，我們有開發存取控制機制。
<p>
這機制的基石是，任何目錄樹根目錄的擁有者對於整個目錄樹具有無限的權限。當有用戶登記或被新增時，系統會新增一個根目錄予每一位用戶。另外，管理員更可以創造附加的目錄樹予任何用戶，或容許其他用戶去新增他們自己的目錄樹。
<p>
當一個目錄樹被新增後，用戶可以指定該目錄樹對於其他用戶群組的權限。您可以從以下的權限中選取：

<p><strong>Read</strong> - 群組內的用戶能夠使用書籤，如果他不希望見到這些書籤，就必須退出該群組。

<p><strong>Add</strong> - 用戶可以加入資料夾或連結。

<p><strong>Modify</strong> - 為資料夾或連結下定義。

<p><strong>Delete</strong> - 刪除資料夾或連結。

<p><strong>Purge</strong> - 清除先前刪除的資料夾或連結，與「Delete」一併使用可容許資料夾由一個目錄樹移動到另一個。

<p><strong>Grant</strong> - 群組會員擁有與目錄樹擁有者一樣的權限。

<p>
權限一定由主目錄中承接 (inheritance)。預設任何群組不具有根目錄的任何權限。用戶可以指定一些限制性的存取到一些資料夾中，從而影響到其子目錄。如果一個資料夾的權限與其主目錄相同的話，現有資料夾的權限規格將會被移除再用上主目錄的承接。
<p>
群組控制員有絕對權限去移除任何由用戶指定的權限。
<p>
這個安全機制有個例外。您可以在一些公開資料夾中保留連結成私人的。目錄樹的擁有者可以標明任何連結成私人的，這可以避免將連結公開給其他用戶觀看及作修改。如果系統沒有任何分享的資料夾 (預設沒有)，您可不必將連結設定成私人的。
<p>
資料夾愈多存取權限規格說明，系統就要花愈多時間去載入用戶的書籤。不應在複雜的目錄樹中過分使用存取權限規格。
<p>
當管理員剔選了「個人模式」後，安全指令將不能被使用，不過在「資料夾選項」中會新增一個「導出資料夾」選項。在這個模式中，當主節點已經被導出後，您將不能限制其子目錄的權限。

用戶能夠從個人及預設的「企業」模式中自由轉換，不過您不能在個人模式中移除任何群組在企業模式中得到的權限，唯「任何人」群組例外。
_P;

$help['303'] = <<<_P
SiteBar 容許用戶創造面板。對於面板設計，您必須有良好的樣式表 (CSS) 知識。創造新面板時，現有的面板應該被採取作為藍本。即是說您可採取任何「skins」目錄現有的面板並複製創作。每一個面板必須包括多張圖片 (應採用 PNG 格式，因為直至 2004 年，歐洲還在等待有關 GIF 版權的問題)、一個樣式表「sitebar.css」和含有 hooks 的 PHP 檔「hook.php」。在 hook 檔裡頭，您可以更改 sitebar 安裝時的頁頭或頁尾 (header or footer)。
<p>
一些管理員可能會創造自己的面板以符合其網站的設計。在此情況下，我們建議您在 SiteBar 選項中選擇預設面板並刪除所有其他的面板。如果您希望您設計的面板可以包含於 SiteBar 發行版本當中，您就必須聯絡管理團隊並在最新的穩定開發版本中通過測試。概括來說 SiteBar 和 SourceForge 商標必須顯示頁面中，但是 SiteBar 商標可能自由地被更新。
_P;

?>
