<?php

$topic = array
(
'100' => 'Astuce d utilisation',
'101' => 'Saisir & Déposer',
'102' => 'Ajouter liens',
'103' => 'Fonctions de la barre d&#39;outils',
'200' => 'Commandes',
'210' => 'Gestion des sessions',
'220' => 'Installation & Maintenance',
'230' => 'Gestion des comptes',
'240' => 'Gestions des utilisateurs',
'250' => 'Gestion des groupes',
'260' => 'Opérations sur les répertoires',
'270' => 'Opérations sur les liens',
'300' => 'Informations techniques',
'301' => 'Compatibilié',
'302' => 'Mechanisme de sécurité',
'303' => 'Thèmes',
);

?>
