<?php

$text = array
(
'The Bookmark Server for Personal and Team Use' => 'Der Lesezeichen-Server für Einzelne und ganze Teams',
'SiteBar Homepage' => 'SiteBar Homepage',
'SiteBar Installation & Launcher' => 'SiteBar Installation und Startprogramm',
'Any Browser' => 'Jeder Browser',
'Content Bookmarklets' => 'Skript-Lesezeichen',
'Bookmarklet' => 'Skript-Lesezeichen',
'Your Language' => 'Deutsch',
'Charset in MS Windows' => 'ISO-8859-1',
'Add Link to SiteBar' => 'Lesezeichen zur SiteBar hinzufügen',
'Add Page to SiteBar' => 'Seite zur SiteBar hinzufügen',
'Error' => 'Fehler',
'Warning' => 'Warnung',
'Unknown' => 'Unbekannt',
'Search' => 'Suchen',
'Highlight' => 'Hervorheben',
'Collapse/Expand All' => 'Alles kollabieren/expandieren',
'Reload' => 'Neu laden',
'Reload with Hidden Folders' => 'Mit verstecken Ordnern neu laden',
'Backup Log In' => 'Backup Einloggen',
'Backup Log Out' => 'Backup Ausloggen',
'Commander' => 'Commander',
'Add Folder' => 'Ordner hinzufügen',
'Add Link' => 'Eintrag hinzufügen',
'Contact Admin' => 'Administrator kontaktieren',
'Contact Moderator' => 'Moderator kontaktieren',
'Copy' => 'Kopieren',
'Copy Link' => 'Kopieren',
'Create Group' => 'Gruppe erstellen',
'Create Tree' => 'Baum erstellen',
'Create User' => 'Benutzer erstellen',
'Custom Order' => 'Benutzerdefinierte Sortierung',
'Delete Folder' => 'Ordner löschen',
'Delete Group' => 'Gruppe löschen',
'Delete Link' => 'Löschen',
'Delete Account' => 'Meinen Account löschen',
'Delete User' => 'Benutzer löschen',
'Delete Tree' => 'Baum löschen',
'Display Topic' => 'Thema anzeigen',
'Email Link' => 'Versenden',
'Export Bookmarks' => 'Exportieren',
'Export Description' => 'Beschreibungen exportieren',
'Favicon Management' => 'Icon Managment',
'Folder Properties' => 'Ordnereigenschaften',
'Group Members' => 'Gruppen-Mitglieder',
'Group Moderators' => 'Gruppen-Moderatoren',
'Group Properties' => 'Gruppen-Eigenschaften',
'Help' => 'Hilfe',
'Hide Folder' => 'Ordner verstecken',
'Import Bookmarks' => 'Importieren',
'Import Description' => 'Beschreibungen importieren',
'Log In' => 'Einloggen',
'Log Out' => 'Ausloggen',
'Maintain Groups' => 'Gruppen verwalten',
'Maintain Users' => 'Benutzer verwalten',
'Maintain Trees' => 'Bäume verwalten',
'Membership' => 'Mitgliedschaften',
'Modify User' => 'Benutzer editieren',
'Order of Trees' => 'Sortierung der Bäume',
'Paste' => 'Einfügen',
'Properties' => 'Eigenschaften',
'Purge Cache' => 'Cache leeren',
'Purge Folder' => 'Papierkorb leeren',
'Retrieve Link Information' => 'Seiten-Informationen abrufen',
'Security' => 'Sicherheit',
'Send Email to Members' => 'E-mail an Gruppenmitglieder schicken',
'Send Email to Moderators' => 'E-mail an den Moderator schicken',
'Send Email to User' => 'E-mail an den Benutzer schicken',
'Send Email to All' => 'E-mail an alle schicken',
'Show All Icons' => 'Zeige alle Icons',
'Set Up' => 'Einrichten',
'Sign Up' => 'Anmelden',
'SiteBar Settings' => 'SiteBar-Einstellungen',
'Undelete' => 'Löschen rückgängig',
'Unhide Trees' => 'Bäume anzeigen',
'Unhide Subfolders' => 'Unterordner anzeigen',
'User Settings' => 'Benutzereinstellungen',
'Personal Data' => 'Persönliche Daten',
'Validate Links' => 'Lesezeichen validieren',
'Validation' => 'Validierung',
'Verify Email' => 'Email verifizieren',
'Verify Email Code' => 'Email Code verifizieren',
'Admin Password' => 'Administrator Passwort',
'Allow Anonymous Contact' => 'Anonymen Kontakt zum Admin erlauben',
'Allow Contact' => 'Kontakt erlauben',
'Allow Given Membership' => 'Zuweisen der Mitgliedschaft ok',
'Allow Info Mail' => 'Info-Mail zulassen',
'Allow Noninteractive Mode' => 'Nicht-interaktiven Modus erlauben',
'Allow Self Add' => 'Eigenes hinzufügen erlauben',
'Allow Sign Up' => 'Gastzugang erlauben',
'Auto Join E-Mail RegExp' => 'E-Mail RegExp für Autom. Hinzufg.',
'Auto Retrieve Favicon' => 'Automatisch Favicon empfangen',
'Bookmark File' => 'Lesezeichen-Datei',
'Cached: ' => 'Im Cache:',
'Codepage' => 'Codepage',
'Comment' => 'Kommentar',
'Content Only' => 'Nur Inhalt',
'Create New Sub Folder' => 'Neuen Unterordner erstellen',
'Dead Link' => 'Defektes Lesezeichen',
'Decode Using' => 'Dekodieren mit',
'Decorate ACL Folders' => 'ACL Order markieren',
'Default Language' => 'Standardsprache',
'Default Search In' => 'Standardsuche in',
'Default Skin' => 'Standarddesign',
'Delete Content Only' => 'Nur Inhalt löschen',
'Delete Invalid Favicons' => 'Ungültige Icons löschen',
'Demo Account' => 'Demo-Konto',
'Description' => 'Beschreibung',
'Description File' => 'Beschreibungsdatei',
'Description Import/Export' => 'Im-/Export von Beschreibungen',
'Discover Missing Favicons' => 'Fehlende Icons suchen',
'E-mail' => 'E-Mail',
'E-mail Verified' => 'E-Mail verifiziert',
'Encode Using' => 'Verschlüsseln mit',
'Exclude From Validation' => 'Von der Validierung ausschliessen',
'Extern Commander' => 'Pop-Up-Fenster verwenden',
'Favicon' => 'Favicon',
'Feedback or Other Comment' => 'Feedback oder sonstiger Kommentar',
'File Type' => 'Dateityp',
'Folder Name' => 'Ordnername',
'From' => 'Von',
'Group Name' => 'Gruppenname',
'Help Topic' => 'Thema',
'Ignore Recently Tested' => 'Kürzlich getestete Lesezeichen ausschliessen',
'Include Subfolders' => 'Unterordner berücksichtigen',
'Keep In Cache' => 'Im Cache behalten',
'Language' => 'Sprache',
'Link Description Length' => 'Beschreibungslänge der Lesezeichen',
'Link Name' => 'Name des Lesezeichen',
'Maximal Icon Age' => 'Maximales Alter der Icons',
'Maximal Icon Size' => 'Maximale Icongrösse',
'Maximal Icons per User' => 'Maximale Icons pro User',
'Maximal Icons Total' => 'Maximale Icons Gesamt',
'Mode' => 'Modus',
'Moderator' => 'Moderator',
'New Tree Owner' => 'Neuer Besitzer der Bäume',
'Old Password' => 'Altes Passwort',
'Only to Verified Emails' => 'Nur an verifizierte E-mails',
'Original: ' => 'Original:',
'Owner' => 'Besitzer',
'Parent Folder' => 'Übergeordneter Ordner',
'Password' => 'Passwort',
'Paste Mode' => 'Einfügemodus',
'Personal Mode' => 'Einzelbenutzer Modus',
'Private' => 'Privat',
'Publish Folder' => 'Ordner veröffentlichen',
'Real Name' => 'Name',
'Recent Time Expressed in Seconds' => 'Zeitraum für "Kürzlich getestet"',
'Remember as Default' => 'Ordner als Default merken',
'Remember Me' => 'Zugangsdaten verwenden',
'Rename Duplicate Links' => 'Doppelte Links neu benennen',
'Repeat Admin Password' => 'Admin Passwort wiederholen',
'Repeat Password' => 'Passwort wiederholen',
'Respect Allow Info Mail' => '"Info-Mail zulassen" berücksichtigen',
'Select Group' => 'Gruppe auswählen',
'Select User' => 'Benutzer auswählen',
'Select Tree' => 'Baum auswählen',
'Sender E-mail' => 'E-mail des Absenders',
'Show Logo' => 'Logo zeigen',
'Show Menu Icon' => 'Kontextmenü-Icon zeigen',
'Show Public Bookmarks' => 'Öffentliche Lesezeichen zeigen',
'Show Sponsor' => 'Sponsor zeigen',
'Show Statistics' => 'Statistik zeigen',
'Skin' => 'Design',
'Skip Execution Messages' => 'Programmeldungen verwerfen',
'Source Folder Name' => 'Name des Originalverzeichnisses',
'Source Link Name' => 'Name des Originallesezeichens',
'Target Folder Name' => 'Name des Zielordners',
'To' => 'An',
'Topic' => 'Thema',
'Tree Name' => 'Baum-Name',
'Tree Owner' => 'Baum Besitzer',
'URL' => 'URL',
'Use Compression' => 'Komprimierung verwenden',
'Use Conversion Engine' => 'Zeichensatz-Konvertierung verwenden',
'Use E-mail Features' => 'E-Mail-Features verwenden',
'Use Favicons' => 'Favicons verwenden',
'Use Folder Hiding' => 'Ordner können versteckt werden',
'Use Hit Counter' => 'Hits zählen',
'Use Outbound Connection' => 'Ausgehende Verbindungen erlauben',
'Use the Favicon Cache' => 'Icon Cache verwenden',
'Users Can Create Trees' => 'Benutzer können Bäume erstellen',
'Users Can Delete Trees' => 'Benutzer können Bäume löschen',
'Your E-mail' => 'Deine E-Mail',
'Until I close browser' => 'Bis ich den Browser schliesse',
'12 hours' => '12 Stunden',
'6 days' => '6 Tage',
'1 month' => '1 Monat',
'No caching' => 'Nicht cachen',
'Order of Folders v. Links' => 'Ordner oder Links zuerst',
'Links first' => 'Links zuerst',
'Folders first' => 'Ordner zuerst',
'Default Link Sort Mode' => 'Standard Sortierung',
'Sort Mode' => 'Sortierungsmodus',
'User default' => 'Standard',
'Custom order' => 'Benutzerdefiniert',
'Alphabetically' => 'Alphabetisch',
'Most clicked first' => 'Am häufigsten verwendet zuerst',
'New/changed links first' => 'Neue/Veränderte Links zuerst',
'Waiting for visit' => 'Noch nicht besuchte zuerst',
'Anonymous Guest' => 'Anonymer Gast',
'Guest' => 'Gast',
'Message' => 'Nachricht',
'SiteBar Server' => 'SiteBar Server',
'%s - ok.' => '%s - ok.',
'%s - error!' => '%s - Fehler!',
'SiteBar: Contact Admin' => 'SiteBar: Administrator kontaktieren',
'SiteBar: Contact Group Moderator' => 'SiteBar: Gruppenmitglieder kontaktieren',
'SiteBar: Email to all SiteBar Users' => 'SiteBar: E-mail an alle SiteBar-Benutzer',
'SiteBar: Email to Group Members' => 'SiteBar: E-mail an die Gruppenmitglieder',
'SiteBar: Email to Group Moderators' => 'SiteBar: E-mail an die Gruppen-Moderatoren',
'SiteBar: Email to SiteBar User' => 'SiteBar: E-mail an einen SiteBar Benutzer',
'SiteBar: Email Verification' => 'SiteBar: Email verifizieren',
'SiteBar: New SiteBar User' => 'SiteBar: Neuer SiteBar Benutzer',
'SiteBar: Web site' => 'SiteBar: Webseite',
'Group' => 'Gruppe',
'R' => 'A',
'A' => 'H',
'M' => 'M',
'D' => 'L',
'P' => 'E',
'G' => 'G',
'Ask' => 'Nachfragen',
'Move or Copy' => 'Verschieben oder Kopieren',
'Copy (Keep Source)' => 'Kopieren (Original behalten)',
'Move (Delete Source)' => 'Verschieben (Original löschen)',
'Auto detection' => 'Automatisch bestimmen',
'Netscape/Mozilla/MS IE' => 'Netscape/Mozilla/MS IE',
'Netscape/Mozilla' => 'Netscape/Mozilla',
'MS Internet Explorer' => 'MS Internet Explorer',
'Opera Hotlist version 2.0' => 'Opera Hotlist Version 2.0',
'Admins' => 'Administratoren',
'Everyone' => 'Jeder',
'%s&#39;s Bookmarks' => '%s&#39;s Lesezeichen',
'Deleted root %s of %s at %s' => 'Baum %s von Benutzer %s wurde um %s gelöscht',
'All' => 'Alle',
'Name' => 'Name',
'Access denied!' => 'Zugriff verweigert!',
'All links recently validated!' => 'Alle Lesezeichen vor kurzem validiert!',
'Cannot connect to http://%s:%s!' => 'Keine Verbindung zu http://%s:%s!',
'Cannot delete built in group!' => 'Fest programmierte Gruppe kann nicht gelöscht werden!',
'Cannot delete user because he is the only moderator of the following group(s): %s!' => 'Der Benutzer kann nicht gelöscht werden, da er der einzige Moderator der Gruppe(n) %s ist!',
'Cannot download %s using https, will try http!' => 'HTTPS ist nicht verfügbar für %s, HTTP wird versucht.',
'Cannot export empty description!' => 'Kann eine leere Beschreibung nicht exportieren!',
'Cannot handle %s protocol!' => 'Protokoll %s kann nicht verwendet werden!',
'Cannot move folder to its subfolder!' => 'Ordner kann nicht in eigenes Unterordner verschoben werden!',
'Cannot remove all moderators from a group!' => 'Es können nicht alle Moderatoren einer Gruppe entfernt werden!',
'Cannot send email!' => 'Email konnte nicht versendet werden!',
'Connection timed out!' => 'Verbindung reagiert nicht rechtzeitig (Timeout)!',
'Database corrupted - missing anonymous account!' => 'Datenbank defekt - der anonyme Benutzer fehlt!',
'Duplicate folder name "%s"!' => 'Doppelter ordner Name: "%s"!',
'Duplicate folder name!' => 'Doppelter Ordner Name!',
'Duplicate name "%s" in the target folder!' => 'Doppelter Name "%s" im Zielordner!',
'Duplicate name "%s"!' => 'Doppelter Name "%s"!',
'Expected field %s was not filled!' => 'Erforderliches Feld %s wurde nicht ausgefüllt!',
'Favicon <img src="%s"> found at url %s.' => 'Icon <img src="%s"> wurde für die URL %s gefunden.',
'Favicon not found!' => 'Kein Icon gefunden!',
'Field %s must be filled!' => 'Feld %s muss ausgefüllt werden!',
'Folder has already been deleted!' => 'Der Ordner wurde bereits gelöscht!',
'Folder with id %s does not exist!' => 'Ordner mit der ID %s existiert nicht!',
'Group has already been deleted!' => 'Die Gruppe wurde bereits gelöscht!',
'Group name "%s" is already used!' => 'Der Gruppenname "%s" wird bereits verwendet!',
'Head of the HTML page was not found!' => 'Es wurde kein Head-Bereich der Seite gefunden!',
'HEAD unsupported, trying GET!' => 'HEAD-Befehl nicht unterstützt, weiche auf GET aus!',
'Host or port undefined!' => 'Host oder Port nicht unterstützt!',
'Icon size %s exceeds maximal size %s!' => 'Icongröße (%s) überschreitet maximale Grösse %s!',
'Incomplete HTTP response!' => 'Unvollständige HTTP-Antwort!',
'Invalid code, verification disabled!' => 'Falsche Code, Verifikation nicht möglich!',
'Invalid regular expresssion!' => 'Ungültiger regulärer Ausdruck!',
'Invalid filename or other upload related problem: %s!' => 'Falscher Dateiname oder ein anderes Problem beim Upload: %s!',
'Link already is in the target folder!' => 'Das Lesezeichen befindet sich bereits im Zielverzeichnis!',
'Link has already been deleted!' => 'Das Lesezeichen wurde bereits gelöscht!',
'Missing command!' => 'Fehlender Befehl!',
'No links in the folder!' => 'Keine Lesezeichen im Ordner!',
'No more than %s redirections allowed!' => 'Nicht mehr als %s Weiterleitungen erlaubt!',
'No user was selected!' => 'Es wurde kein Benutzer ausgewählt!',
'Node number %s has ACL record but does not exist!' => 'Der Knoten mit der Nummer %s hat einen ACL Eintrag, aber er existiert nicht!',
'Old password is invalid!' => 'Altes Passwort ist nicht korrekt!',
'Page not found!' => 'Seite nicht gefunden!',
'Page redirected to %s!' => 'Weiterleitung zu %s!',
'Purge folder to remove it permanently!' => 'Ordner entfernen um ihn komplett zu löschen!',
'Shortcut icon not found! Trying default favicon location %s.' => 'Kein Icon spezifiziert. Möglich Position %s wird getestet.',
'The description length exceeds maximum length of %s bytes!' => 'Die Beschreibungslänge ist um %s Bytes zu lang!',
'The e-mail %s does not look correct!' => 'Die Addresse %s sieht nicht korrekt aus!',
'The password was not repeated correctly!' => 'Das Passwort wurde nicht korrekt wiederholt!',
'There is no content to be deleted!' => 'Da gibt es kein Inhalt den man löschen könnte!',
'There is nothing to be undeleted!' => 'Es kann nichts rückgängig gemacht werden!',
'This email is already used. Did you forget your password?' => 'Diese E-Mail wird bereits verwendet. Hast du dein Passwort vergessen?',
'Tree has already been deleted!' => 'Der Baum wurde bereits gelöscht!',
'Use "%s" command to delete own account!' => '"%s" verwenden um den eigenen Account zu löschen!',
'Unknown command!' => 'Unbekannter Befehl!',
'Unknown username or wrong password!' => 'Unbekannter Benutzer oder falsches Passwort!',
'Verification e-mail has been sent to your e-mail address!' => 'Eine E-Mail zur Verifikation wurde an deine Adresse verschickt!',
'Wrong favicon type/format "%s"!' => 'Falscher Datei-Typ des Icons "%s"!',
'You have been left as group moderator!' => 'Du bist als Gruppenmoderator übriggeblieben!',
'You are the last moderator of used group(s): %s. Account cannot be deleted!' => 'Sie sind der letzte Moderator der Gruppe(n) %s. Ihr Account kann nicht gelöscht werden!',
'%s, welcome to the SiteBar!<p>You have been already logged in.' => '%s, hallo bei der SiteBar!<p>Du bist bereits eingeloggt.',
'E-mail %s verified! Any pending memberships were approved.' => 'E-mail %s verifiziert! Alle noch ausstehenden Mitgliedschaften wurden damit akzeptiert.',
'Link has been added.<p>You must reload your SiteBar in order to see added link!' => 'Lesezeichen wurde hinzugefügt.<p>Du musst SiteBar neu laden um das Lesezeichen zu sehen!',
'Imported %s link(s) into %s folder(s) from the bookmark file.' => '%s Lesezeichen wurden von der Lesezeichendatei in den Ordner %s importiert.',
'Successful execution!' => 'Erfolgreich ausgeführt!',
'Submit' => 'Bestätigen',
'Reset' => 'Zurücksetzen',
'Reload SiteBar' => 'SiteBar neu laden',
'Close' => 'Schliessen',
'Return' => 'Zurück',
'Backup Return to SiteBar' => 'Zurücksetzen',
'Cannot open file!' => 'Die Datei kann nicht geöffnet werden!',
'Unknown bookmark file format!' => 'Unbekanntes Format der Lesezeichen Datei!',
'File is empty!' => 'Datei ist leer!',
'Character set overriden from document to %s!' => 'Der Zeichensatz des Dokumentes wurde zu %s überschrieben!',
'There is no conversion engine available to convert from %s character set!' => 'Es fehlt die Bibliothek um den %s Zeichensatz zu konvertieren!',
'Powered by %s ver. %s' => 'Powered by %s ver. %s',
'Skin created by' => 'Skin erstellt von',
'Skin designed by' => 'Design von',
'Folder found' => 'Ordner gefunden',
'Link found' => 'Lesezeichen gefunden',
'Desc' => 'Beschr.',
'Find next?' => 'Nächstes finden?',
);

?>
