<?php

$text = array
(
'The Bookmark Server for Personal and Team Use' => 'De favorieten server voor persoonlijk- en teamgebruik',
'SiteBar Homepage' => 'SiteBar Homepage',
'SiteBar Installation & Launcher' => 'SiteBar Installatie & Opstarten',
'Any Browser' => 'Iedere browser',
'Content Bookmarklets' => 'Inhoud Bookmarklets',
'Bookmarklet' => 'Bookmarklets',
'Your Language' => 'Nederlands',
'Charset in MS Windows' => 'ISO-8859-1',
'Add Link to SiteBar' => 'Voeg link aan SiteBar toe',
'Add Page to SiteBar' => 'Voeg pagina aan SiteBar toe',
'Error' => 'Fout',
'Warning' => 'Waarschuwing',
'Unknown' => 'Onbekend',
'Search' => 'Zoek',
'Highlight' => 'Markeer',
'Collapse/Expand All' => 'Klap alles in/uit',
'Reload' => 'Herlaad',
'Reload with Hidden Folders' => 'Herlaad met verborgen mappen',
'Backup Log In' => 'Backup aanmelden',
'Backup Log Out' => 'Backup afmelden',
'Commander' => 'Commander',
'Add Folder' => 'Voeg map toe',
'Add Link' => 'Voeg link toe',
'Contact Admin' => 'Contact met beheerder',
'Contact Moderator' => 'Contact met moderator',
'Copy' => 'Kopieer',
'Copy Link' => 'Kopieer link',
'Create Group' => 'Maak groep aan',
'Create Tree' => 'Maak structuur aan',
'Create User' => 'Maak gebruiker aan',
'Custom Order' => 'Eigen volgorde',
'Delete Folder' => 'Verwijder map',
'Delete Group' => 'Verwijder groep',
'Delete Link' => 'Verwijder link',
'Delete Account' => 'Verwijder Account',
'Delete User' => 'Verwijder gebruiker',
'Delete Tree' => 'Verwijder structuur',
'Display Topic' => 'Toon onderwerp',
'Email Link' => 'E-mail link',
'Export Bookmarks' => 'Exporteer favorieten',
'Export Description' => 'Exporteer omschrijving',
'Favicon Management' => 'Favicon beheer',
'Folder Properties' => 'Map eigenschappen',
'Group Members' => 'Groepsleden',
'Group Moderators' => 'Groep moderators',
'Group Properties' => 'Groep eigenschappen',
'Help' => 'Help',
'Hide Folder' => 'Verberg map',
'Import Bookmarks' => 'Importeer favorieten',
'Import Description' => 'Importeer omschrijving',
'Log In' => 'Aanmelden',
'Log Out' => 'Afmelden',
'Maintain Groups' => 'Groepenbeheer',
'Maintain Users' => 'Gebruikersbeheer',
'Maintain Trees' => 'Onderhoud structuur',
'Membership' => 'Lidmaatschap',
'Modify User' => 'Bewerk gebruiker',
'Order of Trees' => 'Volgorde van structuren',
'Paste' => 'Plak',
'Properties' => 'Eigenschappen',
'Purge Cache' => 'Leeg cache',
'Purge Folder' => 'Verwijder map definitief',
'Retrieve Link Information' => 'Verkrijg link informatie',
'Security' => 'Beveiliging',
'Send Email to Members' => 'Verstuur e-mail aan leden',
'Send Email to Moderators' => 'Verstuur e-mail aan moderators',
'Send Email to User' => 'Verstuur e-mail aan gebruiker',
'Send Email to All' => 'Verstuur e-mail aan iedereen',
'Show All Icons' => 'Toon alle iconen',
'Set Up' => 'Installatie',
'Sign Up' => 'Word lid',
'SiteBar Settings' => 'SiteBar instellingen',
'Undelete' => 'Maak ongedaan',
'Unhide Trees' => 'Toon structuren',
'Unhide Subfolders' => 'Toon submappen',
'User Settings' => 'Gebruikersinstellingen',
'Personal Data' => 'Persoonlijke gegevens',
'Validate Links' => 'Valideer Links',
'Validation' => 'Valideren',
'Verify Email' => 'E-mail bevestiging',
'Verify Email Code' => 'E-mail bevestigings code',
'Admin Password' => 'Beheerder wachtwoord',
'Allow Anonymous Contact' => 'Sta anoniem contact toe',
'Allow Contact' => 'Sta contact toe',
'Allow Given Membership' => 'Sta aangebracht lidmaatschap toe',
'Allow Info Mail' => 'Sta informatieve e-mail toe',
'Allow Noninteractive Mode' => 'Sta niet interactieve mode toe',
'Allow Self Add' => 'Sta zelf toevoegen toe',
'Allow Sign Up' => 'Sta lid worden toe',
'Auto Join E-Mail RegExp' => 'Automatisch aanmelden e-mail RegExp',
'Auto Retrieve Favicon' => 'Automatisch favicon ophalen',
'Bookmark File' => 'Favorieten bestand',
'Cached: ' => 'In tussengeheugen:',
'Codepage' => 'Codepagina',
'Comment' => 'Opmerkingen',
'Content Only' => 'Enkel inhoud',
'Create New Sub Folder' => 'Maak nieuw submap aan',
'Dead Link' => 'Dode Link',
'Decode Using' => 'Decodeer met',
'Decorate ACL Folders' => 'Markeer ACL mappen',
'Default Language' => 'Standaard taal',
'Default Search In' => 'Zoek standaard in',
'Default Skin' => 'Standaard opmaak',
'Delete Content Only' => 'Verwijder enkel inhoud',
'Delete Invalid Favicons' => 'Verwijder Incorrecte Favicons',
'Demo Account' => 'Demo account',
'Description' => 'Omschrijving',
'Description File' => 'Omschrijvingen bestand',
'Description Import/Export' => 'Omschrijving im-/export',
'Discover Missing Favicons' => 'Zoek ontbrekende Favicons',
'E-mail' => 'E-mail',
'E-mail Verified' => 'E-mail geverifieerd',
'Encode Using' => 'Encodeer met',
'Exclude From Validation' => 'Uitsluiten van validatie',
'Extern Commander' => 'Externe besturing',
'Favicon' => 'Favicon',
'Feedback or Other Comment' => 'Opmerkingen of ander commentaar',
'File Type' => 'Bestandstype',
'Folder Name' => 'Mapnaam',
'From' => 'Van',
'Group Name' => 'Groep naam',
'Help Topic' => 'Help onderwerp',
'Ignore Recently Tested' => 'Negeer Recent Getest',
'Include Subfolders' => 'Met submappen',
'Keep In Cache' => 'Bewaar in buffer',
'Language' => 'Taal',
'Link Description Length' => 'Lengte omschrijving verwijzing ',
'Link Name' => 'Naam verwijzing',
'Maximal Icon Age' => 'Maximale iconen leeftijd',
'Maximal Icon Size' => 'Maximale iconen grootte',
'Maximal Icons per User' => 'Maximaal aantal iconen per gebruiker',
'Maximal Icons Total' => 'Maximaal totaal aantal iconen ',
'Mode' => 'Modus',
'Moderator' => 'Moderator',
'New Tree Owner' => 'Nieuwe structuur eigenaar',
'Old Password' => 'Oud wachtwoord',
'Only to Verified Emails' => 'Enkel aan geverifieerde e-mail adressen',
'Original: ' => 'Origineel:',
'Owner' => 'Eigenaar',
'Parent Folder' => 'Hoofdmap',
'Password' => 'Wachtwoord',
'Paste Mode' => 'Plak mode',
'Personal Mode' => 'Persoonlijke mode',
'Private' => 'Prive',
'Publish Folder' => 'Publiceer map',
'Real Name' => 'Volledige naam',
'Recent Time Expressed in Seconds' => 'Recente Tijd Uitgedrukt in Seconden',
'Remember as Default' => 'Onthoud me als standaard',
'Remember Me' => 'Onthoud me',
'Rename Duplicate Links' => 'Hernoem dubbele links',
'Repeat Admin Password' => 'Herhaal beheerder wachtwoord',
'Repeat Password' => 'Herhaal wachtwoord',
'Respect Allow Info Mail' => 'Respecteer toegestane info mail',
'Select Group' => 'Selecteer groep',
'Select User' => 'Selecteer gebruiker',
'Sender E-mail' => 'Afzender e-mail',
'Show Logo' => 'Toon logo',
'Show Menu Icon' => 'Toon menu iconen',
'Show Public Bookmarks' => 'Toon publieke favorieten',
'Show Sponsor' => 'Toon sponsor',
'Skin' => 'Opmaak',
'Skip Execution Messages' => 'Geen verwerkt berichten',
'Source Folder Name' => 'Bronmap naam',
'Source Link Name' => 'Bronlink naam',
'Target Folder Name' => 'Doelmap naam',
'To' => 'Aan ',
'Topic' => 'Onderwerp',
'Tree Name' => 'Structuur naam',
'Tree Owner' => 'Structuur eigenaar',
'URL' => 'URL',
'Use Compression' => 'Gebruik compressie',
'Use Conversion Engine' => 'Gebruik conversie motor',
'Use E-mail Features' => 'Gebruik e-mail instellingen',
'Use Favicons' => 'Gebruik favicons',
'Use Folder Hiding' => 'Gebruik map verbergen',
'Use Hit Counter' => 'Gebruik hit teller',
'Use Outbound Connection' => 'Gebruik outbound connectie',
'Use the Favicon Cache' => 'Gebruik de favicon cache',
'Users Can Create Trees' => 'Gebruikers kunnen structuren aanmaken',
'Your E-mail' => 'Uw e-mailadres',
'Until I close browser' => 'Tot ik de browser sluit',
'12 hours' => '12 uur',
'6 days' => '6 dagen',
'1 month' => '1 maand',
'No caching' => 'Geen caching',
'Order of Folders v. Links' => 'Volgorde van mappen versus Links',
'Links first' => 'Links eerst',
'Folders first' => 'Mappen eerst',
'Default Link Sort Mode' => 'Standaard link sorteer mode',
'Sort Mode' => 'Sorteer mode',
'User default' => 'Gebruikers standaard',
'Custom order' => 'Eigen volgorde',
'Alphabetically' => 'Alfabetisch',
'Most clicked first' => 'Meest geklikt eerst',
'New/changed links first' => 'Nieuwste/gewijzigde links eerst',
'Waiting for visit' => 'Wacht op bezoek',
'Anonymous Guest' => 'Anonieme gast',
'Guest' => 'Gast',
'Message' => 'Bericht',
'SiteBar Server' => 'SiteBar Server',
'%s - ok.' => '%s -ok.',
'%s - error!' => '%s - fout!',
'SiteBar: Contact Admin' => 'SiteBar: Contact met beheerder',
'SiteBar: Contact Group Moderator' => 'SiteBar: Contact met groeps moderator',
'SiteBar: Email to all SiteBar Users' => 'SiteBar: E-mail aan alle SiteBar gebruikers',
'SiteBar: Email to Group Members' => 'SiteBar: E-mail aan groepsleden',
'SiteBar: Email to Group Moderators' => 'SiteBar: E-mail aan groep moderators',
'SiteBar: Email to SiteBar User' => 'SiteBar: E-mail aan SiteBar gebruiker',
'SiteBar: Email Verification' => 'SiteBar: E-mail verificatie',
'SiteBar: New SiteBar User' => 'SiteBar: Nieuwe SiteBar gebruiker',
'SiteBar: Web site' => 'SiteBar: website',
'Group' => 'Groep',
'R' => 'R',
'A' => 'A',
'M' => 'M',
'D' => 'D',
'P' => 'P',
'G' => 'G',
'Ask' => 'Vraag',
'Move or Copy' => 'Verplaats of kopieer',
'Copy (Keep Source)' => 'Kopieer (bewaar bron)',
'Move (Delete Source)' => 'Verplaats (verwijder bron)',
'Auto detection' => 'Autodetectie',
'Netscape/Mozilla/MS IE' => 'Netscape/Mozilla/MS IE',
'Netscape/Mozilla' => 'Netscape/Mozilla',
'MS Internet Explorer' => 'MS Internet Explorer',
'Opera Hotlist version 2.0' => 'Opera Hotlist versie 2.0',
'Admins' => 'Beheerders',
'Everyone' => 'Iedereen',
'%s&#39;s Bookmarks' => '%s&#39;s favorieten',
'Deleted root %s of %s at %s' => 'Verwijderd bron %s van %s op %s',
'All' => 'Alle',
'Name' => 'Naam',
'Access denied!' => 'Toegang geweigerd!',
'All links recently validated!' => 'Alle links onlangs gevalideerd!',
'Cannot connect to http://%s:%s!' => 'Kan niet verbinden met http://%s:%s!',
'Cannot delete built in group!' => 'Kan geen standaard groepen verwijderen!',
'Cannot delete user because he is the only moderator of the following group(s): %s!' => 'Kan gebruiker niet verwijderen omdat dit de enige moderator is van de volgende groep(en): %s!',
'Cannot download %s using https, will try http!' => 'Kan %s niet downloaden via https, zal nu proberen met http!',
'Cannot export empty description!' => 'Kan geen lege omschrijving exporteren!',
'Cannot handle %s protocol!' => 'Kan niet omgaan met protocol %s!',
'Cannot move folder to its subfolder!' => 'Kan de map niet verplaatsen naar diens submap!',
'Cannot remove all moderators from a group!' => 'Kan niet alle moderators van een groep verwijderen!',
'Cannot send email!' => 'Kan geen e-mail versturen!',
'Connection timed out!' => 'Kon geen connectie tot stand brengen!',
'Database corrupted - missing anonymous account!' => 'Database corrupt - geen anoniem account!',
'Duplicate folder name "%s"!' => 'Dubbele mapnaam "%s"!',
'Duplicate folder name!' => 'Dubbele mapnaam!',
'Duplicate name "%s" in the target folder!' => 'Dubbele naam "%s" in de doelmap!',
'Duplicate name "%s"!' => 'Dubbele naam "%s"!',
'Expected field %s was not filled!' => 'Verwacht veld "%s" is niet ingevuld!',
'Favicon <img src="%s"> found at url %s.' => 'Favicon <img src="%s"> gevonden op adres %s.',
'Favicon not found!' => 'Favicon niet gevonden!',
'Field %s must be filled!' => 'Veld "%s" moet ingevuld worden!',
'Folder has already been deleted!' => 'Map is al verwijderd!',
'Folder with id %s does not exist!' => 'Map met id %s bestaat niet!',
'Group has already been deleted!' => 'Groep is al verwijderd!',
'Group name "%s" is already used!' => 'Groepnaam "%s" is reeds in gebruik!',
'Head of the HTML page was not found!' => 'Kop van de HTML pagina niet gevonden!',
'HEAD unsupported, trying GET!' => 'HEAD is niet ondersteund, zal met GET proberen! ',
'Host or port undefined!' => 'Host of port niet ingevuld!',
'Icon size %s exceeds maximal size %s!' => 'Icoon afmeting %s is groter dan het maximum van %s!',
'Incomplete HTTP response!' => 'Incompleet HTTP antwoord!',
'Invalid code, verification disabled!' => 'Ongeldige code, verificatie uitgezet!',
'Invalid regular expresssion!' => 'Ongeldige reguliere uitdrukking!',
'Invalid filename or other upload related problem: %s!' => 'Ongeldige bestandsnaam of ander upload gerelateerd probleem: %s!',
'Link already is in the target folder!' => 'Favoriet bestaat al in de doelmap!',
'Link has already been deleted!' => 'Favoriet is al verwijderd!',
'Missing command!' => 'Missend commando!',
'No links in the folder!' => 'Geen links in de folder!',
'No more than %s redirections allowed!' => 'Niet meer dan %s omleidingen toegestaan!',
'No user was selected!' => 'Er is geen gebruiker geselecteerd!',
'Node number %s has ACL record but does not exist!' => 'Node nummer %s heeft een ACL record maar bestaat niet!',
'Old password is invalid!' => 'Oude wachtwoord is ongeldig!',
'Page not found!' => 'Pagina niet gevonden!',
'Page redirected to %s!' => 'Pagina omgeleid naar %s!',
'Purge folder to remove it permanently!' => 'Verwijder folder permanent!',
'Shortcut icon not found! Trying default favicon location %s.' => 'Snelkoppeling icoon niet gevonden! Zal standaard locatie voor favicon %s proberen.',
'The description length exceeds maximum length of %s bytes!' => 'De omschrijvingslengte is groter dan de maximale lengte van %s bytes!',
'The e-mail %s does not look correct!' => 'Het e-mail adres %s lijkt niet juist!',
'The password was not repeated correctly!' => 'Het wachtwoord is niet juist herhaald!',
'There is no content to be deleted!' => 'Er is geen inhoud om te verwjideren!',
'There is nothing to be undeleted!' => 'Er is niets om hersteld te worden!',
'This email is already used. Did you forget your password?' => 'Dit e-mail adres is al gebruikt. Bent u uw wachtwoord vergeten?',
'Tree has already been deleted!' => 'Structuur is al verwijderd!',
'Use "%s" command to delete own account!' => 'Gebruik "%s" commando om het eigen account te verwijderen!',
'Unknown command!' => 'Onbekend commando!',
'Unknown username or wrong password!' => 'Ongeldige gebruikersnaam of verkeerd wachtwoord! ',
'Verification e-mail has been sent to your e-mail address!' => 'Een verficatie e-mail is aan u toegestuurd!',
'Wrong favicon type/format "%s"!' => 'Favicon heeft verkeerd type/formaat "%s"!',
'You have been left as group moderator!' => 'U bent achtergebleven als groep moderator!',
'You are the last moderator of used group(s): %s. Account cannot be deleted!' => 'U bent de laatste moderator van groep(en): %s. Account kan niet verwijderd worden!',
'%s, welcome to the SiteBar!<p>You have been already logged in.' => '%s, welkom bij de SiteBar!<p>U bent nu direct aangemeld.',
'E-mail %s verified! Any pending memberships were approved.' => 'E-mail %s geverifieerd! Alle lidmaatschappen zijn goedgekeurd.',
'Link has been added.<p>You must reload your SiteBar in order to see added link!' => 'Favoriet is toegevoegd.<p>U moet de SiteBar herladen om deze link te zien!',
'Imported %s link(s) into %s folder(s) from the bookmark file.' => 'Er zijn %s favorieten geimporteerd in %s map(pen) uit het favorieten bestand.',
'Successful execution!' => 'Succesvol verwerkt!',
'Submit' => 'Bijwerken',
'Reset' => 'Herstel',
'Reload SiteBar' => 'Herlaad SiteBar',
'Close' => 'Sluit',
'Return' => 'Terug',
'Backup Return to SiteBar' => 'Backup naar SiteBar',
'Cannot open file!' => 'Kan bestand niet openen!',
'Unknown bookmark file format!' => 'Ongeldig favorieten bestandsformaat!',
'File is empty!' => 'Bestand is leeg!',
'Character set overriden from document to %s!' => 'Karakter set overschreven uit het document met %s!',
'There is no conversion engine available to convert from %s character set!' => 'Er is geen conversie motor beschikbaar om naar de %s karakterset te converteren!',
'Powered by %s ver. %s' => 'Powered by %s versie %s',
'Skin created by' => 'Opmaak door',
'Skin designed by' => 'Opmaak ontworpen door',
'Folder found' => 'Map gevonden',
'Link found' => 'Favoriet gevonden',
'Desc' => 'Omschr.',
'Find next?' => 'Vind volgende?',
);

?>
