<?php

$text = array
(
'The Bookmark Server for Personal and Team Use' => 'Bokmerketjener til personlig bruk og gruppebruk',
'SiteBar Homepage' => 'SiteBar hjemmeside',
'SiteBar Installation & Launcher' => 'SiteBar installasjon & velger',
'Any Browser' => 'Enhver nettleser',
'Content Bookmarklets' => 'Bookmarklets for innhold',
'Bookmarklet' => 'Bookmarklet',
'Your Language' => 'Norsk (bokmål)',
'Charset in MS Windows' => 'ISO-8859-1',
'Add Link to SiteBar' => 'Legg lenke til SiteBar',
'Add Page to SiteBar' => 'Legg siden til SiteBar',
'Error' => 'Feil',
'Warning' => 'Advarsel',
'Unknown' => 'Ukjent',
'Search' => 'Søk',
'Highlight' => 'Markér',
'Collapse/Expand All' => 'Skjul/Utvid Alt',
'Reload' => 'Oppdater',
'Reload with Hidden Folders' => 'Oppdater med skjulte mapper',
'Backup Log In' => 'Backup logg inn',
'Backup Log Out' => 'Backup logg ut',
'Commander' => 'Kommandohåndtering',
'Add Folder' => 'Legg til mappe',
'Add Link' => 'Legg til lenke',
'Contact Admin' => 'Kontakt admin',
'Contact Moderator' => 'Kontakt moderator',
'Copy' => 'Kopier',
'Copy Link' => 'Kopier lenke',
'Create Group' => 'Opprett gruppe',
'Create Tree' => 'Opprett tre',
'Create User' => 'Opprett bruker',
'Custom Order' => 'Sorter etter egen rekkefølge',
'Delete Folder' => 'Slett mappe',
'Delete Group' => 'Slett gruppe',
'Delete Link' => 'Slett lenke',
'Delete Account' => 'Slett konto',
'Delete User' => 'Slett bruker',
'Delete Tree' => 'Slett tre',
'Display Topic' => 'Vis emne',
'Email Link' => 'Epost lenke',
'Export Bookmarks' => 'Eksporter bokmerker',
'Export Description' => 'Eksporter beskrivelse',
'Favicon Management' => 'Favikon-håndtering',
'Folder Properties' => 'Egenskaper for mappe',
'Group Members' => 'Gruppemedlemmer',
'Group Moderators' => 'Gruppemoderatorer',
'Group Properties' => 'Egenskaper for gruppe',
'Help' => 'Hjelp',
'Hide Folder' => 'Skjult mappe',
'Import Bookmarks' => 'Importer bokmerker',
'Import Description' => 'Importer beskrivelse',
'Log In' => 'Logg inn',
'Log Out' => 'Logg ut',
'Maintain Groups' => 'Vedlikehold grupper',
'Maintain Users' => 'Vedlikehold brukere',
'Maintain Trees' => 'Vedlikehold trær',
'Membership' => 'Medlemsskap',
'Modify User' => 'Modifisere bruker',
'Order of Trees' => 'Sortering av trær',
'Paste' => 'Lim inn',
'Properties' => 'Egenskaper',
'Purge Cache' => 'Rens mellomlager',
'Purge Folder' => 'Rens mappe',
'Retrieve Link Information' => 'Gjenvinn lenkeinformasjon',
'Security' => 'Sikkerhet',
'Send Email to Members' => 'Send epost til medlemmer',
'Send Email to Moderators' => 'Send epost til moderatorer',
'Send Email to User' => 'Send epost til bruker',
'Send Email to All' => 'Send epost til alle',
'Show All Icons' => 'Vis alle ikoner',
'Set Up' => 'Oppsett',
'Sign Up' => 'Registrer deg',
'SiteBar Settings' => 'Instillinger for SiteBar',
'Undelete' => 'Gjenopprett',
'Unhide Trees' => 'Vis trær',
'Unhide Subfolders' => 'Vis undermapper',
'User Settings' => 'Brukerinstillinger',
'Personal Data' => 'Personlige data',
'Validate Links' => 'Valider lenker',
'Validation' => 'Validering',
'Verify Email' => 'Verifiser epost',
'Verify Email Code' => 'Verifiser epostkode',
'Admin Password' => 'Admin-passord',
'Allow Anonymous Contact' => 'Tillat anonym kontakt',
'Allow Contact' => 'Tillat kontakt',
'Allow Given Membership' => 'Tillat gitt medlemsskap',
'Allow Info Mail' => 'Tillat infopost',
'Allow Noninteractive Mode' => 'Tillat ikke-interaktiv operasjon',
'Allow Self Add' => 'Tillat å legge til deg selv',
'Allow Sign Up' => 'Tillat å registrere deg selv',
'Auto Join E-Mail RegExp' => 'Autoforbind epost-RegExp',
'Auto Retrieve Favicon' => 'Gjenopprett favicon automatisk',
'Bookmark File' => 'Bokmerkefil',
'Cached: ' => 'Mellomlagret:',
'Codepage' => 'Codepage',
'Comment' => 'Kommentar',
'Content Only' => 'Kun innhold',
'Create New Sub Folder' => 'Opprett ny undermappe',
'Dead Link' => 'Død lenke',
'Decode Using' => 'Dekode med bruk av',
'Decorate ACL Folders' => 'Dekorer ACL-mapper',
'Default Language' => 'Standardspråk',
'Default Search In' => 'Søk standard i',
'Default Skin' => 'Standard drakt',
'Delete Content Only' => 'Slett kun innhold',
'Delete Invalid Favicons' => 'Slett ugyldige favikoner',
'Demo Account' => 'Demo-konto',
'Description' => 'Beskrivelse',
'Description File' => 'Fil for beskrivelser',
'Description Import/Export' => 'Importer/eksporter beskrivelse',
'Discover Missing Favicons' => 'Oppdag manglende favikoner',
'E-mail' => 'Epost',
'E-mail Verified' => 'Epost verifisert',
'Encode Using' => 'Kode med bruk av',
'Exclude From Validation' => 'Unnta fra validering',
'Extern Commander' => 'Ekstern kommandohåndtering',
'Favicon' => 'Favikon',
'Feedback or Other Comment' => 'Tilbakemelding eller andre kommentarer',
'File Type' => 'Filtype',
'Folder Name' => 'Mappenavn',
'From' => 'Fra',
'Group Name' => 'Gruppenavn',
'Help Topic' => 'Emner i Hjelp',
'Ignore Recently Tested' => 'Ignorer nylig testede',
'Include Subfolders' => 'Inlluder undermapper',
'Keep In Cache' => 'Behold i mellomlager',
'Language' => 'Språk',
'Link Description Length' => 'Lengde på lenkebeskrivelse',
'Link Name' => 'Lenkenavn',
'Maximal Icon Age' => 'Maksimal ikonalder',
'Maximal Icon Size' => 'Maksimal ikonstørrelse',
'Maximal Icons per User' => 'Maksimum antall ikoner pr. bruker',
'Maximal Icons Total' => 'Maksimum ikoner totalt',
'Mode' => 'Modus',
'Moderator' => 'Moderator',
'New Tree Owner' => 'Ny eier av tre',
'Old Password' => 'Gammelt passord',
'Only to Verified Emails' => 'Bare for verifiserte epostadresser',
'Original: ' => 'Opprinnelig:',
'Owner' => 'Eier',
'Parent Folder' => 'Foreldermappe',
'Password' => 'Passord',
'Paste Mode' => 'Innlimingsmodus',
'Personal Mode' => 'Personlig modus',
'Private' => 'Privat',
'Publish Folder' => 'Publisér mappe',
'Real Name' => 'Fullt navn',
'Recent Time Expressed in Seconds' => 'Siste tid uttrykt i sekunder',
'Remember as Default' => 'Husk som standard',
'Remember Me' => 'Husk meg',
'Rename Duplicate Links' => 'Gi nytt navn til duplikatlenker',
'Repeat Admin Password' => 'Gjenta admin-passord',
'Repeat Password' => 'Gjenta passord',
'Respect Allow Info Mail' => 'Respekter "tillat informasjons-epost"',
'Select Group' => 'Velg gruppe',
'Select User' => 'Velg bruker',
'Sender E-mail' => 'Avsenders epost',
'Show Logo' => 'Vis logo',
'Show Menu Icon' => 'Vis menyikon',
'Show Public Bookmarks' => 'Vis offentlige bokmerker',
'Show Sponsor' => 'Vis sponsor',
'Skin' => 'Drakt',
'Skip Execution Messages' => 'Ikke vis kjøremeldinger',
'Source Folder Name' => 'Kildemappes navn',
'Source Link Name' => 'Kildelenkes navn',
'Target Folder Name' => 'Målmappes navn',
'To' => 'Til',
'Topic' => 'Emne',
'Tree Name' => 'Treets navn',
'Tree Owner' => 'Eier av tre',
'URL' => 'URL',
'Use Compression' => 'Bruk komprimering',
'Use Conversion Engine' => 'Bruk konverteringsmotor',
'Use E-mail Features' => 'Bruk epostmuligheter',
'Use Favicons' => 'Bruk favikoner',
'Use Folder Hiding' => 'Bruk skjuling av mapper',
'Use Hit Counter' => 'Bruk treffteller',
'Use Outbound Connection' => 'Bruk utgående forbindelse',
'Use the Favicon Cache' => 'Bruk mellomlageret for favikoner',
'Users Can Create Trees' => 'Brukere kan opprette trær',
'Your E-mail' => 'Din epostadresse',
'Until I close browser' => 'Til jeg lukker nettleseren',
'12 hours' => '12 timer',
'6 days' => '6 dager',
'1 month' => '1 måned',
'No caching' => 'Ingen mellomlagring',
'Order of Folders v. Links' => 'Sortering av mapper el. lenker',
'Links first' => 'Lenker først',
'Folders first' => 'Mapper først',
'Default Link Sort Mode' => 'Standardsortering av lenker',
'Sort Mode' => 'Sortering',
'User default' => 'Bruk standard',
'Custom order' => 'Tilpasset sortering',
'Alphabetically' => 'Alfabetisk',
'Most clicked first' => 'Mest klikket på først',
'New/changed links first' => 'Sist endrede lenker først',
'Waiting for visit' => 'Venter på besøk',
'Anonymous Guest' => 'Anonym gjest',
'Guest' => 'Gjest',
'Message' => 'Melding',
'SiteBar Server' => 'SiteBar-tjener',
'%s - ok.' => '%s - ok.',
'%s - error!' => '%s - feil!',
'SiteBar: Contact Admin' => 'SiteBar: Kontakt admin',
'SiteBar: Contact Group Moderator' => 'SiteBar: Kontakt gruppemoderator',
'SiteBar: Email to all SiteBar Users' => 'SiteBar: Epost til alle SiteBar-brukere',
'SiteBar: Email to Group Members' => 'SiteBar: Epost til gruppemedlemmer',
'SiteBar: Email to Group Moderators' => 'SiteBar: Epost til gruppemoderatorer',
'SiteBar: Email to SiteBar User' => 'SiteBar: Epost til SiteBar-bruker',
'SiteBar: Email Verification' => 'SiteBar: Epostverifisering',
'SiteBar: New SiteBar User' => 'SiteBar: Ny SiteBar-bruker',
'SiteBar: Web site' => 'SiteBar: Websted',
'Group' => 'Gruppe',
'R' => 'e',
'A' => 'L',
'M' => 'M',
'D' => 'S',
'P' => 'R',
'G' => 'T',
'Ask' => 'Spør',
'Move or Copy' => 'Flytt eller Kopier',
'Copy (Keep Source)' => 'Kopier (behold kilden)',
'Move (Delete Source)' => 'Flytt (slett kilden)',
'Auto detection' => 'Automatisk oppdaging',
'Netscape/Mozilla/MS IE' => 'Netscape/Mozilla/MS IE',
'Netscape/Mozilla' => 'Netscape/Mozilla',
'MS Internet Explorer' => 'MS Internet Explorer',
'Opera Hotlist version 2.0' => 'Opera panel-versjon 2.0',
'Admins' => 'Aministratorer',
'Everyone' => 'Alle',
'%s&#39;s Bookmarks' => '%ss Bokmerker',
'Deleted root %s of %s at %s' => 'Slettet rot %s av %s på %s',
'All' => 'Alle',
'Name' => 'Navn',
'Access denied!' => 'Tilgang nektet',
'All links recently validated!' => 'Alle lenker nylig verifisert!',
'Cannot connect to http://%s:%s!' => 'Kan ikke koble til http://%s:%s!',
'Cannot delete built in group!' => 'Kan ikke slette innebygget gruppe!',
'Cannot delete user because he is the only moderator of the following group(s): %s!' => 'Kan ikke slette bruker fordi brukeren er den eneste moderator i følgende gruppe(r): %s!',
'Cannot download %s using https, will try http!' => 'Kan ikke nedlaste %s ved bruk av https, prøver http!',
'Cannot export empty description!' => 'Kan ikke eksportere tom beskrivelse!',
'Cannot handle %s protocol!' => 'Kan ikke håndtere %s protokoll!',
'Cannot remove all moderators from a group!' => 'Kan ikke fjerne alle moderatorer fra en gruppe!',
'Cannot send email!' => 'Kan ikke sende epost!',
'Connection timed out!' => 'Forbindelsen tidsutkoblet!',
'Database corrupted - missing anonymous account!' => 'Databasen er korrupt - mangler anonym konto!',
'Duplicate folder name "%s"!' => 'Duplisert mappenavn "%s"!',
'Duplicate folder name!' => 'Duplisert mappenavn!',
'Duplicate name "%s" in the target folder!' => 'Duplisert navn "%s" i målmappen!',
'Duplicate name "%s"!' => 'Duplisert navn "%s"!',
'Expected field %s was not filled!' => 'Forventet felt %s ikke utfyllt!',
'Favicon <img src="%s"> found at url %s.' => 'Favikon <img src="%s"> funnet ved url %s.',
'Favicon not found!' => 'Favikon ikke funnet!',
'Field %s must be filled!' => 'Feltet %s må fylles ut!',
'Folder has already been deleted!' => 'Mappen har allerede blitt slettet!',
'Folder with id %s does not exist!' => 'Mappen med id %s finnes ikke!',
'Group has already been deleted!' => 'Gruppen er allerede slettet!',
'Group name "%s" is already used!' => 'Gruppenavnet "%s" er allerede i bruk!',
'Head of the HTML page was not found!' => 'HTML-sidens head ble ikke funnet!',
'HEAD unsupported, trying GET!' => 'HEAD er ikke støttet, prøver GET!',
'Host or port undefined!' => 'Vert eller port udefinert!',
'Icon size %s exceeds maximal size %s!' => 'Ikon-størrelsen %s er over maksimalstørrelsen %s!',
'Incomplete HTTP response!' => 'Ufullstendig HTTP-respons!',
'Invalid code, verification disabled!' => 'Ugyldig kode, verifisering slått av!',
'Invalid regular expresssion!' => 'Ugyldig regular expression!',
'Invalid filename or other upload related problem: %s!' => 'Ugyldig filnavn eller andre opplastingsrelaterte problemer: %s!',
'Link already is in the target folder!' => 'Lenken finnes allerede i målmappen!',
'Link has already been deleted!' => 'Lenken er allerede slettet!',
'Missing command!' => 'Mangelende kommando!',
'No links in the folder!' => 'Ingen lenker i mappen!',
'No more than %s redirections allowed!' => 'Ikke mer enn %s omadresseringer er tillatt!',
'No user was selected!' => 'Ingen bruker ble valgt!',
'Node number %s has ACL record but does not exist!' => 'Notenummer %s har ACL-oppføring, men eksisterer ikke!',
'Old password is invalid!' => 'Gammelt passord er ugyldig!',
'Page not found!' => 'Siden ikke funnet!',
'Page redirected to %s!' => 'Siden omadressert til %s!',
'Purge folder to remove it permanently!' => 'Rydd mappe for å fjerne den permanent!',
'Shortcut icon not found! Trying default favicon location %s.' => 'Snarveisikon ikke funnet! Prøv standard plassering %s for favikoner.',
'The description length exceeds maximum length of %s bytes!' => 'Lengden på beskrivelsen overgår maks-lengden på %s byte!',
'The e-mail %s does not look correct!' => 'Epostadresen %s ser ikke ut til å være korrekt!',
'The password was not repeated correctly!' => 'Passordet ble ikke gjentatt riktig!',
'There is no content to be deleted!' => 'Det er ikke noe innhold å slette!',
'There is nothing to be undeleted!' => 'Det er ingen ting å gjenopprette!',
'This email is already used. Did you forget your password?' => 'Denne eposten er allerede brukt. Har du glemte passordet?',
'Tree has already been deleted!' => 'Treet er allerede slettet!',
'Use "%s" command to delete own account!' => 'Bruk kommandoen"%s" for å slette egen konto!',
'Unknown command!' => 'Ukjent kommando!',
'Unknown username or wrong password!' => 'Ukjent brukernavn eller feil passord!',
'Verification e-mail has been sent to your e-mail address!' => 'Verifikasjons-epost er sendt til din epost-adresse!',
'Wrong favicon type/format "%s"!' => 'Favikonets type/format "%s" er feil!',
'You have been left as group moderator!' => 'Du har blitt etterlatt som gruppemoderator!',
'You are the last moderator of used group(s): %s. Account cannot be deleted!' => 'Du er den siste moderator for gruppe(ne): %s. Konto kan ikke slettes!',
'%s, welcome to the SiteBar!<p>You have been already logged in.' => '%s, velkommen til SiteBar!<p>Du har allerede blitt logget inn.',
'E-mail %s verified! Any pending memberships were approved.' => 'Epost %s verifisert! Ventende medlemskap ble godkjent.',
'Link has been added.<p>You must reload your SiteBar in order to see added link!' => 'Lenka har blitt lagt til.<p>Du må oppfriske din SiteBar for å se den tillagte lenka!',
'Imported %s link(s) into %s folder(s) from the bookmark file.' => 'Importert %s lenke(r) til %s mappe(r) fra bokmerkefil.',
'Successful execution!' => 'Vellykket utført!',
'Submit' => 'Send',
'Reset' => 'Rens',
'Reload SiteBar' => 'Oppfrisk SiteBar',
'Close' => 'Lukk',
'Return' => 'Tilbake',
'Backup Return to SiteBar' => 'Backup tilbake til SiteBar',
'Cannot open file!' => 'Kan ikke åpne fil!',
'Unknown bookmark file format!' => 'Ukjent filformat for bokmerkefil!',
'File is empty!' => 'Filen var tom!',
'Character set overriden from document to %s!' => 'Tegnsett tilsidesatt fra dokument for %s!',
'There is no conversion engine available to convert from %s character set!' => 'Det er ingen konverteringsmotor tilgjengelig for å konvertere fra tegnsettet %s!',
'Powered by %s ver. %s' => 'Laget av %s v. %s',
'Skin created by' => 'Drakt laget av',
'Skin designed by' => 'Drakt designet av',
'Folder found' => 'Mappe funnet',
'Link found' => 'Lenke funnet',
'Desc' => 'Beskr.',
'Find next?' => 'Finn neste?',
);

?>
