<?php

$help = array();

$help['100'] = <<<_P
Les funcions de SiteBar son accessibles des del <strong>Menú d'usuari</strong> i des dels <strong>Menús contextuals</strong> de carpeta i enllaç. El menú d'usuari es mostra a baix de SiteBar, i els menús contextuals son accesibles clicant amb el botó dret a les carpetes o enllaços. Usuaris d'Opera i Apple poden fer un Ctrl-clic. En el cas que fins i tot un Ctrl-clic no sigui reconegut és posible activar un switch "Mostrar icona de menú" des de la comanda "Preferències d'usuari". Quan aquesta opció sigui activa es mostrarà una petita icona de menu sota la icona de carpeta o enllaç. Clicant en aquesta icona obrirà el menú contextual. <p> Tant els menus contextuals com els d'usuari poden mostrar diferents subconjunts de comandes per diferents usuaris segons els seus drets al sistema. Algunes opcions poden estar desactivades al menú contextual basat en els drets d'usuari als nodes i l'estat actual del programa. Les comandes son executades via la finestra de comandes.
_P;

$help['101'] = <<<_P
Clica en una carpeta o un enllaç i mou el cursor damunt una altra carpeta mantenint el botó apretat. Arrastrar és senyalat iluminant la carpeta de destí. Solta el botó per deixar caure l'enllaç o carpeta arrastrat a la carpeta iluminada.
<p>
Drag & Drop no està implementat per l'equip de SiteBar per als navegadors Opera. Copy and Paste ha de ser usat en aquest cas.
_P;

$help['102'] = <<<_P
La forma més convenient d'afegir enllaços es usar l'anomenat bookmarklet. Pots crear bookmarklets des de la pàgina de la teva instalació de SiteBar, que hauria de ser disponible per defecte clicant al logotip de SiteBar. L'Internet Explorer pot usar el menú contextual si han usat l'instalador descrit a la mateixa pàgina que el bookmarklet.
_P;

$help['200'] = <<<_P
Les comandes estan agrupades en diversos grups lògics. Sisplau, selecciona un dels grups per veure l'ajuda de la comanda.
_P;

?>
