<?php

$text = array
(
'The Bookmark Server for Personal and Team Use' => 'Il Bookmark Server per uso personale e di gruppo',
'SiteBar Homepage' => 'SiteBar homepage',
'Any Browser' => 'Qualsiasi browser',
'Your Language' => 'Italiano',
'Charset in MS Windows' => 'ISO-8859-1',
'Add Link to SiteBar' => 'Aggiungi collegamento a SiteBar',
'Add Page to SiteBar' => 'Aggiungi pagine a SiteBar',
'Error' => 'Errore',
'Warning' => 'Avvertimento',
'Unknown' => 'Sconosciuto',
'Search' => 'Trova',
'Highlight' => 'Trova evidenziando risultati',
'Collapse/Expand All' => 'Espandi/Riduci tutto',
'Reload' => 'Ricarica',
'Backup Log In' => 'Backup ingresso',
'Backup Log Out' => 'Backup uscita',
'Commander' => 'Commander',
'Add Folder' => 'Aggiungi cartella',
'Add Link' => 'Aggiungi link',
'Contact Admin' => 'Contatta Admin',
'Contact Moderator' => 'Contatta moderatore',
'Copy' => 'Copia',
'Copy Link' => 'Copia collegamento',
'Create Group' => 'Crea nuovo gruppo',
'Create Tree' => 'Crea nuovo albero',
'Create User' => 'Crea nuovo utente',
'Delete Folder' => 'Elimina cartella',
'Delete Group' => 'Elimina gruppo',
'Delete Link' => 'Elimina collegamento',
'Delete Account' => 'Elimina account',
'Delete User' => 'Elimina utente',
'Display Topic' => 'Mostra argomento',
'Email Link' => 'E-mail',
'Export Bookmarks' => 'Esporta Bookmarks',
'Export Description' => 'Esporta descrizione',
'Folder Properties' => 'Proprietà cartella',
'Group Members' => 'Membri del gruppo',
'Group Moderators' => 'Moderatori del gruppo',
'Group Properties' => 'Proprietà del gruppo',
'Help' => 'Aiuto',
'Import Bookmarks' => 'Importa Bookmarks',
'Import Description' => 'Importa descrizione',
'Log In' => 'Entra',
'Log Out' => 'Esci',
'Maintain Groups' => 'Preserva gruppi',
'Maintain Users' => 'Preserva utenti',
'Membership' => 'Membro di',
'Modify User' => 'Modifica utente',
'Paste' => 'Incolla',
'Properties' => 'Proprietà',
'Purge Folder' => 'Ripulisci cartella',
'Security' => 'Sicurezza',
'Send Email to Members' => 'Spedisci e-mail ai membri',
'Send Email to Moderators' => 'Spedisci e-mail al moderatore',
'Send Email to User' => 'Spedisci e-mail all&#39;utente',
'Send Email to All' => 'Spedisci e-mail a tutti',
'Set Up' => 'Sistema',
'Sign Up' => 'Registrati',
'SiteBar Settings' => 'Impostazioni SiteBar',
'Undelete' => 'Recupera eliminazione',
'User Settings' => 'Impostazioni utente',
'Verify Email' => 'Verifica e-mail',
'Verify Email Code' => 'Verifica codice e-mail',
'Admin Password' => 'Password dell&#39;amministratore',
'Allow Anonymous Contact' => 'Permetti contatti anonimi',
'Allow Contact' => 'Permetti contatti',
'Allow Given Membership' => 'Permetti aggiunta gruppo',
'Allow Info Mail' => 'Accetta Info Mail',
'Allow Noninteractive Mode' => 'Permetti modalità non interattiva',
'Allow Self Add' => 'Permetti aggiunta automatica',
'Allow Sign Up' => 'Permetti registrazione',
'Auto Join E-Mail RegExp' => 'Auto unione e-mail RegExp',
'Bookmark File' => 'File dei Bookmarks',
'Codepage' => 'Codepage',
'Comment' => 'Commento',
'Content Only' => 'Solo contenuto',
'Create New Sub Folder' => 'Crea nuova sottocartella',
'Decode Using' => 'Decodifica usando',
'Decorate ACL Folders' => 'Evidenzia cartelle ACL',
'Default Search In' => 'Ricerca predefinita',
'Default Skin' => 'Skin predefinito',
'Default Language' => 'Lingua predefinita',
'Delete Content Only' => 'Elimina solo il contenuto',
'Demo Account' => 'Account Demo',
'Description File' => 'Descrizione file',
'Description Import/Export' => 'Descrizione Importazione/Esportazione',
'Description' => 'Descrizione',
'E-mail Verified' => 'E-mail verificata',
'E-mail' => 'E-mail',
'Encode Using' => 'Codifica usando',
'Extern Commander' => 'Commander esterno',
'Favicon' => 'Favicon',
'Feedback or Other Comment' => 'Commenti o suggerimenti',
'File Type' => 'Tipo file',
'Folder Name' => 'Nome cartella',
'From' => 'Da',
'Group Name' => 'Nome gruppo',
'Help Topic' => 'Indice aiuti',
'Language' => 'Lingua',
'Link Description Length' => 'Lunghezza descrizione collegamento',
'Link Name' => 'Nome collegamento',
'Mode' => 'Modalità',
'Moderator' => 'Moderatore',
'New Tree Owner' => 'Nuovo proprietario dell&#39;albero',
'Old Password' => 'Vecchia password',
'Only to Verified Emails' => 'Solo per e-mail verificate',
'Owner' => 'Proprietario',
'Parent Folder' => 'Cartella padre',
'Password' => 'Password',
'Paste Mode' => 'Modalità di copia',
'Personal Mode' => 'Modalità personale',
'Private' => 'Privato',
'Publish Folder' => 'Pubblica cartella',
'Real Name' => 'Nome vero',
'Remember Me' => 'Ricordati di me',
'Remember as Default' => 'Ricordati sempre',
'Repeat Admin Password' => 'Ripetere password dell&#39;amministratore',
'Repeat Password' => 'Ripetere password',
'Select Group' => 'Seleziona gruppo',
'Select User' => 'Seleziona utente',
'Show Logo' => 'Mostra Logo',
'Show Menu Icon' => 'Mostra menu icone',
'Show Public Bookmarks' => 'Mostra collegamenti condivisi',
'Show Sponsor' => 'Mostra Sponsor',
'Skin' => 'Skin',
'Skip Execution Messages' => 'Messaggi di esecuzione',
'Source Folder Name' => 'Nome cartella di origine',
'Source Link Name' => 'Nome collegamento di origine',
'Target Folder Name' => 'Nome cartella di destinazione',
'To' => 'A',
'Topic' => 'Indice',
'Tree Name' => 'Nome albero',
'Tree Owner' => 'Proprietario albero',
'URL' => 'URL',
'Use Compression' => 'Comprimi',
'Use E-mail Features' => 'Usa caratteristiche dell&#39;e-mail',
'Use Favicons' => 'Usa Favicons',
'Users Can Create Trees' => 'L&#39;utente può  creare alberi',
'Your E-mail' => 'Tua e-mail',
'Until I close browser' => 'Fino alla chiusura del browser',
'12 hours' => '12 ore',
'6 days' => '6 giorni',
'1 month' => '1 mese',
'Anonymous Guest' => 'Utente anonimo',
'Guest' => 'Ospite',
'Message' => 'Messaggio',
'SiteBar Server' => 'SiteBare Server',
'%s - ok.' => '%s - ok.',
'%s - error!' => '%s - errore!',
'SiteBar: Contact Admin' => 'SiteBar: Contatta amministratore',
'SiteBar: Contact Group Moderator' => 'SiteBar: Contatta moderatore del gruppo',
'SiteBar: Email to all SiteBar Users' => 'SiteBar: Spedisci e-mail a tutti gli utenti di SiteBar',
'SiteBar: Email to Group Members' => 'SiteBar: Spedisci e-mail al moderatore del gruppo',
'SiteBar: Email to Group Moderators' => 'SiteBar: Spedisci e-mail ai moderatori dei gruppi',
'SiteBar: Email to SiteBar User' => 'SiteBar: Spedisci e-mail a un utente di SiteBar',
'SiteBar: Email Verification' => 'SiteBat: verifica e-mail',
'SiteBar: New SiteBar User' => 'SiteBar: Nuovo utente SiteBar',
'SiteBar: Web site' => 'SiteBar: sito web',
'Group' => 'Gruppo',
'R' => 'R',
'A' => 'A',
'M' => 'M',
'D' => 'D',
'P' => 'P',
'G' => 'G',
'Ask' => 'Chiedi',
'Move or Copy' => 'Copia o sposta',
'Copy (Keep Source)' => 'Copia (mantieni origine)',
'Move (Delete Source)' => 'Muovi (elimina origine)',
'Auto detection' => 'Riconoscimento automatico',
'Netscape/Mozilla/MS IE' => 'Netscape/Mozilla/MS IE',
'Opera Hotlist version 2.0' => 'Opera Hotlist versione 2.0',
'Admins' => 'Amministratori',
'Everyone' => 'Ognuno',
'%s&#39;s Bookmarks' => 'Bookmarks di %s',
'Deleted root %s of %s at %s' => 'Elimina root %s di %s a %s',
'All' => 'Tutto',
'Name' => 'Nome',
'Access denied!' => 'Accesso negato!',
'Cannot delete built in group!' => 'Impossibile eliminare gruppo integrato!',
'Cannot delete user because he is the only moderator of the following group(s): %s!' => 'Impossibile eliminare l&#39;utente, perché &#232; l&#39;unico moderatore del(i) gruppo(i): %s!',
'Cannot export empty description!' => 'Impossibile esportare descrizione vuota!',
'Cannot remove all moderators from a group!' => 'Impossibile rimuovere tutti i moderatori da un gruppo!',
'Cannot send email!' => 'Impossibile inviare e-mail!',
'Database corrupted - missing anonymous account!' => 'Database corrotto - manca utente anonimo!',
'Duplicate folder name "%s"!' => 'Copia nome cartella "%s"!',
'Duplicate folder name!' => 'Copia nome cartella!',
'Duplicate name "%s" in the target folder!' => 'Copia nome "%s" nella seguente cartella!',
'Duplicate name "%s"!' => 'Copia nome "%s"!',
'Expected field %s was not filled!' => 'Il campo %s non é stato compilato!',
'Field %s must be filled!' => 'Il campo %s deve essere compilato!',
'Folder has already been deleted!' => 'La cartella é già stata eliminata',
'Folder with id %s does not exist!' => 'La cartella con ID %s non esiste!',
'Group has already been deleted!' => 'Il gruppo é già stato eliminato!',
'Group name "%s" is already used!' => 'Il gruppo "%s" é già in uso!',
'Invalid code, verification disabled!' => 'Codice non valido, varifica disabilitata!',
'Invalid filename or other upload related problem: %s!' => 'Nome file non valido o problemi con l&#39;upload: %s!',
'Link already is in the target folder!' => 'Collegamento già esistente nella cartella!',
'Link has already been deleted!' => 'Il collegamento é già stato eliminato!',
'Missing command!' => 'Comando mancante!',
'No user was selected!' => 'Nessun utente é stato selezionato',
'Node number %s has ACL record but does not exist!' => 'Il nodo numero %s possiede record ACL ma non esiste!',
'Old password is invalid!' => 'Vecchia password non valida!',
'Purge folder to remove it permanently!' => 'Ripulire la cartella prima di rimuoverla!',
'The description length exceeds maximum length of %s bytes!' => 'La descrizione eccede di %s bytes!',
'The e-mail %s does not look correct!' => 'L&#39;e-mail %s non &#232; corretta! ',
'The password was not repeated correctly!' => 'La password non é stata inserita corretamente!',
'There is no content to be deleted!' => 'Non c&#39;é nessun contenuto da eliminare!',
'There is nothing to be undeleted!' => 'Non c&#39;é nulla da eliminare!',
'This email is already used. Did you forget your password?' => 'Questa e-mail é già in uso. Hai dimenticao la password?',
'Tree has already been deleted!' => 'L&#39;albero é già stato cancellato!',
'Unknown command!' => 'Comando sconosciuto!',
'Unknown username or wrong password!' => 'Utente sconosciuto o password errata!',
'Verification e-mail has been sent to your e-mail address!' => 'E-mail di verifica é stata spedita al tuo indirizzo e-mail!',
'You have been left as group moderator!' => 'Non sei piu moderatore del gruppo!',
'You are the last moderator of used group(s): %s. Account cannot be deleted!' => 'Sei l&#39;ultimo moderatore del(i) gruppo(i): %s. L&#39;account non pu&#242; essere eliminato!',
'%s, welcome to the SiteBar!<p>You have been already logged in.' => '%s, benvenuto in SiteBar!<p>You have been already logged in.',
'E-mail %s verified! Any pending memberships were approved.' => 'E-mail %s verificata! ',
'Link has been added.<p>You must reload your SiteBar in order to see added link!' => 'Il collegamento é stato aggiunto.<p>Ricaricare SiteBar per vedere le modifiche!',
'Imported %s link(s) into %s folder(s) from the bookmark file.' => 'Collegamenti %s importati nella cartella %s dal bookmark file.',
'Successful execution!' => 'Eseguito con successo!',
'Submit' => 'Accetta',
'Reset' => 'Annulla',
'Reload SiteBar' => 'Ricarica SiteBar',
'Close' => 'Chiudi',
'Return' => 'Home',
'Backup Return to SiteBar' => 'Backup e ritorna a SiteBar',
'Cannot open file!' => 'Impossibile aprire il file!',
'Unknown bookmark file format!' => 'Formato file sconosciuto!',
'File is empty!' => 'Il file é vuoto!',
'Character set overriden from document to %s!' => 'Il set di caratteri e prioritario dal documento a %s',
'Powered by %s ver. %s' => 'Powered by %s ver. %s',
'Skin created by' => 'Skin creato da',
'Skin designed by' => 'Skin disegnato da',
'Folder found' => 'Cartella trovata',
'Link found' => 'Collegamento trovato',
'Desc' => 'Descrizione',
'Find next?' => 'Trova succesivo?',
);

?>
