<?php

$para = array();

$para['index::tip'] = <<<_P
Använd den här sidan för att installera SiteBar bokmärkesserver till din
webbläsare. Du rekommenderas lägga till en av länkarna markerade med "*"
i stället för att lägga till denna sida bland dina bokmärken. Denna sida kan
öppnas från SiteBarfönstret genom att klicka på logotypen.
_P;

$para['index::any_browser'] = <<<_P
Använd <a title="SiteBar" href="%s/sitebar.php">SiteBar</a>* i detta
fönster - eller öppna det i ett
<a title="SiteBar" href="javascript:void(window.open('%s/sitebar.php?target=_blank','_sb_pop_up','directories=no, height=600, width=220, left=0, top=0, scrollbars=yes, location=no, menubar=no, status=no, toolbar=no'))">
SiteBar</a>liknande* popupfönster.
_P;

$para['index::ie_install'] = <<<_P
<a href="?install=1">Installera</a> / <a href="?install=0">Avinstallera</a>
till/från Explorerfältet och kontextmenyn - detta kräver ändring i
Windows registry och omstart av Windows för alla egenskaper. Beroende på
dina rättigheter kan olika många egenskaper installeras.
<p class='comment'>Öppna SiteBar Explorerfältet från menyn
Visa/Explorerfält eller använd funktionen <b>Anpassa...</b> verktygsfält (högerklick på verktygsfältet) för att visa ikonen för SiteBarpanelen i verktygsfältet. Högerklicka var som helst på sidan eller på en länk för att lägga till en sida eller länk till SiteBar.
</p>
_P;

$para['index::ie_search'] = <<<_P
Lägg till <a title="SiteBar" href="javascript:void(_search=open('%s/sitebar.php','_search'))">
SiteBar</a>* temporärt till sökfältet i Internet Explorer.
<p class='comment'>Använd denna när du inte har tillräckligt med rättigheter
för att använda installeraren ovan.</p>
_P;

$para['index::mozilla'] = <<<_P
Addera till en Mozilla/Netscape-kompatibel
<a title="SiteBar"
href="javascript:sidebar.addPanel('SiteBar','%s/sitebar.php','')">
sidebar</a> - Växla visning med F9.
<p class='comment'>Mozilla Firefox-användare bör använda länken ovan för
att skapa ett bokmärke som öppnar i en sidebar när man klickar på den. <a href="http://forums.mozillazine.org/viewtopic.php?t=36166">Mozillazine</a> beskriver hur man använder <a href="http://www.sitebar.org/plugin/firefox/SiteBar.xpi?url=%s">SiteBar sidebartillägg</a> och <a href="http://www.sitebar.org/plugin/firefox/WebLinks_for_SiteBar.xpi?url=%s">WebLinks menytillägg</a> med SiteBar.
</p>
_P;

$para['index::opera'] = <<<_P
Lägg till Operas <a title="SiteBar" rel="sidebar" href="%s/sitebar.php">Hotlist</a>
som Sidebar.
<p class='comment'>Använd Ctrl+klick i stället för Höger+klick för att visa
mapp- eller kontextmeny.</p>
_P;

$para['index::myie2_install'] = <<<_P
Ladda ner en skräddarsydd <a href="http://www.sitebar.org/plugin/myie2/?sidebar=%s">sidebar</a>
och/eller verktygspluginet "<a href="http://www.sitebar.org/plugin/myie2/?toolbar=%s">Lägg Till Aktuell Flik till SiteBar</a>".
_P;

$para['index::bookmarklet'] = <<<_P
<a href="javascript:%s">Lägg till sida till SiteBar</a>* - Högerklicka på
denna länk och lägg till dina favoriter/bokmärken. Det kommer tillåta dig
att senare lägga till en länk till den sida som för närvarande visas i webbläsaren till SiteBar. När du är på en sida som du vill lägga till i SiteBar är det bara att klicka på denna länk i favoriter. Microsoft Internet Explorer 5+ användare kan med fördel använda den ovanstående installationen till Explorerfältet och kontextmenyn i stället.
_P;

$para['index::copyright2'] = <<<_P
Copyright � 2003,2004 <a href='http://brablc.com/'>Ondřej Brablc</a>
och <a href='http://www.sitebar.org/team.php'>SiteBar Team</a>.
<a href='http://sourceforge.net/forum/forum.php?forum_id=261003'>Supportforum</a>.
_P;

$para['command::contact'] = <<<_P
Meddelande:

%s


--
SiteBarinstallation på %s.
_P;

$para['command::contact_group'] = <<<_P
Grupp: %s
Meddelande:

%s


--
SiteBarinstallation på %s.
_P;

$para['command::delete_account'] = <<<_P
<h3>Vill du verkligen ta bort ditt konto?</h3>
Det finns inget sätt att ångra sig!<p>
Alla dina kvarvarande träd kommer att överlåtas till systemadministratören.
_P;

$para['command::email_link_href'] = <<<_P
<p>Sänd epost via ditt <a href='mailto:?subject=Webbsida: %s&amp;body=Jag har hittat en webbsida som jag
tror du kan vara intresserad av.
 Kolla in: %s
 --
 Skickat via %s driven av bomärkesservern SiteBar (http://www.sitebar.org/)
'>standardepostprogram</a>
_P;

$para['command::email_link'] = <<<_P
Jag har hittat en hemsida du kan vara intresserad av.
Kolla in denna:

    "%s" %s

%s

--
Skickat via %s driven av bomärkesservern SiteBar (http://www.sitebar.org/)
_P;

$para['command::verify_email'] = <<<_P
Du har begärt epostverifiering. Var god klicka på följande länk för att verifiera din epostadress:
%s
_P;

$para['command::import_bk'] = <<<_P
<br>
Dina lokala favoriter kan exporteras till en lokal fil genom att <a href='javascript:window.external.ImportExportFavorites(false,"")'>klicka här</a>.
_P;

$para['command::export_bk'] = <<<_P
<br>
Exporterade bokmärken kan importeras till lokala favoriter genom att <a href='javascript:window.external.ImportExportFavorites(true,"")'>klicka här</a>.
_P;

$para['command::noiconv'] = <<<_P
<br>
Codepagekonvertering är inte installerat på denna SiteBar-server.
<br>
_P;

$para['command::security_legend'] = <<<_P
Rättigheter:
<strong>L</strong>äs,
<strong>A</strong>ddera,
<strong>M</strong>odifiera,
<strong>T</strong>a Bort,
<strong>R</strong>ensa,
<strong>B</strong>evilja
_P;

$para['command::purge_cache'] = <<<_P
<h3>Vill du verkligen ta bort alla faviconer från cachen?</h3>
_P;

$para['usermanager::auto_verify_email'] = <<<_P
Din epostadress matchar regler för automatiskt deltagande i följande stängda
grupp(er):
    %s.

För att godkänna ditt medlemsskap måste din epostadress verifieras. Var god
klicka på följande länk för att verifiera den:
    %s
_P;

$para['usermanager::signup_info'] = <<<_P
Användare "%s" <%s> registrerade nyligen sig
på din SiteBarinstallation vid %s.
_P;

$para['hook::statistics'] = <<<_P
Rötter {roots_total}.
Mappar {nodes_shown}/{nodes_total}.
Länkar {links_shown}/{links_total}. Användare {users}. Grupper {groups}. SQL-förfrågningar {queries}. Databas/Total tid {time_db}/{time_total} sekunder ({time_pct}%).

_P;

?>
