<?php

$text = array
(
'The Bookmark Server for Personal and Team Use' => '"Suosikit" -palvelin yksityiseen ja ryhmäkäyttöön',
'SiteBar Homepage' => 'SiteBar ohjelman kotisivu',
'SiteBar Installation & Launcher' => 'SiteBar asennus / käynnistys',
'Any Browser' => 'Kaikki selaimet',
'Bookmarklet' => 'Bookmarklet',
'Your Language' => 'Suomi',
'Charset in MS Windows' => 'ISO-8859-1',
'Add Link to SiteBar' => 'Lisää linkki SiteBar:iin',
'Add Page to SiteBar' => 'Lisää sivu SiteBar:iin',
'Error' => 'Virhe',
'Warning' => 'Varoitus',
'Unknown' => 'Tuntematon',
'Search' => 'Etsi',
'Highlight' => 'Korostus',
'Collapse/Expand All' => 'Näytä/piilota kaikki',
'Reload' => 'Virkistä',
'Reload with Hidden Folders' => 'Virkistä myös piilotetut',
'Add Folder' => 'Lisää kansio',
'Add Link' => 'Lisää linkki',
'Contact Admin' => 'Viesti ylläpitäjälle',
'Contact Moderator' => 'Viesti moderaattorille',
'Copy' => 'Kopioi',
'Copy Link' => 'Kopioi linkki',
'Create Group' => 'Luo ryhmä',
'Create Tree' => 'Luo puurakenne',
'Create User' => 'Luo käyttäjä',
'Custom Order' => 'Muokattu järjestys',
'Delete Folder' => 'Poista kansio',
'Delete Group' => 'Poista ryhmä',
'Delete Link' => 'Poista linkki',
'Delete Account' => 'Poista tunnus',
'Delete User' => 'Poista käyttäjä',
'Delete Tree' => 'Poista puurakenne',
'Display Topic' => 'Näytä otsikko',
'Email Link' => 'Lähetä linkki...',
'Export Bookmarks' => 'Vie suosikit...',
'Export Description' => 'Vie kuvaus',
'Favicon Management' => 'Favicon:n hallinta',
'Folder Properties' => 'Kansion asetukset',
'Group Members' => 'Ryhmien jäsenyydet',
'Group Moderators' => 'Ryhmien moderaattorit',
'Group Properties' => 'Ryhmän asetukset',
'Help' => 'Apua!',
'Hide Folder' => 'Piilota kansio',
'Import Bookmarks' => 'Tuo suosikit...',
'Import Description' => 'Tuo kuvaus',
'Log In' => 'Kirjaudu sisään',
'Log Out' => 'Kirjaudu ulos',
'Maintain Groups' => 'Muokkaa ryhmiä',
'Maintain Users' => 'Muokkaa käyttäjiä',
'Maintain Trees' => 'Muokkaa puurakennetta',
'Membership' => 'Jäsenyys ryhmissä',
'Modify User' => 'Muokkaa käyttäjää',
'Order of Trees' => 'Puurakenteen järjestys',
'Paste' => 'Liitä',
'Properties' => 'Ominaisuudet...',
'Purge Cache' => 'Siivoa/tyhjennä välimuisti',
'Purge Folder' => 'Siivoa/tyhjennä kansio',
'Retrieve Link Information' => 'Hae linkin tiedot palvelimelta',
'Security' => 'Käyttöoikeudet',
'Send Email to Members' => 'Lähetä s-postia jäsenille',
'Send Email to Moderators' => 'Lähetä s-postia moderaattoreille',
'Send Email to User' => 'Lähetä postia käyttäjälle',
'Send Email to All' => 'Lähetä postia kaikille',
'Show All Icons' => 'Näytä kaikki ikonit',
'Set Up' => 'Asennus',
'Sign Up' => 'Luo tunnus',
'SiteBar Settings' => 'Asetukset',
'Undelete' => 'Peruuta poisto',
'Unhide Trees' => 'Näytä hierarkia',
'Unhide Subfolders' => 'Näytä alikansiot',
'User Settings' => 'Omat asetukset',
'Personal Data' => 'Henkilökohtaiset tiedot',
'Validate Links' => 'Tarkista linkit',
'Validation' => 'Tarkistus',
'Verify Email' => 'Vahvista sähköposti',
'Verify Email Code' => 'Verifioi sähkpostiosoiteen muoto',
'Admin Password' => 'Pääkäyttäjän salasana',
'Allow Anonymous Contact' => 'Hyväksy anonyymitunnukset',
'Allow Contact' => 'Salli kontaktit',
'Allow Given Membership' => 'Hyväksy annettu ryhmä',
'Allow Info Mail' => 'Saa lähettää info -postia',
'Allow Self Add' => 'Salli käyttäjän lisätä',
'Allow Sign Up' => 'Salli käyttäjtunnusten luominen',
'Auto Retrieve Favicon' => 'Tuo automaattisesti "favicon"',
'Bookmark File' => 'Bookmarktiedosto',
'Cached: ' => 'Välimuistissa:',
'Codepage' => 'Koodisivu',
'Comment' => 'Kommentti',
'Content Only' => 'Vain sisältö',
'Create New Sub Folder' => 'Luo uusi alikansio',
'Dead Link' => 'Toimimaton linkki',
'Decode Using' => 'Korista käyttäen',
'Decorate ACL Folders' => 'Koristele ACL -kansiot',
'Default Language' => 'Oletuskieli',
'Default Search In' => 'Oletus etsintäpaikka',
'Default Skin' => 'Oletustyyli',
'Delete Content Only' => 'Poista vain sisältö',
'Delete Invalid Favicons' => 'Poista puutteelliset faviconit',
'Demo Account' => 'Demotunnus',
'Description' => 'Kuvaus',
'Description File' => 'Kuvaustiedosto',
'Description Import/Export' => 'Tuo/vie kuvaus',
'Discover Missing Favicons' => 'Etsi puuttuvat faviconit',
'E-mail' => 'Sähköposti',
'E-mail Verified' => 'Sähköposti tarkistettu',
'Encode Using' => 'Käytä enkoodausta',
'Extern Commander' => 'Ulkoinen "Commander"',
'Favicon' => 'Favicon',
'Feedback or Other Comment' => 'Palaute tai muu kommentti',
'File Type' => 'Tiedostotyyppi',
'Folder Name' => 'Kansion nimi',
'From' => 'From',
'Group Name' => 'Ryhmän nimi',
'Help Topic' => 'Ohjeet (Suomennos kesken)',
'Ignore Recently Tested' => 'Ohita juuri testatut',
'Include Subfolders' => 'Alikansiot mukaan',
'Keep In Cache' => 'Pidä välimuistissa',
'Language' => 'Kieli',
'Link Description Length' => 'Linkin kuvauksen pituus',
'Link Name' => 'Linkin nimi',
'Maximal Icon Age' => 'Iconin maximi-ikä',
'Maximal Icon Size' => 'Iconin maksimikoko',
'Maximal Icons per User' => 'Max. iconia per käyttäjä',
'Maximal Icons Total' => 'Max. iconia kaikkiaan',
'Mode' => 'Moodi',
'Moderator' => 'Moderaattori',
'New Tree Owner' => 'Uusi puurakenteen omistaja',
'Old Password' => 'Vanha salasana',
'Only to Verified Emails' => 'Vain tarkistettuihin osoitteisiin',
'Original: ' => 'Alkuperäinen:',
'Owner' => 'Omistaja',
'Parent Folder' => 'Yläkansio',
'Password' => 'Salasana',
'Paste Mode' => '"Liittää" -toiminto',
'Personal Mode' => 'Henkilökohtainen moodi',
'Private' => 'Yksityinen',
'Publish Folder' => 'Julkinen kansio',
'Real Name' => 'Oikea nimi',
'Remember as Default' => 'Muista oletuksena',
'Remember Me' => 'Muista minut',
'Rename Duplicate Links' => 'Uudelleen nimeä kaksoiskappaleet linkeistä',
'Repeat Admin Password' => 'Anna admin -salasana uudelleen',
'Repeat Password' => 'Toista salasana',
'Respect Allow Info Mail' => 'Kunnioita infopostin asetusta.',
'Select Group' => 'Valitse ryhmä',
'Select User' => 'Valitse käyttäjä',
'Sender E-mail' => 'Lähettäjän sähköposti',
'Show Logo' => 'Näytä logo',
'Show Menu Icon' => 'Näytä menu-iconi',
'Show Public Bookmarks' => 'Näytä julkiset bookmarkit',
'Show Sponsor' => 'Näytä sponsorin mainos',
'Skin' => 'Tyyli',
'Skip Execution Messages' => 'Ohita "suorita" -viestit',
'Source Folder Name' => 'Lähdekansio',
'Source Link Name' => 'Lähdelinkki',
'Target Folder Name' => 'Kohdekansio',
'To' => 'To',
'Topic' => 'Otsikko/aihe',
'Tree Name' => 'Puurakenteen nimi',
'Tree Owner' => 'Puurakenteen omistaja',
'URL' => 'URL',
'Use Compression' => 'Käytä pakkausta',
'Use Conversion Engine' => 'Käytä konversiota',
'Use E-mail Features' => 'Käytä sähköpostiominaisuuksia',
'Use Favicons' => 'Käytä suosikki-ikoneita',
'Use Folder Hiding' => 'Käytä kansioiden piilotusta',
'Use Hit Counter' => 'Ota käyttölaskuri käyttöön',
'Use the Favicon Cache' => 'Käytä suosikki-ikoni välimuistia',
'Users Can Create Trees' => 'Käyttäjä voi luoda puurakenteita',
'Your E-mail' => 'Sähköpostisi',
'Until I close browser' => 'Istunnon ajan',
'12 hours' => '12 tuntia',
'6 days' => '6 päivää',
'1 month' => '1 kuukausi',
'No caching' => 'älä salli välimuistia',
'Order of Folders v. Links' => 'Lajittelu',
'Links first' => 'Linkit ensin',
'Folders first' => 'Kansiot ensin',
'Default Link Sort Mode' => 'Oletusjärjestys',
'Sort Mode' => 'Järjestystapa',
'User default' => 'Käyttäjän oletus',
'Custom order' => 'Muokattu järjestys',
'Alphabetically' => 'Aakkostettu',
'Most clicked first' => 'Eniten käytetyt ylimpänä',
'New/changed links first' => 'Viimeksi muokatut ylimpänä',
'Waiting for visit' => 'Odottaa käyntiä',
'Anonymous Guest' => 'Nimetön vieras',
'Guest' => 'Vieras',
'Message' => 'Viesti',
'SiteBar Server' => 'SiteBar palvelin',
'%s - ok.' => '%s - ok',
'%s - error!' => '%s - virhe',
'SiteBar: Contact Admin' => 'Viestien aiheet',
'SiteBar: Contact Group Moderator' => 'SiteBar: ota yhteyttä moderaattoriin',
'SiteBar: Email to all SiteBar Users' => 'SiteBar: Sähköpostia käyttäjille',
'SiteBar: Email to Group Members' => 'SiteBar: Sähköpostia ryhmän jäsenille',
'SiteBar: Email to Group Moderators' => 'SiteBar: Sähköpostia ryhmän moderaattoreille',
'SiteBar: Email to SiteBar User' => 'siteBar: Sähköpostia SiteBar -käyttäjälle',
'SiteBar: Email Verification' => 'SiteBar: Sähköpostin vahvistus',
'SiteBar: New SiteBar User' => 'SiteBar: Uusi käyttäjä',
'SiteBar: Web site' => 'SiteBar: Web -sivusto',
'Group' => 'Ryhmä',
'R' => 'R',
'A' => 'A',
'M' => 'M',
'D' => 'D',
'P' => 'P',
'G' => 'G',
'Ask' => 'Liitä -toiminto',
'Move or Copy' => 'Siirrä tai kopioi',
'Copy (Keep Source)' => 'Kopioi (pidä alkuperäinen)',
'Move (Delete Source)' => 'Siirrä (poista alkuperäinen)',
'Auto detection' => 'Automaattinen tunnistus',
'Netscape/Mozilla/MS IE' => 'Netscape/Mozilla/MS IE',
'Netscape/Mozilla' => 'Netscape/Mozilla',
'MS Internet Explorer' => 'MS Internet Explorer',
'Opera Hotlist version 2.0' => 'Opera Hotlist version 2.0',
'Admins' => 'Admin -tunnukset',
'Everyone' => 'Kaikki',
'%s&#39;s Bookmarks' => '%s&#39;s Bookmarkit',
'Name' => 'Nimi',
'Access denied!' => 'Virheilmoitukset',
'Cannot delete built in group!' => 'Järjestelmän sisäistä ryhmää ei voi poistaa',
'Cannot delete user because he is the only moderator of the following group(s): %s!' => 'Käyttäjää ei voida poistaa. Hän on viimeinen moderaattori %s :ssä',
'Cannot export empty description!' => 'Ei voi viedä tyhjää kuvausta',
'Cannot remove all moderators from a group!' => 'Kaikkia moderaattoreita ei voi poistaa ryhmältä',
'Cannot send email!' => 'Sähköpostia ei voi lähettää',
'Connection timed out!' => 'Yhteys on katkaistu liian pitkän viiveen johdosta.',
'Database corrupted - missing anonymous account!' => 'Tietokanta on viallinen. Anonyymitunnus puuttuu.',
'Duplicate folder name "%s"!' => 'Duplikaatti "%s" kansionimi',
'Duplicate folder name!' => 'Kansionimi on jo olemassa',
'Duplicate name "%s" in the target folder!' => 'Sama nimi "%s" on jo kohdekansiossa',
'Duplicate name "%s"!' => 'Duplikaatti nimi "%s"',
'Expected field %s was not filled!' => 'Kenttää %s ei ole täytetty.',
'Favicon <img src="%s"> found at url %s.' => 'Favicon <img src="%s"> löytyi osoitteesta %s.',
'Favicon not found!' => 'Suosikki-ikonia ei löytynyt',
'Field %s must be filled!' => 'Kenttä on täytettävä',
'Folder has already been deleted!' => 'Kansio on jo poistettu',
'Folder with id %s does not exist!' => 'Annettua kansiota id:llä %s ei ole olemassa',
'Group has already been deleted!' => 'Ryhmä on jo poistettu',
'Group name "%s" is already used!' => 'Ryhmänimi on jo käytössä',
'Head of the HTML page was not found!' => 'HTML -sivun "head" -osiota ei löytynyt!',
'Incomplete HTTP response!' => 'HTTP -vastaus oli epätäydellinen.',
'Invalid code, verification disabled!' => 'Koodi on virheellinen. Vahvistus on estetty',
'Invalid regular expresssion!' => 'Regexp. on väärin',
'Invalid filename or other upload related problem: %s!' => 'Tiedostonimi on virheellinen tai muu tiedostonsiirtoon liittyvä ongelma.',
'Link already is in the target folder!' => 'Kohdekansiossa on jo sama linkki',
'Link has already been deleted!' => 'Linkki on jo poistettu',
'Missing command!' => 'Komento puuttuu',
'No links in the folder!' => 'Ei linkkejä tässä kansiossa',
'No user was selected!' => 'Yhtään käyttäjää ei ole valittuna',
'Old password is invalid!' => 'Vanha salasana on väärin',
'Purge folder to remove it permanently!' => 'Siivoa/tyhjennä kansio poistaaksesi se lopullisesti',
'The description length exceeds maximum length of %s bytes!' => 'E-mail osoite ei taida olla oikein. Se on aivan liian pitkä: %s tavua',
'The e-mail %s does not look correct!' => 'Antamasi sähköposti nättäisi olevan väärä.',
'The password was not repeated correctly!' => 'Et antanut salasanaa kahdesti samalla tavalla.',
'There is no content to be deleted!' => 'Ei ole mitään poistettavaa',
'There is nothing to be undeleted!' => 'Ei ole poistoja peruttavaksi',
'This email is already used. Did you forget your password?' => 'Tämä sähköpostiosoite on jo käytössä. Unohditko salasanasi?',
'Tree has already been deleted!' => 'Puurakenne on jo poistettu!',
'Use "%s" command to delete own account!' => 'Käytä komentoa %s poistaaksesi oma tunnuksesi',
'Unknown command!' => 'Tuntematon komento',
'Unknown username or wrong password!' => 'Tuntematon tunnus tai salasana väärin',
'Verification e-mail has been sent to your e-mail address!' => 'Tarkistusviesti on lähetetty antamaasi s-postiosoitteeseen.',
'Wrong favicon type/format "%s"!' => 'Väärä favicon tyyppi/formaatti "%s"!',
'You have been left as group moderator!' => 'You have been left as group moderator!',
'You are the last moderator of used group(s): %s. Account cannot be deleted!' => 'olet viimeinen ryhmän %s moderaattori. Tunnusta ei voida poistaa',
'%s, welcome to the SiteBar!<p>You have been already logged in.' => '%s, tervetuloa SiteBar -sivustoon.<p>Sinä olet jo kirjautunut sisään!',
'E-mail %s verified! Any pending memberships were approved.' => 'Sähköpostiosoite on tarkistettu. Jäsenyydet on hyväksytty',
'Link has been added.<p>You must reload your SiteBar in order to see added link!' => 'Linkki on lisätty. Virkistä SiteBar, että näet linkin.',
'Imported %s link(s) into %s folder(s) from the bookmark file.' => 'Tuotiin %s linkki(ä) yhteensä %s kansioon bookmark -tiedostosta.',
'Successful execution!' => 'Suoritus onnistui',
'Submit' => 'OK',
'Reset' => 'Peru',
'Reload SiteBar' => 'Virkistä',
'Close' => 'Sulje',
'Return' => 'Takaisin',
'Unknown bookmark file format!' => 'Tuntematon bookmark -tiedostoformaatti',
'File is empty!' => 'Tiedosto on tyhjä',
'Character set overriden from document to %s!' => 'Dokumentin merkistö on jätetty huomitta. Nyt se on %s',
'There is no conversion engine available to convert from %s character set!' => 'Merkistöä %s ei voida muuntaa. Muunnostaulu puuttuu!',
'Powered by %s ver. %s' => 'Tyylit',
'Skin created by' => 'Tyylin on luonut',
'Skin designed by' => 'Tyylin ulkoasun on luonut',
'Folder found' => 'Kansio löytyi',
'Link found' => 'Linkki löytyi',
'Desc' => 'Kuvaus',
'Find next?' => 'Etsitäänkö seuraava?',
);

?>
