<?php
$text = array
(
    'The Bookmark Server for Personal and Team Use' => 'Index window',
    'SiteBar Homepage' => '',
    'SiteBar Installation & Launcher'=> '',
    'Any Browser' => '',
    'Content Bookmarklets' => '',
    'Bookmarklet' => '',

    'Your Language' => 'Do not translate, just write the name of your language in your own language',
    'Charset in MS Windows' => 'Do not translate, just put value like "ISO-8859-1"!',
    'Add Link to SiteBar' => '',
    'Add Page to SiteBar' => '',

    'Error' => 'Error states',
    'Warning' => '',
    'Unknown' => '',

    'Search' => 'SiteBar window',
    'Highlight' => '',
    'Collapse/Expand All' => '',
    'Reload' => '',
    'Reload with Hidden Folders' => '',
    'Backup Log In' => '',
    'Backup Log Out' => '',

    'Commander' => 'Commands',
    'Add Folder' => '',
    'Add Link' => '',
    'Contact Admin' => '',
    'Contact Moderator' => '',
    'Copy' => '',
    'Copy Link' => '',
    'Create Group' => '',
    'Create Tree' => '',
    'Create User' => '',
    'Custom Order' => '',
    'Delete Folder' => '',
    'Delete Group' => '',
    'Delete Link' => '',
    'Delete Account' => '',
    'Delete User' => '',
    'Delete Tree' => '',
    'Display Topic' => '',
    'Email Link' => '',
    'Export Bookmarks' => '',
    'Export Description' => '',
    'Favicon Management' => '',
    'Folder Properties' => '',
    'Group Members' => '',
    'Group Moderators' => '',
    'Group Properties' => '',
    'Help' => '',
    'Hide Folder' => '',
    'Import Bookmarks' => '',
    'Import Description' => '',
    'Log In' => '',
    'Log Out' => '',
    'Maintain Groups' => '',
    'Maintain Users' => '',
    'Maintain Trees' => '',
    'Membership' => '',
    'Modify User' => '',
    'Order of Trees' => '',
    'Paste' => '',
    'Properties' => '',
    'Purge Cache' => '',
    'Purge Folder' => '',
    'Retrieve Link Information' => '',
    'Security' => '',
    'Send Email to Members' => '',
    'Send Email to Moderators' => '',
    'Send Email to User' => '',
    'Send Email to All' => '',
    'Show All Icons' => '',
    'Set Up' => '',
    'Sign Up' => '',
    'SiteBar Settings' => '',
    'Undelete' => '',
    'Unhide Trees' => '',
    'Unhide Subfolders' => '',
    'User Settings' => '',
    'Personal Data' => '',
    'Validate Links' => '',
    'Validation' => '',
    'Verify Email' => '',
    'Verify Email Code' => '',

    'Admin Password' => 'Command window - form fields',
    'Allow Anonymous Contact' => '',
    'Allow Contact' => '',
    'Allow Given Membership' => '',
    'Allow Info Mail' => '',
    'Allow Noninteractive Mode' => '',
    'Allow Self Add' => '',
    'Allow Sign Up' => '',
    'Auto Join E-Mail RegExp' => '',
    'Auto Retrieve Favicon' => '',
    'Bookmark File' => '',
    'Cached: ' => '',
    'Codepage' => '',
    'Comment' => '',
    'Content Only' => '',
    'Create Group' => '',
    'Create New Sub Folder' => '',
    'Create User' => '',
    'Dead Link' => '',
    'Decode Using' => '',
    'Decorate ACL Folders' => '',
    'Default Language' => '',
    'Default Search In' => '',
    'Default Skin' => '',
    'Delete Content Only' => '',
    'Delete Group' => '',
    'Delete Invalid Favicons' => '',
    'Delete User' => '',
    'Demo Account' => '',
    'Description' => '',
    'Description File' => '',
    'Description Import/Export' => '',
    'Discover Missing Favicons' => '',
    'Display Topic' => '',
    'E-mail' => '',
    'E-mail Verified' => '',
    'Encode Using' => '',
    'Exclude From Validation' => '',
    'Export Description' => '',
    'Extern Commander' => '',
    'Favicon' => '',
    'Feedback or Other Comment' => '',
    'File Type' => '',
    'Folder Name' => '',
    'From' => '',
    'Group Members' => '',
    'Group Moderators' => '',
    'Group Name' => '',
    'Group Properties' => '',
    'Help Topic' => '',
    'Ignore Recently Tested' => '',
    'Import Description' => '',
    'Include Subfolders' => '',
    'Keep In Cache' => '',
    'Language' => '',
    'Link Description Length' => '',
    'Link Name' => '',
    'Maximal Icon Age' => '',
    'Maximal Icon Size' => '',
    'Maximal Icons per User' => '',
    'Maximal Icons Total' => '',
    'Mode' => '',
    'Moderator' => '',
    'Modify User' => '',
    'New Tree Owner' => '',
    'Old Password' => '',
    'Only to Verified Emails' => '',
    'Original: ' => '',
    'Owner' => '',
    'Parent Folder' => '',
    'Password' => '',
    'Paste Mode' => '',
    'Personal Mode' => '',
    'Private' => '',
    'Publish Folder' => '',
    'Real Name' => '',
    'Recent Time Expressed in Seconds' => '',
    'Remember as Default' => '',
    'Remember Me' => '',
    'Rename Duplicate Links' => '',
    'Repeat Admin Password' => '',
    'Repeat Password' => '',
    'Respect Allow Info Mail' => '',
    'Select Group' => '',
    'Select User' => '',
    'Select Tree' => '',
    'Sender E-mail' => '',
    'Show Logo' => '',
    'Show Menu Icon' => '',
    'Show Public Bookmarks' => '',
    'Show Sponsor' => '',
    'Show Statistics' => '',
    'Skin' => '',
    'Skip Execution Messages' => '',
    'Source Folder Name' => '',
    'Source Link Name' => '',
    'Target Folder Name' => '',
    'To' => '',
    'Topic' => '',
    'Tree Name' => '',
    'Tree Owner' => '',
    'URL' => '',
    'Use Compression' => '',
    'Use Conversion Engine' => '',
    'Use E-mail Features' => '',
    'Use Favicons' => '',
    'Use Folder Hiding' => '',
    'Use Hit Counter' => '',
    'Use Outbound Connection' => '',
    'Use the Favicon Cache' => '',
    'Users Can Create Trees' => '',
    'Users Can Delete Trees' => '',
    'Your E-mail' => '',

    'Until I close browser' => 'Session expiration time',
    '12 hours' => '',
    '6 days' => '',
    '1 month' => '',
    'No caching' => '',

    'Order of Folders v. Links' => 'What comes first?',
    'Links first' => '',
    'Folders first' => '',

    'Default Link Sort Mode' => '',
    'Sort Mode' => '',
    'User default' => '',
    'Custom order' => '',
    'Alphabetically' => '',
    'Most clicked first' => '',
    'New/changed links first' => '',
    'Waiting for visit' => '',

    'Anonymous Guest' => 'Mailing',
    'Guest' => '',
    'Message' => '',
    'SiteBar Server'=>'',
    '%s - ok.' => '',
    '%s - error!' => '',


    'SiteBar: Contact Admin' => 'Mail subjects',
    'SiteBar: Contact Group Moderator' => '',
    'SiteBar: Email to all SiteBar Users' => '',
    'SiteBar: Email to Group Members' => '',
    'SiteBar: Email to Group Moderators' => '',
    'SiteBar: Email to SiteBar User' => '',
    'SiteBar: Email Verification' => '',
    'SiteBar: New SiteBar User' => '',
    'SiteBar: Web site' => '',

    'Group' => 'Security, the letters should be unique',
    'R' => 'Read shortcut letter',
    'A' => 'Add shortcut letter',
    'M' => 'Modify shortcut letter',
    'D' => 'Delete shortcut letter',
    'P' => 'Purge shortcut letter',
    'G' => 'Grant shortcut letter',

    'Ask' => 'Paste mode',
    'Copy' => '',
    'Move or Copy' => '',
    'Copy (Keep Source)' => '',
    'Move (Delete Source)' => '',

    'Auto detection' => 'Bookmark file formats',
    'Netscape/Mozilla/MS IE' => '',
    'Netscape/Mozilla' => '',
    'MS Internet Explorer' => '',
    'Opera Hotlist version 2.0' => '',

    'Admins' => 'Various',
    'Everyone' => '',
    '%s&#39;s Bookmarks' => '',
    'Deleted root %s of %s at %s' => '',

    'All' => '"Search in" default prefixes',
    'Name' => '',

    'Access denied!' => 'Error messages',
    'All links recently validated!' => '',
    'Cannot connect to http://%s:%s!' => '',
    'Cannot delete built in group!' => '',
    'Cannot delete user because he is the only moderator of the following group(s): %s!' => '',
    'Cannot download %s using https, will try http!' => '',
    'Cannot export empty description!' => '',
    'Cannot handle %s protocol!' => '',
    'Cannot move folder to its subfolder!' => '',
    'Cannot remove all moderators from a group!' => '',
    'Cannot send email!' => '',
    'Connection timed out!' => '',
    'Database corrupted - missing anonymous account!' => '',
    'Duplicate folder name "%s"!' => '',
    'Duplicate folder name!' => '',
    'Duplicate name "%s" in the target folder!' => '',
    'Duplicate name "%s"!' => '',
    'Expected field %s was not filled!' => '',
    'Favicon <img src="%s"> found at url %s.' => '',
    'Favicon not found!' => '',
    'Field %s must be filled!' => '',
    'Folder has already been deleted!' => '',
    'Folder with id %s does not exist!' => '',
    'Group has already been deleted!' => '',
    'Group name "%s" is already used!' => '',
    'Head of the HTML page was not found!' => '',
    'HEAD unsupported, trying GET!' => '',
    'Host or port undefined!' => '',
    'Icon size %s exceeds maximal size %s!' => '',
    'Incomplete HTTP response!' => '',
    'Invalid code, verification disabled!' => '',
    'Invalid regular expresssion!' => '',
    'Invalid filename or other upload related problem: %s!' => '',
    'Link already is in the target folder!' => '',
    'Link has already been deleted!' => '',
    'Missing command!' => '',
    'No links in the folder!' => '',
    'No more than %s redirections allowed!' => '',
    'No user was selected!' => '',
    'Node number %s has ACL record but does not exist!' => '',
    'Old password is invalid!' => '',
    'Page not found!' => '',
    'Page redirected to %s!' => '',
    'Purge folder to remove it permanently!' => '',
    'Shortcut icon not found! Trying default favicon location %s.' => '',
    'The description length exceeds maximum length of %s bytes!' => '',
    'The e-mail %s does not look correct!' => '',
    'The password was not repeated correctly!' => '',
    'There is no content to be deleted!' => '',
    'There is nothing to be undeleted!' => '',
    'This email is already used. Did you forget your password?' => '',
    'Tree has already been deleted!' => '',
    'Use "%s" command to delete own account!' => '',
    'Unknown command!' => '',
    'Unknown username or wrong password!' => '',
    'Verification e-mail has been sent to your e-mail address!' => '',
    'Wrong favicon type/format "%s"!' => '',
    'You have been left as group moderator!' => '',
    'You are the last moderator of used group(s): %s. Account cannot be deleted!' => '',

    '%s, welcome to the SiteBar!<p>You have been already logged in.' => 'Command window - execution messages',
    'E-mail %s verified! Any pending memberships were approved.' => '',
    'Link has been added.<p>You must reload your SiteBar in order to see added link!' => '',
    'Imported %s link(s) into %s folder(s) from the bookmark file.' => '',
    'Successful execution!' => '',
    'Submit' => '',
    'Reset' => '',
    'Reload SiteBar' => '',
    'Close' => '',
    'Return' => '',
    'Backup Return to SiteBar' => '',

    'Cannot open file!' => 'Bookmark manager - error messages',
    'Unknown bookmark file format!' => '',
    'File is empty!' => '',
    'Character set overriden from document to %s!' => '',
    'There is no conversion engine available to convert from %s character set!' => '',

    'Powered by %s ver. %s' => 'Skins',
    'Skin created by' => '',
    'Skin designed by' => '',

    'Folder found' => 'Javascript',
    'Link found' => '',
    'Desc' => '',
    'Name' => '',
    'Find next?' => '',
);

?>