<?php

$text = array
(
'The Bookmark Server for Personal and Team Use' => 'El servidor de bookmarks per us personal o d&#39;equip',
'SiteBar Homepage' => 'Pàgina de SiteBar',
'SiteBar Installation & Launcher' => 'Instalació i execució de SiteBar',
'Any Browser' => 'Qualsevol navegador',
'Content Bookmarklets' => 'Bookmarklets de context',
'Bookmarklet' => 'Bookmarklet',
'Your Language' => 'Català',
'Charset in MS Windows' => 'ISO-8859-1',
'Add Link to SiteBar' => 'Afegir enllaç a SiteBar',
'Add Page to SiteBar' => 'Afegir pàgina a SiteBar',
'Error' => 'Error',
'Warning' => 'Advertència',
'Unknown' => 'Desconegut',
'Search' => 'Cerca',
'Highlight' => 'Resaltat',
'Collapse/Expand All' => 'Plega/desplega tots',
'Reload' => 'Rellegeix',
'Reload with Hidden Folders' => 'Rellegeix amb carpetes amagades',
'Backup Log In' => 'Entra a còpia de seguretat',
'Backup Log Out' => 'Surt de còpia de seguretat',
'Commander' => 'intèrpret de comandes',
'Add Folder' => 'Afegeix carpeta',
'Add Link' => 'Afegeix enllaç',
'Contact Admin' => 'Contacta amb l&#39;administrador',
'Contact Moderator' => 'Contacta amb el moderador',
'Copy' => 'Copia',
'Copy Link' => 'Copia enllaç',
'Create Group' => 'Crea grup',
'Create Tree' => 'Crea arbre',
'Create User' => 'Crea usuari',
'Custom Order' => 'Ordre personalitzat',
'Delete Folder' => 'Esborra carpeta',
'Delete Group' => 'Esborra grup',
'Delete Link' => 'Esborra enllaç',
'Delete Account' => 'Esborra compte',
'Delete User' => 'Esborra usuari',
'Delete Tree' => 'Esborra arbre',
'Display Topic' => 'Mostra tòpic',
'Email Link' => 'Envia enllaç per correu',
'Export Bookmarks' => 'Exporta bookmarks',
'Export Description' => 'Esporta descripció',
'Favicon Management' => 'Tractament de favicons',
'Folder Properties' => 'Propietats de carpeta',
'Group Members' => 'Membres del grup',
'Group Moderators' => 'Moderadors del grup',
'Group Properties' => 'Propietats del grup',
'Help' => 'Ajuda',
'Hide Folder' => 'Amaga carpeta',
'Import Bookmarks' => 'Importa bookmarks',
'Import Description' => 'Importa descripció',
'Log In' => 'Entra',
'Log Out' => 'Surt',
'Maintain Groups' => 'Manteniment de grups',
'Maintain Users' => 'Manteniment d&#39;usuaris',
'Maintain Trees' => 'Manté arbres',
'Membership' => 'Pertenència als grups',
'Modify User' => 'Modifica usuari',
'Order of Trees' => 'Ordre d&#39;arbres',
'Paste' => 'Enganxa',
'Properties' => 'Propietats',
'Purge Cache' => 'Purga caché',
'Purge Folder' => 'Purga carpeta',
'Retrieve Link Information' => 'Obté informació dels enllaços',
'Security' => 'Seguretat',
'Send Email to Members' => 'Envia correu als membres',
'Send Email to Moderators' => 'Envia correu als moderadors',
'Send Email to User' => 'Envia correu a l&#39;usuari',
'Send Email to All' => 'Envia correu a tothom',
'Show All Icons' => 'Mostra totes les icones',
'Set Up' => 'Configuració',
'Sign Up' => 'Registra&#39;t',
'SiteBar Settings' => 'Preferències de SiteBar',
'Undelete' => 'Des-esborra',
'Unhide Trees' => 'Mostra arbres',
'Unhide Subfolders' => 'Mostra subcarpetes',
'User Settings' => 'Preferències d&#39;usuari',
'Personal Data' => 'Dades personals',
'Validate Links' => 'Valida enllaços',
'Validation' => 'Validació',
'Verify Email' => 'Verifica adreça de correu',
'Verify Email Code' => 'Verifica codi de correu',
'Admin Password' => 'Contrasenya d&#39;administrador',
'Allow Anonymous Contact' => 'Permet contacte anònim',
'Allow Contact' => 'Permet contacte',
'Allow Given Membership' => 'Permet afiliació donada',
'Allow Info Mail' => 'Permet correu d&#39;informació',
'Allow Noninteractive Mode' => 'Permet mode no interactiu',
'Allow Self Add' => 'Permet auto afegir',
'Allow Sign Up' => 'Permet registre',
'Auto Join E-Mail RegExp' => 'Auto afegir-se correu RegExp',
'Auto Retrieve Favicon' => 'Auto obtenir Favicon',
'Bookmark File' => 'Fitxer de bookmark',
'Cached: ' => 'Cachejat:',
'Codepage' => 'Pàgina de codi',
'Comment' => 'Comentari',
'Content Only' => 'Només contingut',
'Create New Sub Folder' => 'Crear nova sub-carpeta',
'Dead Link' => 'Enllaç mort',
'Decode Using' => 'Decodificar usant',
'Decorate ACL Folders' => 'Decorar carpetes ACL',
'Default Language' => 'Idioma per defecte',
'Default Search In' => 'Cerca per defecte',
'Default Skin' => 'Skin per defecte',
'Delete Content Only' => 'Esborra només continguts',
'Delete Invalid Favicons' => 'Esborra favicons invàlids',
'Demo Account' => 'Compte de demostració',
'Description' => 'Descripció',
'Description File' => 'Fitxer de escripció',
'Description Import/Export' => 'importa/exporta descripció',
'Discover Missing Favicons' => 'Decobreix favicons que falten',
'E-mail' => 'Adreça de correu',
'E-mail Verified' => 'Correu verificat',
'Encode Using' => 'Codifica usant',
'Exclude From Validation' => 'Exclou de la validació',
'Extern Commander' => 'Intèrpret d&#39;ordres extern',
'Favicon' => 'Favicon',
'Feedback or Other Comment' => 'Sugerències o altres comentaris',
'File Type' => 'tipus de fitxer',
'Folder Name' => 'Nom de la carpeta',
'From' => 'De',
'Group Name' => 'Nom del grup',
'Help Topic' => 'Tòpic d&#39;ajuda',
'Ignore Recently Tested' => 'Ignora els testats recentment',
'Include Subfolders' => 'Inclou subcarpetes',
'Keep In Cache' => 'Manté en caché',
'Language' => 'Idioma',
'Link Description Length' => 'Llargada de la descripció d&#39;enllaç',
'Link Name' => 'Nom de l&#39;enllaç',
'Maximal Icon Age' => 'Edat màxima d&#39;icona',
'Maximal Icon Size' => 'Tamany màxim d&#39;icona',
'Maximal Icons per User' => 'Icones màximes per usuari',
'Maximal Icons Total' => 'Icones màximes totals',
'Mode' => 'Mode',
'Moderator' => 'Moderador',
'New Tree Owner' => 'Nou propietari de l&#39;arbre',
'Old Password' => 'Contrasenya vella',
'Only to Verified Emails' => 'Només a correus verificats',
'Original: ' => 'Original:',
'Owner' => 'Propietari',
'Parent Folder' => 'Carpeta pare',
'Password' => 'Contrasenya',
'Paste Mode' => 'Mode d&#39;enganxat',
'Personal Mode' => 'Mode personal',
'Private' => 'Privat',
'Publish Folder' => 'Publica carpeta',
'Real Name' => 'Nom real',
'Recent Time Expressed in Seconds' => 'Temps recent expresat en segons',
'Remember as Default' => 'Recorda per defecte',
'Remember Me' => 'Recorda&#39;m',
'Rename Duplicate Links' => 'Renomena enllaços duplicats',
'Repeat Admin Password' => 'Repeteix contrasenya d&#39;administrador',
'Repeat Password' => 'Repeteix contrasenya',
'Respect Allow Info Mail' => 'Respecta permetre correu d&#39;informació',
'Select Group' => 'Selecciona grup',
'Select User' => 'Selecciona usuari',
'Sender E-mail' => 'correu de l&#39;enviador',
'Show Logo' => 'Mostra logotip',
'Show Menu Icon' => 'Mostra icona de menú',
'Show Public Bookmarks' => 'Mostra bookmarks públics',
'Show Sponsor' => 'Mostra espònsor',
'Skin' => 'Skin',
'Skip Execution Messages' => 'Salta missatges d&#39;execució',
'Source Folder Name' => 'Nom de la carpeta origen',
'Source Link Name' => 'Nom de l&#39;enllaç origen',
'Target Folder Name' => 'Nom de la carpeta destí',
'To' => 'A',
'Topic' => 'Tòpic',
'Tree Name' => 'Nom de l&#39;arbre',
'Tree Owner' => 'Propietari de l&#39;arbre',
'URL' => 'URL',
'Use Compression' => 'Usa compressió',
'Use Conversion Engine' => 'Usa motor de conversió',
'Use E-mail Features' => 'Usa característiques del correu',
'Use Favicons' => 'Usa favicons',
'Use Folder Hiding' => 'Usa ocultació de carpetes',
'Use Hit Counter' => 'Usa contador de hits',
'Use Outbound Connection' => 'Usa connexió de sortida',
'Use the Favicon Cache' => 'Usa la caché de favicons',
'Users Can Create Trees' => 'Usuaris poden crear arbres',
'Your E-mail' => 'La teva adreça de correu',
'Until I close browser' => 'Fins que tanqui el navegador',
'12 hours' => '12 hores',
'6 days' => '6 dies',
'1 month' => '1 mes',
'No caching' => 'Sense caché',
'Order of Folders v. Links' => 'Ordre de Carpetes vs. Enllaços',
'Links first' => 'Enllaços primer',
'Folders first' => 'Carpetes primer',
'Default Link Sort Mode' => 'Mode d&#39;ordenació d&#39;enllaços per defecte',
'Sort Mode' => 'Mode d&#39;ordenació',
'User default' => 'Usuari per defecte',
'Custom order' => 'Ordre personalitzat',
'Alphabetically' => 'Alfabeticament',
'Most clicked first' => 'El més clicat primer',
'New/changed links first' => 'Enllaços nous/canviats primer',
'Waiting for visit' => 'Esperant una visita',
'Anonymous Guest' => 'Convidat anònim',
'Guest' => 'Convidat',
'Message' => 'Missatge',
'SiteBar Server' => 'Servidor de SiteBar',
'%s - ok.' => '%s - ok.',
'%s - error!' => '%s - error!',
'SiteBar: Contact Admin' => 'SiteBar: Contacta administrador',
'SiteBar: Contact Group Moderator' => 'SiteBar: Contacta moderador de grup',
'SiteBar: Email to all SiteBar Users' => 'SiteBar: correu a tots els usuaris de SiteBar',
'SiteBar: Email to Group Members' => 'SiteBar: correu als membres del grup',
'SiteBar: Email to Group Moderators' => 'SiteBar: correu als moderadors del grup',
'SiteBar: Email to SiteBar User' => 'SiteBar: correu a usuari de SiteBar',
'SiteBar: Email Verification' => 'SiteBar: Verificació d&#39;adreça de correu',
'SiteBar: New SiteBar User' => 'Sitebar: nou usuari de SiteBar',
'SiteBar: Web site' => 'SiteBar: pàgina web',
'Group' => 'Grup',
'R' => 'R',
'A' => 'A',
'M' => 'M',
'D' => 'D',
'P' => 'P',
'G' => 'G',
'Ask' => 'Pregunta',
'Move or Copy' => 'Mou o còpia',
'Copy (Keep Source)' => 'còpia (conserva l&#39;origen)',
'Move (Delete Source)' => 'Mou (esborra l&#39;origen)',
'Auto detection' => 'Auto detecció',
'Netscape/Mozilla/MS IE' => 'Netscape/Mozilla/MS IE',
'Netscape/Mozilla' => 'Netscape/Mozilla',
'MS Internet Explorer' => 'MS Internet Explorer',
'Opera Hotlist version 2.0' => 'Opera Hotlist versió 2.0',
'Admins' => 'Administradors',
'Everyone' => 'Tothom',
'%s&#39;s Bookmarks' => 'Bookmarks de %s',
'Deleted root %s of %s at %s' => 'Esborrat arrel %s de %s a %s',
'All' => 'Tot',
'Name' => 'Nom',
'Access denied!' => 'Accés denegat!',
'All links recently validated!' => 'Tots els enllaços validats recentment!',
'Cannot connect to http://%s:%s!' => 'No puc connectar a http://%s:%s!',
'Cannot delete built in group!' => 'No puc esborrar grup &#39;built in&#39;!',
'Cannot delete user because he is the only moderator of the following group(s): %s!' => 'No puc esborrar l&#39;usuari doncs és l&#39;únic moderador del(s) següent(s) grup(s): %s!',
'Cannot download %s using https, will try http!' => 'No puc descarregar %s usant https, provaré amb http',
'Cannot export empty description!' => 'No puc exportar descripció buida!',
'Cannot handle %s protocol!' => 'No suporto el protocol %s!',
'Cannot remove all moderators from a group!' => 'No puc esborrar tots els moderadors d&#39;un grup!',
'Cannot send email!' => 'No puc enviar correu!',
'Connection timed out!' => 'Connexió expirada!',
'Database corrupted - missing anonymous account!' => 'Base de dades corrupta - falta compte anònim!',
'Duplicate folder name "%s"!' => 'Carpeta duplicada "%s"!',
'Duplicate folder name!' => 'Carpeta duplicada!',
'Duplicate name "%s" in the target folder!' => 'Nom "%s" duplicat en la carpeta de destí!',
'Duplicate name "%s"!' => 'Nom "%s" duplicat!',
'Expected field %s was not filled!' => 'El camp esperat %s no ha estat omplert',
'Favicon <img src="%s"> found at url %s.' => 'Favicon <img src="%s"> trobat a la url %s.',
'Favicon not found!' => 'Favicon no trobat',
'Field %s must be filled!' => 'El camp %s ha de ser omplert!',
'Folder has already been deleted!' => 'La carpeta ja ha estat eliminada!',
'Folder with id %s does not exist!' => 'La carpeta amb id %s no existeix!',
'Group has already been deleted!' => 'El grup ja ha estat eliminat!',
'Group name "%s" is already used!' => 'El nom de grup "%s" ja està usat!',
'Head of the HTML page was not found!' => 'No s&#39;ha trobat la capççalera de la pàgina HTML',
'HEAD unsupported, trying GET!' => 'HEAD no suportat, provant GET!',
'Host or port undefined!' => 'Host o port indefinit',
'Icon size %s exceeds maximal size %s!' => 'El tamany d&#39;icona %s excedeix el màxim %s!',
'Incomplete HTTP response!' => 'Resposta HTTP incompleta!',
'Invalid code, verification disabled!' => 'Codi invàlid, verificació desactivada!',
'Invalid regular expresssion!' => 'Expressió regular invàlida!',
'Invalid filename or other upload related problem: %s!' => 'Nom de fitxer invalid o un altre problema de càrrega: %s!',
'Link already is in the target folder!' => 'L&#39;enllaç ja existeix en la carpeta de destí!',
'Link has already been deleted!' => 'L&#39;enllaç ja ha estat eliminat!',
'Missing command!' => 'Falta comanda!',
'No links in the folder!' => 'No hi ha enllaços en la carpeta!',
'No more than %s redirections allowed!' => 'No més de %s redireccions permeses!',
'No user was selected!' => 'Cap usuari seleccionat!',
'Node number %s has ACL record but does not exist!' => 'El node %s té registre ACL però no existeix!',
'Old password is invalid!' => 'La contrasenya vella és invàlida!',
'Page not found!' => 'No s&#39;ha trobat la pàgina!',
'Page redirected to %s!' => 'Pàgina redireccionada a %s!',
'Purge folder to remove it permanently!' => 'Purga carpeta per eliminarla permanentment!',
'Shortcut icon not found! Trying default favicon location %s.' => 'Icona d&#39;enllaç no trobada! Intentant amb la localització de favicons per defecte %s.',
'The description length exceeds maximum length of %s bytes!' => 'La descripció és mes llarga que la llargada màxima de %s bytes!',
'The e-mail %s does not look correct!' => 'L&#39;adreça de correu %s no sembla correcta!',
'The password was not repeated correctly!' => 'La contrasenya no s&#39;ha repetit correctament!',
'There is no content to be deleted!' => 'No hi ha contingut a eliminar!',
'There is nothing to be undeleted!' => 'No hi ha res a eliminar!',
'This email is already used. Did you forget your password?' => 'Aquesta adreça de correu ja és usada. Has oblidat la teva contrasenya?',
'Tree has already been deleted!' => 'L&#39;Arbre ja ha estat eliminat!',
'Use "%s" command to delete own account!' => 'Usa la comanda "%s" per esborrar el propi compte.',
'Unknown command!' => 'Comanda desconeguda!',
'Unknown username or wrong password!' => 'Nom d&#39;usuari desconegut o contrasenya incorrecta!',
'Verification e-mail has been sent to your e-mail address!' => 'Un correu de verificació ha estat enviat a la teva adreça de correu!',
'Wrong favicon type/format "%s"!' => 'Tipus/format de favicon incorrecte "%s"!',
'You have been left as group moderator!' => 'Has quedat com a moderador de grup!',
'You are the last moderator of used group(s): %s. Account cannot be deleted!' => 'Ets el darrer moderador del(s) grup(s): %s. El compte no pot ser esborrat!',
'%s, welcome to the SiteBar!<p>You have been already logged in.' => '%s, benvingut a SiteBar!<p>Has entrat correctament.',
'E-mail %s verified! Any pending memberships were approved.' => 'Adreça de correu %s verificada! Totes les afiliacions pendents han estat aprovades.',
'Link has been added.<p>You must reload your SiteBar in order to see added link!' => 'L&#39;enllaç ha estat afegit.<p>Has de recarregar el teu Sitebar per veure l?enllaç afegit!',
'Imported %s link(s) into %s folder(s) from the bookmark file.' => '%s enllaç(os) ha(n) estat importat(s) en %s carpeta(es) del fitxer de bookmarks',
'Successful execution!' => 'Execució amb exit!',
'Submit' => 'Envia',
'Reset' => 'Restablir',
'Reload SiteBar' => 'Recarrega SiteBar',
'Close' => 'Tanca',
'Return' => 'Torna',
'Backup Return to SiteBar' => 'Restaura còpia de seguretat en SiteBar',
'Cannot open file!' => 'No puc obrir fitxer!',
'Unknown bookmark file format!' => 'Format de fitxer de bookmarks desconegut!',
'File is empty!' => 'El fitxer és buit!',
'Character set overriden from document to %s!' => 'Set de caràcters del document anulats a %s!',
'There is no conversion engine available to convert from %s character set!' => 'No hi ha cap motor de conversió disponible per convertir des del set de caràcters %s!',
'Powered by %s ver. %s' => 'Funciona amb %s versió %s',
'Skin created by' => 'Skin creada per',
'Skin designed by' => 'Skin dissenyada per',
'Folder found' => 'Carpeta trobada',
'Link found' => 'Enllaç trobat',
'Desc' => 'Descripció',
'Find next?' => 'Cerca següent?',
);

?>
