<?php

$para = array();

$para['index::tip'] = <<<_P
Käytä tätä sivua SiteBarin käynnistämiseen tai asentamiseen.

Lisää suosikkeihisi jokin "*" -merkitty linkki. Ne vievät suoraan SiteBar
bookmarkkeihin.

Tämä sivu avautuu aina SiteBar:n ylälaidan logosta.
_P;

$para['index::any_browser'] = <<<_P
Avaa <a title="SiteBar" href="%s/sitebar.php">SiteBar</a>*
tähän ikkunaan - tai avaa se
<a title="SiteBar" href="%s">pop-up:ssa</a>* omaan ikkunaan.
_P;

$para['index::ie_install'] = <<<_P
<a href="?install=1">Asenna</a> / <a href="?install=0">poista asennus</a>
Internet Exploreriin - vaatii rekisterimuutoksen
ja uudelleenkäynnistyksen, että kaikki ominaisuudet astuvat voimaan.

<p>Käyttöoikeutesi järjestelmässä voivat rajoittaa asennusta.</p>

<p class='comment'>Avaa SiteBar IE:n työkalupalkista. Joudut ehkä kustomoimaan
palkkiasi. Lisää SiteBar nappi klikkaamallaa työkaluriviä hiiren kakkospainikkeella
ja valitse "Customize..." / "Muokkaa..."</p>
_P;

$para['command::noiconv'] = <<<_P
<br>
Koodisivun muuntoa ei ole asennettu tähän SiteBar -palveluun
<br>
_P;

$para['command::security_legend'] = <<<_P
Oikeudet: <strong>R</strong>ead = Lukea, <strong>A</strong>dd = Lisätä, <strong>M</strong>odify = Muokata, <strong>D</strong>elete = poistaa, <strong>P</strong>urge = tyhjentää, <strong>G</strong>rant = vahvistaa
_P;

$para['command::purge_cache'] = <<<_P
<h3>Haluatko varmasti poistaa kaikkia faviconit välimuistista?</h3>
_P;

$para['usermanager::signup_info'] = <<<_P
Uusi käyttäjä "%s" <%s> on lisätty SiteBar -sivustoon: %s.
_P;

?>
