<?php

$text = array
(
'The Bookmark Server for Personal and Team Use' => 'Serveur de favoris à utilisation personnel ou en équipe',
'SiteBar Homepage' => 'Page d&#39;acceuil de SiteBar',
'SiteBar Installation & Launcher' => 'Installation de SiteBar & Lanceur',
'Any Browser' => 'Tous Navigateurs',
'Content Bookmarklets' => 'Contenu des favoris',
'Bookmarklet' => 'Favoris',
'Your Language' => 'Français',
'Charset in MS Windows' => 'ISO-8859-1',
'Add Link to SiteBar' => 'Ajouter le lien à SiteBar',
'Add Page to SiteBar' => 'Ajouter la page à SiteBar',
'Error' => 'Erreur',
'Warning' => 'Attention',
'Unknown' => 'Inconnu',
'Search' => 'Rechercher',
'Highlight' => 'Surbrillance',
'Collapse/Expand All' => 'Réduire/Developper tout',
'Reload' => 'Recharger',
'Reload with Hidden Folders' => 'Recharger avec kes repertoires cachés',
'Backup Log In' => 'Connexion de secours',
'Backup Log Out' => 'Deconnexion de secours',
'Commander' => 'Panneau de commande',
'Add Folder' => 'Ajouter Répertoire',
'Add Link' => 'Ajouter Lien',
'Contact Admin' => 'Contacter l&#39;administrateur',
'Contact Moderator' => 'Contacter le modérateur',
'Copy' => 'Copier',
'Copy Link' => 'Copier le Lien',
'Create Group' => 'Créer un Groupe',
'Create Tree' => 'Créer une hierarchie',
'Create User' => 'Créer un utilisateur',
'Custom Order' => 'Commande personnalisée',
'Delete Folder' => 'Supprimer le Répertoire',
'Delete Group' => 'Supprimer ungroupe',
'Delete Link' => 'Supprimer un lien',
'Delete Account' => 'Supprimer le compte',
'Delete User' => 'Supprmier un utilisateur',
'Delete Tree' => 'Supprimer la hierarchie',
'Display Topic' => 'Afficher le sujet',
'Email Link' => 'Envoyer le lien par Email',
'Export Bookmarks' => 'Exporter les favoris',
'Export Description' => 'Exporter la description',
'Favicon Management' => 'Gestion des Favicon',
'Folder Properties' => 'Proprété du répertoire',
'Group Members' => 'Membre du groupe',
'Group Moderators' => 'Modérateur du groupe',
'Group Properties' => 'Propriété du groupe',
'Help' => 'Aide',
'Hide Folder' => 'Répertoire caché',
'Import Bookmarks' => 'Importer les favoris',
'Import Description' => 'Importer la description',
'Log In' => 'Connexion',
'Log Out' => 'Deconnexion',
'Maintain Groups' => 'Maintenir les groupes',
'Maintain Users' => 'Maintenir les utilisateurs',
'Maintain Trees' => 'Maintenir les hierarchies',
'Membership' => 'Adhésion',
'Modify User' => 'Modifier un utilisateur',
'Order of Trees' => 'Positionnement des hierarchies',
'Paste' => 'Coller',
'Properties' => 'Propriétés',
'Purge Cache' => 'Purger le cache',
'Purge Folder' => 'Purger les répertoires',
'Retrieve Link Information' => 'Recupération des informations du lien',
'Security' => 'Sécurité',
'Send Email to Members' => 'Envoyer un email aux membres',
'Send Email to Moderators' => 'Envoyer un email aux modérateurs',
'Send Email to User' => 'Envoyer un email à un utilisateur',
'Send Email to All' => 'Envoyer un email à tout le monde',
'Show All Icons' => 'Afficher tous les icones',
'Set Up' => 'Configurer',
'Sign Up' => 'Inscription',
'SiteBar Settings' => 'Paramètres de SiteBar',
'Undelete' => 'Restaurer',
'Unhide Trees' => 'Afficher les hierarchies',
'Unhide Subfolders' => 'Afficher les osus-répertoires',
'User Settings' => 'Paramètres utilisateur',
'Personal Data' => 'Information personnelles',
'Validate Links' => 'Valider les liens',
'Validation' => 'Validation',
'Verify Email' => 'Vérifier l&#39;email',
'Verify Email Code' => 'Code de vérification de l email',
'Admin Password' => 'Mode de passe Administrateur',
'Allow Anonymous Contact' => 'Autoriser les contacts anonymes',
'Allow Contact' => 'Autoriser les contacts',
'Allow Given Membership' => 'Autoriser la possibiliter d&#39;autoriser les adhesions',
'Allow Info Mail' => 'Autoriser les informations par email',
'Allow Noninteractive Mode' => 'Autoriser le mode non-intéractif',
'Allow Self Add' => 'Autoriser l&#39;ajout automatique',
'Allow Sign Up' => 'Autoriser les inscriptions',
'Auto Join E-Mail RegExp' => 'Règle RegExp d ajout automatique sur les emails',
'Auto Retrieve Favicon' => 'Recuperation automatique du Favicon',
'Bookmark File' => 'Fichiers favoris',
'Cached: ' => 'En cache:',
'Codepage' => 'Codepage',
'Comment' => 'Commentaire',
'Content Only' => 'Contenu uniquement',
'Create New Sub Folder' => 'Créer un sous-répertoire',
'Dead Link' => 'Lien mort',
'Decode Using' => 'Decoder en utilisant',
'Decorate ACL Folders' => 'Mise en couleur pour les règles de répertoire',
'Default Language' => 'Langage par defaut',
'Default Search In' => 'Recherche par defaut dans',
'Default Skin' => 'Thème par defaut',
'Delete Content Only' => 'Supprimer le contenu seulement',
'Delete Invalid Favicons' => 'Supprimer les Favicons invalides',
'Demo Account' => 'Compte de démonstration',
'Description' => 'Description',
'Description File' => 'Description du fichier',
'Description Import/Export' => 'Description Importer/Exporter',
'Discover Missing Favicons' => 'Rechercher les Favicons manquants',
'E-mail' => 'Email',
'E-mail Verified' => 'E-mail verifier',
'Encode Using' => 'Encoder en utilisant',
'Exclude From Validation' => 'Exclure de la validation',
'Extern Commander' => 'Commande externe',
'Favicon' => 'Favicon',
'Feedback or Other Comment' => 'Commentaires ou retour d&#39;utilisation',
'File Type' => 'Type de fichier',
'Folder Name' => 'Nom du répertoire',
'From' => 'De',
'Group Name' => 'Nom du groupe',
'Help Topic' => 'Sommaire de l&#39;aide',
'Ignore Recently Tested' => 'Ignorer les tests récents',
'Include Subfolders' => 'Inclure les sous-repertories',
'Keep In Cache' => 'Conserver dans le cache',
'Language' => 'Langage',
'Link Description Length' => 'Taille de la description du lien',
'Link Name' => 'Nom du lien',
'Maximal Icon Age' => 'Durée maximum d&#39;une icone',
'Maximal Icon Size' => 'Taille maximum d&#39;une icone',
'Maximal Icons per User' => 'Nombre d&#39;icone maximum par utilisateur',
'Maximal Icons Total' => 'Nombre total d&#39;icone maximum',
'Mode' => 'Mode',
'Moderator' => 'Modérateur',
'New Tree Owner' => 'Nouveau propriétaire de la hierarchie',
'Old Password' => 'Ancien mot de passe',
'Only to Verified Emails' => 'Seulement aux emails verifiées',
'Original: ' => 'Original:',
'Owner' => 'Propriétaire',
'Parent Folder' => 'Répertorie parent',
'Password' => 'Mode de passe',
'Paste Mode' => 'Mode de copie',
'Personal Mode' => 'Mode personnel',
'Private' => 'Privé',
'Publish Folder' => 'Publier le répertorie',
'Real Name' => 'Nom réel',
'Remember as Default' => 'Se souvnir par defaut',
'Remember Me' => 'Se souvenir de moi',
'Rename Duplicate Links' => 'Renomer les liens dupliqués',
'Repeat Admin Password' => 'Réécrire le mode passe administrateur',
'Repeat Password' => 'Réécrire le mot de passe',
'Respect Allow Info Mail' => 'Respect des informaitons d&#39;autorisation sur l&#39;email',
'Select Group' => 'Séléctionner le groupe',
'Select User' => 'Selection l&#39;utilisateur',
'Sender E-mail' => 'Expediteur du email',
'Show Logo' => 'Afficher le Logo',
'Show Menu Icon' => 'Afficher les icones du menu',
'Show Public Bookmarks' => 'Afficher les favoris publics',
'Show Sponsor' => 'Afficher le Sponsor',
'Skin' => 'Thème',
'Skip Execution Messages' => 'Ignorer les messages d&#39;executions',
'Source Folder Name' => 'Nom du répertoire source',
'Source Link Name' => 'Nom du lien source',
'Target Folder Name' => 'Nom du répertoire de destination',
'To' => 'A',
'Topic' => 'Sujet',
'Tree Name' => 'Nom de la hierarchie',
'Tree Owner' => 'Propriétaire de la hierarchie',
'URL' => 'URL',
'Use Compression' => 'Utiliser la compression',
'Use Conversion Engine' => 'Utiliser le moteur de convertion',
'Use E-mail Features' => 'Utiliser les options d email',
'Use Favicons' => 'Utiliser les Favicons',
'Use Folder Hiding' => 'Utilisation des répertoires cachés',
'Use Hit Counter' => 'Utilisation du compteur de HIT',
'Use the Favicon Cache' => 'Utilisation du cache de Favicon',
'Users Can Create Trees' => 'Les utilisateurs peuvent créer des hierarchies',
'Your E-mail' => 'Votre Email',
'Until I close browser' => 'Jusqu&#39;a ce que je ferme le navigateur',
'12 hours' => '12 heures',
'6 days' => '6 jours',
'1 month' => '1 mois',
'No caching' => 'Pas de cache',
'Order of Folders v. Links' => 'Classer les répertoires v. les liens',
'Links first' => 'Liens en premier',
'Folders first' => 'Répertoires en premier',
'Default Link Sort Mode' => 'Mode de Classement par defaut',
'Sort Mode' => 'Mode de classement',
'User default' => 'Utilisateur par defaut',
'Custom order' => 'Classement personnalisé',
'Alphabetically' => 'Alphabétique',
'Most clicked first' => 'Le plus cliqué en premier',
'New/changed links first' => 'Nouveau/Recement changé en premier',
'Waiting for visit' => 'Attente pour visite',
'Anonymous Guest' => 'Invité anonyme',
'Guest' => 'Invité',
'Message' => 'Message',
'SiteBar Server' => 'Serveur SiteBar',
'%s - ok.' => '%s - effectué.',
'%s - error!' => '%s - erreur!',
'SiteBar: Contact Admin' => 'SiteBar: Contacter les administrateurs',
'SiteBar: Contact Group Moderator' => 'SiteBar: Contacter les modérateurs',
'SiteBar: Email to all SiteBar Users' => 'SiteBar: Email à tous les utilisateurs',
'SiteBar: Email to Group Members' => 'SiteBar:  Email à tous les membres du groupe',
'SiteBar: Email to Group Moderators' => 'SiteBar: Email aux modérateurs du groupe',
'SiteBar: Email to SiteBar User' => 'SiteBar: Email à un utilisateur',
'SiteBar: Email Verification' => 'SiteBar: Verification d&#39;email',
'SiteBar: New SiteBar User' => 'SiteBar: Nouvel utilisateur SiteBar',
'SiteBar: Web site' => 'SiteBar: Site Internet',
'Group' => 'Groupe',
'R' => 'L',
'A' => 'A',
'M' => 'M',
'D' => 'S',
'P' => 'P',
'G' => 'P',
'Ask' => 'Poser la question',
'Move or Copy' => 'Déplacer ou copier',
'Copy (Keep Source)' => 'Copier (Conserve la source)',
'Move (Delete Source)' => 'Déplacer (Supprime la source)',
'Auto detection' => 'Détéction automatique',
'Netscape/Mozilla/MS IE' => 'Netscape/Mozilla/MS IE',
'Netscape/Mozilla' => 'Netscape/Mozilla',
'MS Internet Explorer' => 'MS Internet Explorer',
'Opera Hotlist version 2.0' => 'Opéra Hotlist version 2.0',
'Admins' => 'Admins',
'Everyone' => 'Tout le monde',
'%s&#39;s Bookmarks' => 'Favoris de %s',
'Deleted root %s of %s at %s' => 'Suppression de la racine %s de %s à %s',
'All' => 'Tous',
'Name' => 'Nom',
'Access denied!' => 'Accès refusé !',
'All links recently validated!' => 'Tous les liens recement validés!',
'Cannot connect to http://%s:%s!' => 'Impossible de se connecter à http://%s:%s!',
'Cannot delete built in group!' => 'Impossible de supprimer le groupe auquel vous appartenez!',
'Cannot delete user because he is the only moderator of the following group(s): %s!' => 'Impossible de supprimer l&#39;utilisateur parcequ&#39;il est le seul modérateur des groupes suivant: %s!',
'Cannot download %s using https, will try http!' => 'Impossible de télécharger %s en utilisant https, essayons en http!',
'Cannot export empty description!' => 'Impossible d&#39;exporter une description vide',
'Cannot handle %s protocol!' => 'Impossible de comprendre le protocole %s!',
'Cannot remove all moderators from a group!' => 'Impossible de supprimer tous les modérateurs d&#39;un groupe',
'Cannot send email!' => 'Impossibilité d&#39;envoyer un email',
'Connection timed out!' => 'Temps de connexion depassé!',
'Database corrupted - missing anonymous account!' => 'Base de donnée corrompue - il manque les comptes anonymes',
'Duplicate folder name "%s"!' => 'Nom du répertoire existant : %s!',
'Duplicate folder name!' => 'Nom de répertoire existant!',
'Duplicate name "%s" in the target folder!' => 'Nom dupliqué "%s" dans le répertoire cible',
'Duplicate name "%s"!' => 'Nom existant "%s"!',
'Expected field %s was not filled!' => 'Le champs %s est obligatoire',
'Favicon <img src="%s"> found at url %s.' => 'Favicon <img src="%s"> trouvé à l&#39;adresse %s.',
'Favicon not found!' => 'Favicon non trouvé',
'Field %s must be filled!' => 'Le champ % doit être rempli',
'Folder has already been deleted!' => 'Le répertoire est déjà supprimé',
'Folder with id %s does not exist!' => 'L&#39;ID %s du répertoire est inexistant',
'Group has already been deleted!' => 'Le groupe a déjà été supprimé',
'Group name "%s" is already used!' => 'Le nom du groupe %s est déjà utilisé!',
'Head of the HTML page was not found!' => 'L&#39;en-tête de la page HTML n&#39;a pas été trouvée!',
'HEAD unsupported, trying GET!' => 'HEAD non supporté, essayons GET!',
'Host or port undefined!' => 'Hote ou port indéfini!',
'Icon size %s exceeds maximal size %s!' => 'La taille de l&#39;icone est %s, elle depasse la taille maximale de %s',
'Incomplete HTTP response!' => 'Reponse HTTP incomplète',
'Invalid code, verification disabled!' => 'Code invalide, vérification désactivé!',
'Invalid regular expresssion!' => 'Expression régulière invalide!',
'Invalid filename or other upload related problem: %s!' => 'Nom de fichier invalide ou problème lors du téléchargement: %s!',
'Link already is in the target folder!' => 'Lien existant dans le répertoire cible',
'Link has already been deleted!' => 'Le lien a déjà été désactivé',
'Missing command!' => 'Commande manquante!',
'No links in the folder!' => 'Pas de lien dans le répertoire!',
'No more than %s redirections allowed!' => 'Pas plus de %s redirection ne sont autorisées!',
'No user was selected!' => 'Pas d&#39;utilisateur séléctionné!',
'Node number %s has ACL record but does not exist!' => 'Le noeud numéro % à des ACL, mais celui-ci n&#39;existe pas!',
'Old password is invalid!' => 'Ancien mot de passe invalide!',
'Page not found!' => 'Page non trouvé!',
'Page redirected to %s!' => 'Page redirrigé vers %s!',
'Purge folder to remove it permanently!' => 'Purger les répertoire pour les supprimer de manière permanante',
'Shortcut icon not found! Trying default favicon location %s.' => 'Raccourci de l&#39;icon introuvable! Essayons à l&#39;emplacement par defaut %s.',
'The description length exceeds maximum length of %s bytes!' => 'La taille de la description dépasse la taille maximum de %s octets!',
'The e-mail %s does not look correct!' => 'L&#39;email %s ne semble pas être correct',
'The password was not repeated correctly!' => 'Les mots de passe de ne sont pas identiques!',
'There is no content to be deleted!' => 'Il n&#39;y a pas de contenu a supprimer',
'There is nothing to be undeleted!' => 'Il n&#39;y a aucun éléments à restaurer',
'This email is already used. Did you forget your password?' => 'Cette email est déjà utilisé. Avez-vous oublié votre mot de passe?',
'Tree has already been deleted!' => 'Hierarchie déjà supprimée!',
'Use "%s" command to delete own account!' => 'Utiliser la commande "%s" pour supprimer son propre compte!',
'Unknown command!' => 'Commande inconnue!',
'Unknown username or wrong password!' => 'Nom d&#39;utilisateur inconnu ou mot de passe incorrect',
'Verification e-mail has been sent to your e-mail address!' => 'Le message de vérification à été envoyé sur votre Email!',
'Wrong favicon type/format "%s"!' => 'Mauvais type/format de favicon "%s"!',
'You have been left as group moderator!' => 'Vous avez quitté le groupe de modération!',
'You are the last moderator of used group(s): %s. Account cannot be deleted!' => 'Vous êtes le dernier modérateurs des goupes: %s. Le compte ne peut pas être supprimé!',
'%s, welcome to the SiteBar!<p>You have been already logged in.' => '%s, bievenu sur SiteBar!<p>Vous êtes maintenant identifié.',
'E-mail %s verified! Any pending memberships were approved.' => 'L&#39;email %s a été verifié! Toutes les adhésions ont été approuvé.',
'Link has been added.<p>You must reload your SiteBar in order to see added link!' => 'Lien ajouter.<p>Vous devez recharger votre SiteBar pour pouvoir voir les liens ajoutés!',
'Imported %s link(s) into %s folder(s) from the bookmark file.' => 'Importation de % lien(s) dans % répertoire(s) à partir du fichier favori.',
'Successful execution!' => 'Execution réussie!',
'Submit' => 'Envoyer',
'Reset' => 'Annuler',
'Reload SiteBar' => 'Recharger SiteBar',
'Close' => 'Fermer',
'Return' => 'Retour',
'Backup Return to SiteBar' => 'Retour à SiteBar (backup)',
'Cannot open file!' => 'Impossible d&#39;ouvrir le fichier!',
'Unknown bookmark file format!' => 'Le format de fichier favori est inconnu',
'File is empty!' => 'Le fichier est vide!',
'Character set overriden from document to %s!' => 'Le jeu de caractère a été ecrrasé du document à %s!',
'There is no conversion engine available to convert from %s character set!' => 'Il n&#39;y a pas de moteur de convertion disponible pour le type %s !',
'Powered by %s ver. %s' => 'Proposé par %s version %s',
'Skin created by' => 'Thème créé par',
'Skin designed by' => 'Thème développé par',
'Folder found' => 'Répertoire trouvé',
'Link found' => 'Lien trouvé',
'Desc' => 'Desc',
'Find next?' => 'Rechercher le prochain ?',
);

?>
