<?php

$help = array();

$help['100'] = <<<_P
Funkce SiteBaru jsou dostupné z <strong>uživatelského menu</strong> a z
<strong>kontextového</strong> složek a odkazů. Uživatelské menu je vždy
zobrazeno ve spodní části SiteBaru. Kontextová menu složek a odkazů jsou
dostupná kliknutím pravého tlačítka myši na dané složce či odkazu. Uživatelé
Opera či Apple prohlížečů mohou použít kliknutí levého tlačítka spolu
se stisknutou klávesou Ctrl. V případě, že ani tato možnost není browserem
podporovaná lze v <strong>Nastavení</strong> zvolit zobrazování menu ikony.
Tato ikona je zobrazena vedle ikony složky či odkazu a kliknutím na ni se patřičné
kontextové menu vyvolá.
<p>
Jak kontextová menu tak uživatelské menu zobrazují rozdílné podmnožiny dotazů
pro různé uživatele v závislosti na jejich právech v systému. Některé položky
v kontextovém menu mohou být být znepřístupněny v závisloti na uživatelských
právech a právech k dané složce. Vybrané příkazy jsou prováděny v Příkazovém okně.
_P;

$help['101'] = <<<_P
Kliknutím na složku či odkaz myčí a následným tažením myši při stále stlačeném
tlačítku nad jinou složku je možné zkopírovat či přesunout tažený objekt.
Během tažení je cílová složka signalizována barevným zvýrazněním.
<p>
Tato funkce je implementována pro browsery rodiny Mozilla a pro Internet Explorer.
Uživatelé ostatních prohlážečů musí použít kontextové menu <strong>Kopírovat</strong> a
<strong>Vložit</strong>.
_P;

$help['102'] = <<<_P
Nejpohodlnější způsob jak přidávat odkazy do SiteBaru se provádí pomocí takzvaného
bookmarkletu (česky snad odkazovátko :-). Bookmarklet lze vytvořit z domácí stránky
dané instalace SiteBaru. Tato stránka je dostupná kliknutím na horní logo v SiteBaru.
Uživatelé Internet Explorer mohou pro vkládání odkazů používat fukce z kontextového
menu, které jsou dostupné po provedení instalace SiteBaru do MS IE.
_P;

$help['103'] = <<<_P
<p><strong>Hledat</strong> - umožňuje hledat v právě zobrazených odkazech. Je možné
nastavit který parametr odkazu se má prohledávat pomocí následujících prefixů
<strong>url:</strong>, <strong>name:</strong> - název, <strong>desc:</strong> - popis,
<strong>all:</strong> - vše. Defaultní prefix je <strong>name:</strong>. V případě, že
je nalezen vyhovující odkaz či složka je název zvýrazněn a uživatel má možnost na zobrazeném
javascript okně zvolit zda pokračovat v hledání či pokračovat.

<p><strong>Zvýraznit</strong> - stejná funkce jako hledání s tím rozdílem, že všechny
nálezy jsou zvýrazněny bez uživatelské interakce.

<p><strong>Zabalit/rozbalit vše</strong> - zabalí všechny složky. Při druhém kliknutí
(a pokud jsou všechny složky zabalené) rozbalí všechny složky.

<p><strong>Znovu načíst se skrytými složkami</strong> - načte znovu odkazy ze SiteBar serveru včetně
složek skrytých příkazem "Skrýt složku".

<p><strong>Znovu načíst</strong> - načte znovu odkazy ze SiteBar serveru. Tato funkce
je implementována z toho důvodu, že obnova obsahu sidebaru je v některých browserech obtížná.
_P;

$help['200'] = <<<_P
Příkazy jsou sdruženy do několika logických skupin. Vybráním skupiny lze zobrazit nápovědu
k příslušným příkazům.
_P;

$help['210'] = <<<_P
<p><strong>Přihlásit</strong> - přihlásí uživatele do systému. Přihlášení uživatel je
zaznamenáno pomocí Cookies. Uživatel může při přihlášení specifikovat kdy tato Cookie
vyprší.

<p><strong>Odhlásit</strong> - odhlásí uživatele ze serveru. Tento příkaz by měl být
použit vždy, když je SiteBar používán na veřejných terminálech. Ekvivalentem je
použití přihlášení se zapamatováním dokud je prohlížeč otevřen a potom zavřít všechna
okna použitého prohlížeče.

<p><strong>Založit účet</strong> - umožňuje návštěvníkům stránek založit si vlastní
účet v systému. Na základě e-mailové adresy, která slouží jako uživatelské jméno, je
možné nastavit, aby byl uživatel automaticky zařazen mezi členy nějaké skupiny.
Aby k tomu mohlo dojít, je nezbytné, aby uživatel ověřil svoji e-mailovou adresu.
E-mail s vyžádáním ověření je odesílán automaticky. Administrátor může zakázat
uživatelům vytváření účtů.
_P;

$help['220'] = <<<_P
<p><strong>Set Up</strong> - první příkaz, který administrátor spatří po instalaci
SiteBaru a po úspěšném nastavení parametrů databázového připojení. Dovoluje
nastavit základní parametry dané instance SiteBar serveru. Zvolení "Personal Mode"
volby provede restrikci na některé funkce vhodné pro víceuživatelský přístup.

<p><strong>SiteBar nastavení</strong> - umožnuje administrátorovi změnit
nastavení základních parametrů. Adminstrátory jsou členi Admins skupiny
a uživatel vytvoření příkazem "Set Up". Příklad e-mailových funkcí je demonstrován
v příkazu "Založit účet". Více vlastností spojených s e-mailem je plánováno do
budoucna.

<p><strong>Vytvořit strom</strong> - v závislosti na nastavení SiteBaru pouze
administrátoři nebo uživatelé s ověřenou adresou mohou vytvářet další stromy.
Každý nově vytvořený strom mysí být spojen s existujícím účtem (pouze administrátor
může vytvořit strom pro jiného uživatele).
Standardní způsob vytváření týmových odkazů je vytvoření nového stromu a jeho přiřazení
uživateli který je moderátorem dané skupiny (vytvořené pomocí příkazu Správa skupin/Vytvořit
skupinu. Tento uživatel potom může garantovat práva na nově vytvořený strom členům dané skupiny
a může přidávat uživatele do své skupiny.
_P;

$help['230'] = <<<_P
<p><strong>Nastavení</strong> - umožňuje změnit uživatelská nastavení.

Pokud není zašjrtnuta volba "Externí příkazové okno", bude se příkazové okno otevírat
na místě SiteBar okna místo toho, aby se otevíralo v novém okně. Některé příkazy se vždy
zobrazují na místě SiteBaru ("Přihlásit", "Odhlásit",  "Založit účet", "Nastavení").
Pokud je zaškrtnuta volba "Ignorovat zprávy o vykonání" nebude se po úspěšném vykonání
příkazů zobrazovat potvrzovací obrazovka. "Označit zabezpečené složky" označuje graficky
to složky, které mají upraveno zabezpečení sdílení. Zaškrtnutí této volby zpomaluje
načítáné SiteBaru.

<p><strong>Členství ve skupinách</strong> - uživatelé mohou opustit libovolnou
skupinu a připojit se k otevřeným skupinám. Uživatelé nemohou opustit skupinu pouze
tehdy, pokud jsou posledním moderátorem ve skupině. V tomto případě musí kontaktovat
administrátora, který má právo skupinu vymazat.

<p><strong>Ověřit E-mail</strong> - umožňuje uživateli verifikovat svou e-mailovou
adresu, což umožňuje využití některých funkcí systému.
_P;

$help['240'] = <<<_P
<p><strong>Správa uživatelů</strong> - zobrazí seznam s uživateli a umužňuje
provádět následující operace s vybraným uživatelem:

<p><strong>Upravit uživatele</strong> - v současné době jediná možnost jak
vyřešit problém zapomenutého hesla je nastavit nové dočasné heslo a zaslat
jej e-mailem uživateli s žádostí o jeho urychlenou změnu. Administrátor může
označit účet jako demo účet. Tato volba znemožní uživateli změnu některých vlastností
(zejména hesla).

<p><strong>Smazat uživatele</strong> - smaže uživatele a zruší všechna jeho členství
ve skupinách. Při vymazání uživatele je nutné přiřadit všechny jeho stromy jinému uživateli.
Není dovoleno smazat uživatele, který je jediným moderátorem některé ze skupin.

<p><strong>Vytvořit uživatele</strong> - stejná funkce jako "Založit účet", je ovšem
určená pro použití administrátorem.
_P;

$help['250'] = <<<_P
<p><strong>Správa skupin</strong> - zobrazí seznam skupin k nimž má dotyčný uživatel
právo administrátora či moderátora a umožní mu provést některou z následujících
funkcí:

<p><strong>Vlastnosti skupiny</strong> - dostupné moderátorům skupiny.
Umožňuje změnit název skupiny a nastavení pro automatické získání členství na
základě e-mailové adresy. Pokud je "Regulární výraz pro automatické členství na
základě e-mailové adresy" vyplněn a nový uživatel vytvoří své konto, s uživatelským
jménem, které splňuje daný regulátní výraz, získá po ověření e-mailu automaticky
členství v dané skupině. Pokud je zaškrtnuta volba "Povolit osobní přihlášení",
může získat členství ve skupině každý uživatel.

<p><strong>Členové skupiny</strong> - pouze moderátoři mohou určovat členy skupiny.
Není možné odstranit ze skupiny její moderátory. Nejdříve je nutné zrušit jejich
moderátorství pomocí nasledujícího příkazu.

<p><strong>Moderátoři skupiny</strong> - přistupné pro moderátory dané skupiny.
Ve skupině musí vždy zůstat alespoň jeden moderátor.

<p><strong>Smazat skupinu</strong> - skupina může být smazána pouze administrátorem.

<p><strong>Vytvořit skupinu</strong> - přístupné pouze pro administrátory. Umožňuje
vytvořit skupinu a specifikovat jejího moderátora.
_P;

$help['260'] = <<<_P
<p><strong>Přidat složku</strong> - přidání podsložky do jiné složky.

<p><strong>Přidat odkaz</strong> - přidání odkazu do jiné složky. Při vyvolání z
bookmarkletu umožňuje uživateli vybrat cílovou složku. V opačném případě je
odkaz vytvořen ve složce pro kterou byl příkaz vyvolán.

<p>

<p><strong>Vlastnosti složky</strong> - umožňuje nastavit vlastnosti složky -
název a popis.

<p><strong>Smazat složku</strong> - smaže složku. Smazaná složka může být obnovena
pomocí příkazu "Obnovit smazané" nebo permanetně smazaná pomocí příkazu "Vysypat
smazané". Uživatel může smazat i svůj strom, toto smazaní je pouze platné pokud dojde
následně i k vysypání. Smazaný strom může být obnoven či vysypán pouze svým vlastníkem.

<p><strong>Vysypat smazané</strong> - odstraní navždy složky a odkazy, které byly
předtím smazané. Po vysypání není technicky možné obnovit vysypané odkazy či
složky!

<p><strong>Obnovit smazané</strong> - umožňuje obnovit vymazané složky či odkazy
a to až dokamžiku jejich vysypání. Smazaná kořenová složka je normálně zobrazena
ikonou s odstíny šedi a je viditelná pouze vlastníkovi stromu. Tímto je vlastníkovi
stromu (a pouze jemu) garantována možnost strom obnovit a tím předejít nechtěnému
smazání odkazů.

<p>

<p><strong>Kopírovat</strong> - zkopíruje složku a její obsah do interní schránky.

<p><strong>Vložit</strong> - je dostupné pouze pokud byl předtím vykonán příkaz
"Kopírovat" či kopírovat odkaz. Příkaz "Vložit" rozpozná zda může uživateli povolit
přesunutí, či pouze kopírování zdrojové složky. Uživatel má ovšem v každém případě
možnost zvolit kopírování.

<p>

<p><strong>Importovat odkazy</strong> - importuje odkazy z externího souboru do
zvolené složky. Během importu se neprovádí žádná validace odkazů aby nedošlo
v žádném případě k timeoutu na straně serveru.

<p><strong>Exportovat odkazy</strong> - exportuje odkaz složky do externího souboru.
Podporované formáty jsou Netscape bookmark file + Opera Hotlist. Prohlížeče
Mozilla používají formát stejný jako Netscape. Internet Explorer má možnost
exportu a importu do a z tohoto formátu.

<p><strong>Ověřit odkazy</strong> - ověžuje odkazy ve složce a podsložkách. 
Během validace je možné zjistit chybějící ikony odkazů či smazat ty ikony, 
které se nenacházejí v mezipaměti ikon a jsou tudíž považované za neplatné.
Zobrazení výsledků testování je prostřednictvím ikon u odkazů. Standarní ikona
odkazu se zobrazí, pokud žádná speciální ikona odkazu není nalezena ale link je funkční.
V případě neplatného odkazu se zobrazí ikona špatného odkazu v ostatních případech 
ikona odkazu dané stránky. V případě validace velkého množství odkazů může dojít
k tomu, že nedojde k jejich úplné validaci. V tomto případě by uživatel měl jednoduše 
obnovit stránku nebo validaci opakovat. Nedávno otestované odkazy již nebudou testovány.
Odkazy považované za neplatné budou zobrazeny v SiteBaru přeškrtnutě.
<p><strong>Zabezpečení</strong> - dostupné pouze pro složky. Umožňuje specifikovat
přístupová práva k celému stromu či jednotlivým jeho podsložkám. Více informací lze
nalézt v sekci "Bezpečnostní Mechanismus".
_P;

$help['270'] = <<<_P
<p><strong>Poslat odkaz</strong> - umožňuje odeslat odkaz e-mailem jinému uživateli.
Uživatelé s ověřenou e-mailovou adresou mohou používat interní mail systém. Ostatní
uživatelé musí použít externí program pro elektronickou poštu.

<p><strong>Kopírovat odkaz</strong> - zkopíruje odkaz do interní schránky.
Pro zkopírovaní či pšesun je nutné použít příkaz "Vložit" na vybrané cílové složce.

<p><strong>Smazat odkaz</strong> - smaže odkaz ze složky. Smazaný odkaz může být
obnoven příkazem "Obnovit smazané".

<p><strong>Vlastnosti</strong> - umožňuje nastavit vlastnosti odkazu. Především
umožňuje označit odkaz jako privátní, takovýto odkaz je pro ostatní uživatele
neviditelný i ve zveřejněné složce.
_P;

$help['300'] = <<<_P
SiteBar 3 je kompletním přepsáním řady 2.x series, čímž reprezentuje další skok
ve vývoji SiteBaru.
<p>
Na rozdíl od řady 2.x nepoužívá SiteBar 3 pro zobrazení stromu odkazů JavaScript.
JavaScript je nicméně nezbytnou součástí pro zobrazování a skrývání složek včetně
změn ikon. Pro plnou funkčnost musí použitý prohlížeč podporovat
<a href="http://www.w3.org/TR/DOM-Level-2-Core/">Document Object Model Level 2</a>.
Výhodou tohoto postupu je velmi rychlé a inkrementální načítání odkazů. Nevýhodou
je, že uživatelé nekomatibilních prohlížečů mají přístup k odkazům pouze na čtení
(což je nicméně stále více než uměla řada 2.x).
<p>
Na serveru jsou data uložena v jednoduché rekurzivní datové struktuře, který je
optimalizovaná pro modifikace. Poskytuje ovšem velmi dobré výsledky pro zobrazování.
Díky použitým indexům by čtení dat nemělo být zpomaleno ani velkým množstvým
zobrazených dat.
_P;

$help['301'] = <<<_P
SiteBar byl testován s následujícími prohlížeči

<ul>
    <li>Mozilla 1.4, 1.5, 1.6
    <li>Mozilla Firebird 0.61, 0.7
    <li>Galeon 1.3.7
    <li>Internet Explorer 6.0 (Avant, MyIE2)
    <li>Opera 7.11, 7.21, 7.23, 7.5 preview 1
</ul>

Následující prohlížeče mají přístup alespoň na čtení:

<ul>
    <li>Pocket Internet Explorer 2002
    <li>Netscape Navigator 4.78
</ul>
_P;

$help['302'] = <<<_P
SiteBar 3 provádí dvojí jištění v otázce uživatelských práv. Každý uživatel vidí
pouze podmnožinu příkazů, které může vzhledem ke svým právům používat. Každý
příkaz je při odeslání ještě jednou zkontrolován a to v okamžiku těsně před
jeho vykonáním.
<p>
Systém disponuje třemi základními rolemi uživatelů: řadový uživatel, moderátor a
administrátor. Moderátoři jsou uživatelů jimž byla svěřena správa skupiny pří jejich
vytvoření administrátorem nebo jimž bylo toto právo uděleno jiným moderátorem.
Role moderátora je svázána vždy pouze s určitou skupinou. Administrátoři jsou
členové skupiny Admin včetně uživatele založeného při vykonání příkazu "Set Up".
Administrátoři nemají právo jednat jako moderátoři. Maji ovšem právo, celou skupinu
smazat.
<p>
SiteBar 3 byl vyvinutr s cílem umožni sdílení odkazů pro více týmů. To znemaná, že
více uživatelů může sdílet mezi sebou odkazy. Pro zajištění úschovy ciltivých
týmových odkazů byl vyvinut bezpočností mechanismus,
<p>
Základní kamenem tohoto mechanismu je fakt, že vlastník kořenové složky kterékoholiv
stromu odkazů má ke všem podřízeným odkazům neomezená práva. Při vytvoření účtu
je pro každého uživatele vytvořena kořenová složka. Administrátor může dodatečně
vytvořit nový strom, či povolit uživatelům vytvářet další vlastní stromy.
<p>
Pro každý strom, jehož je uživatel vlastníkem, může specifikovat jaká práva
mají jednotlivé skupiny ke složkám tohoto stromu:

<p><strong>Číst</strong> - právo na čtení odkazů, pokud nechce uživatel skupiny
tyto odkazy číst, může opustit skupinu.

<p><strong>Přidat</strong> - umožňuje přidat složku či odkaz.

<p><strong>Změnit</strong> - změna vlastností složky či odkazu.

<p><strong>Smazat</strong> - smazání složky či odkazu.

<p><strong>Vysypat</strong> - právo vysypání smazaných odkazů či složek. Spolu s právem
k mazání umožňuje přesun složky do jiného stromu jiného uživatele.

<p><strong>Garantovat</strong> - toto právo umožňuje jeho držiteli specifikovat
práva stejně jako může vlastník stromu.

<p>
Práva jsou vždy zděděná od rodičovské složky. Kořenová složka nemá defaultně
nastavena žádná práva. Uživatel může specifikovat restrikci práv, která je platná
na pro podřízené složky. Pokud jsou právo pro složku stejná jako pro nadřízenou
složku, je tato definice vymazána a požadovaného efektu je dosaženo děděním.
<p>
Moderátor skupiny má vždy právo zkušit jakékoliv právo garantované jeho skupině.
<p>
Dodatečně ke bezpečnostímu mechanismu složek existuje i řešení pro odkazy, které
umožňuje uchovávat privátní odkazy v jinak zveřejněným složkám. Vlastník stromu
odkazů může označit odkaz jako soukromý čímý zmenožní jeho zobrazení a zpracování
jakýmkoliv jiným uživatele. Nezní nezbytně nutné označovat všechny odkazy jako
soukromé pokud není složka sdílená - výchozí nastavení je, že žádná složka není
sdílená.
<p>
Čím vyšší je počet složek s definovanými právy, tím pomalejší je jejich načítání
pro všechny uživatele. Zabezpečení složek by nemělo být používáno z tohoto
důvodu zejmená na hluboko zanořených stromech odkazů.
<p>
Pokud administrátor SiteBaru zvolí "Osobní mód" není příkaz "Zabezpečení"
dostupný. Místo něho se ve vlastnostech složky zobrazí volba "Zvěřejnit složku".
Jejím zaškrtnutím dojde ke zveřejnění složky pro všechny uživatele. V osobním
módu není možné zrušít sdílení podřízené složky, který je sdílená přes složku
rodičovskou. Je možné přepínat bez problému mezi osobní a skupinovým módem,
nicméně není možné v osobním módu odstranit práva pro jinou skupiny než "Everyone".
_P;

$help['303'] = <<<_P
SiteBar umožňuje tvorbu uživatelských témat. Pro jejich tvorbu je nutná dobrá
znalost CSS. Pro tvorbu nového tématu je doporučené zkopírovat existující
a postupně jej upravovat. Zkopírování se provádí kopií vybraného téma v adresáři
"skins". Každé téma se skládá z několika obrázků (použítý je formát PNG z důvodu
stále existujícího patentu pro formát GIF do roku 2004), jednoho style-sheetu
"sitebar.php" a PHP souboru se zavěšeními "hook.php". V souboru se zavěšeními
je možné změnut hlavičku či zápatí SiteBar instalace.
<p>
Někteřé administrátoři mohou chtít vytvořit téma, které vhodně doplňuje design jejich
serveru. V tomto případě je doporučeno vytvořit vlastní téma a fyzicky odstranit
ostatní téma smazaním příslušného adresáře v adresáři "skins".
<p>
Vytvořená témata je možné poslat autorům SiteBaru pro posouzení. Předtím je ovšem
nutné téma vyladit v poslední stabilní vývojové verzi. Zdařilá téma budou
začleněna do distribuce a budou automaticky upravena vývojovým týmem v případě
nutných technických změn v dalších verzích. Podmínka pro distribuci dalších verzí
je přítomnost loga SiteBar a SourceForge. Logo SiteBar může být zobrazeno libovolným
způsbem.
_P;

?>
