<?php

$para = array();

$para['index::tip'] = <<<_P
Bruk denne siden for å starte en instans av eller installere SiteBar som panel i din nettleser.
Det er anbefalt å bokmerke en av lenkene merket med "*" i stedet for å bokmerke denne siden.
Denne siden finner du tilbake SiteBar-panelet ved å klikke på logoen på toppen.
_P;

$para['index::any_browser'] = <<<_P
Bruk <a title="SiteBar" href="%s/sitebar.php">SiteBar</a>*
i dette vinduet - eller åpen et sprettopp-vindu som et
<a title="SiteBar" href="%s">SiteBar</a>-lignende* vindu.
_P;

$para['index::ie_install'] = <<<_P
<a href="?install=1">Installer</a> til / <a href="?install=0">Deinstaller</a> fra Internet Explorers "Explorer-felt" (Explorer Bar - panelet til venstre) eller til MSIEs kontekstmeny - krever endringer i Windows-registeret, og omstart av systemt for at alt skal virke. Avhengig av dine rettigheter kan bare enkelte funksjoner installeres. <p class='comment'>Åpne SiteBars explorer-felt fra meyen Vis/Explorer-felt eller
bruk funksjonen <b>Tilpass...</b> verktøyrader for å få SiteBarpanelets av/på-knapp til å vises på vertøylinja. Høyreklikk hvor som helst på siden eller over en lenke for å legge til en side eller lenke til SiteBar.</p>
_P;

$para['index::ie_search'] = <<<_P
Legg <a title="SiteBar" href="javascript:void(_search=open('%s/sitebar.php','_search'))">
SiteBar</a>* midlertidig til Internet Explorers søkepanel. <p class='comment'>Bruk denne
hvis du ikke har rettigheter til å å kjøre installasjonen over.</p>
_P;

$para['index::mozilla'] = <<<_P
Legg til et Mozilla/Netscape-kompatibelt 
<a title="SiteBar"
href="javascript:sidebar.addPanel('SiteBar','%s/sitebar.php','')">
sidepanel</a> - skru av/på visning med F9.
<p class='comment'>Mozilla Firefox-brukere bør bruke lenka overfor for å opprette
bokmerke som åpner i sidepanelet når den klikkes. Mozillazine 
<a href="http://forums.mozillazine.org/viewtopic.php?t=36166">emne</a> beskriver hvordan
du bruker <a href="http://www.sitebar.org/plugin/firefox/SiteBar.xpi?url=%s">SiteBars</a> 
sidepanel-utvidelse og menyutvidelsen <a href="http://www.sitebar.org/plugin/firefox/WebLinks_for_SiteBar.xpi?url=%s">WebLenker</a> med SiteBar.
</p>
_P;

$para['index::opera'] = <<<_P
Legg til Operas <a title="SiteBar" rel="sidebar" href="%s/sitebar.php">Lister</a>
som et panel.
<p class='comment'>Bruk Ctrl+klikk i stedet for Høyre+klikk for å vise kontekstmenyen
for mapper og lenker.</p>
_P;

$para['index::myie2_install'] = <<<_P
Last ned tilpasset
<a href="http://www.sitebar.org/plugin/myie2/?sidebar=%s">sidepanel (bar)</a>
og/eller
<a href="http://www.sitebar.org/plugin/myie2/?toolbar=%s">Legg aktiv fane til SiteBars</a>
vertkøyrad-plugin.

_P;

$para['index::bookmarklet'] = <<<_P
<a href="javascript:%s">Legg side til SiteBar</a>* - høyreklikk på denne lenka og
legg den til dine favoritter/bokmerkerad. Det vil tillate deg senere å legge inn 
websider du har oppe i nettleseren din, i SiteBar. MSIE-brukere kan bruke
installereren og kontekstmenyen i stedet.
_P;

$para['index::copyright2'] = <<<_P
Copyright &#169; 2003,2004 <a href='http://brablc.com/'>Ondřej Brablc</a>
og <a href='http://www.sitebar.org/team.php'>SiteBar-teamet</a>.
Support-<a href='http://sourceforge.net/forum/forum.php?forum_id=261003'>forum</a>.
_P;

$para['command::contact'] = <<<_P
Melding:

%s


--
SiteBar-installasjon %s.
_P;

$para['command::contact_group'] = <<<_P
Gruppe: %s
Melding:

%s


--
SiteBar-installasjon %s.
_P;

$para['command::delete_account'] = <<<_P
<h3>Vil du virkelig slette din konto?</h3>
Det finnes ikke noen måte å gjøre om på denne endringen!<p>
Alle dine trær vil bli overført til systemets administrator.
_P;

$para['command::email_link_href'] = <<<_P
<p>Send epost via din standard 
<a href='mailto:?subject=Websted: %s&body=Jeg har funnet et websted som du kan være interessert i.
 Ta en kikk på: %s
 --
 Sendt deg via SiteBar %s
 Åpen kildekode bokmerketjener http://www.sitebar.org'>epostklient</a>
_P;

$para['command::email_link'] = <<<_P
Jeg har funnet et websted som du kansje er interessert i.
Ta en kikk på:

    "%s" %s

%s

--
Sendt deg via SiteBar %s
Bokmerketjener i åpen kildekode http://www.sitebar.org
_P;

$para['command::verify_email'] = <<<_P
Du har forespurt om epost-validering som tillater deg å delta i
grupper med automatisk deltakelse med "regular expressions" og
som tillater deg å bruke SiteBars epostfunksjoner.

Vennligst klikk på følgende lenke for å verifisere din epost:
    %s
_P;

$para['command::import_bk'] = <<<_P
<br>
Lokale favoritter kan eksporteres til en lokal fil ved å bruke denne javascript-<a href='javascript:window.external.ImportExportFavorites(false,"")'>funksjonen</a>.
_P;

$para['command::export_bk'] = <<<_P
<br>
Eksporterte bokmerker kan importeres til dine lokale favoritter ved
å bruke denne javascript-<a href='javascript:window.external.ImportExportFavorites(true,"")'>funksjonen</a>.
_P;

$para['command::noiconv'] = <<<_P
<br>
Codepage-konvertering er ikke installert på denne SiteBar-tjeneren.
<br>
_P;

$para['command::security_legend'] = <<<_P
Rights:
L<strong>e</strong>s,
<strong>L</strong>egg til,
<strong>M</strong>odifiser
<strong>S</strong>lett,
<strong>R</strong>ens,
<strong>T</strong>illat
_P;

$para['command::purge_cache'] = <<<_P
<h3>Vil du virkelig fjerne alle favikoner fra mellomlageret?</h3>
_P;

$para['usermanager::auto_verify_email'] = <<<_P
Din epostadresse passer med regler for automatisk deltakelse i 
følgede lukkede gruppe(r):
    %s.

For å godkjenne ditt medlemsskap, må din epostadresse verifiseres.
Vennligst klikk på følgende lenke for å verifisere den:
    %s
_P;

$para['usermanager::signup_info'] = <<<_P
Bruker "%s" <%s> har registrert seg på din SiteBar-installasjon %s.
_P;

$para['hook::statistics'] = <<<_P
Røtter {roots_total}.
Mapper {nodes_shown}/{nodes_total}.
Lenker {links_shown}/{links_total}.
Brukere {users}.
Grupper {groups}.
SQL-spørringer {queries}.
DB/Total tid {time_db}/{time_total} sec ({time_pct}%).
_P;

?>
