<?php 

$help = array();

$help['100'] = <<<_P
Les fonctions SiteBar sont accessibles à partir de <strong>du menu utilisateur</strong> et à partir du menu contextuel du répertoire ou du lien. Le menu utilisateur apparait en haut du menu de SiteBar, et dans le menu contextuel accessible en effectuant un clique droit sur un répertoire ou lien. Opéra et les utilisateurs Mac peuvent utiliser le CTRL+Clique également. Dans ce cas, quand un évenement CTRL+clique n&#39;est pas reconnu il est possible d&#39;afficher le menu sous forme d&#39;icone à partir de la commande "Paramètre utilisateur". Quand cette option est activée vous pourrez voir un petit menu sous forme d&#39;icone en dessous de l&#39;icone du répertoire ou du lien. Cliqué dessys pour faire apparaitre le menu contextuel.
<p>
Tous deux peuvent faire apparaitre différentes sous-foncitons pour défférents utilisateurs basés sur leur droit d&#39;accès sur le système. Quelques éléments peuvent être désactivés dnas le menu contextuel du fait des droits sur le noeud et du status courant de l&#39;application. Les commandes sont executées via la fenêtre commande.
_P;

$help['101'] = <<<_P
Cliquez sur un répertoire ou un lien avec la souris et déplacé le curseur sur un autre répertoire tout en maintenant le bouton enfoncé. La fonction saisir est signalée par la mise en surbrillance du répertoire cible. RElachez le bouton pour déposer le lien ou le répertoire dans le répertoire mise en surbrillance.
<p>
Saisir & Déposer n&#39;est pas implémenté pour les navigateurs Opera. La fonction Copier & Coller doit être utilisé en remplacement.
_P;

?>
