<?php

$help = array();

$help['100'] = <<<_P
您可以从<strong>用户选项</strong>、文件夹和链接的 <strong>右键选项</strong>中使用所有 SiteBar 的功能。用户选项显示在 SiteBar 的最底部，而右键选项则可从目录或链接中按鼠标右键取得。Opera 和苹果计算机的用户可用 Ctrl-click 代替。万一 Ctrl-click 不能被系统用辨认的话，您可以到「用户设定」中开启「显示选项图标」功能。当您选中这选项后，文件夹或链接旁边会显示一个细小的选项图示。按下图示就可以开启右键选项。
<p>
基于用户权限的不同，右键和用户选项所显示的子功能会有所不同。有些项目可能被系统失效。指令会在指令窗口中执行。
_P;

$help['101'] = <<<_P
用您的鼠标按下任何一个文件夹或链接，途中不要放手，将鼠标光标拉到另一个文件夹上。拖拉成功的话，目的地目录将会被标亮。放开鼠标键将所选的链接或文件夹放到被标亮的目录中。
<p>
SiteBar team 并未为 Opera 浏览器植入 Drag & Drop 功能。Opera 用户应以 Copy and Paste 代替。
_P;

$help['102'] = <<<_P
使用「bookmarklet」是新增链接最方便的途径。您可以从 SiteBar 系统的主页中安装 bookmarklet，预设主页是可以从 SiteBar 最顶部的商标链接得到的。如果 Internet Explorer 用户使用主页介绍的安装程序安装 bookmarklet 的话，就可以用右键选项新增链接。
_P;

$help['103'] = <<<_P
<@>
<p><strong>搜寻</strong> - 允许在所有已显示的链接中搜寻。您可以用以下的前缀 (prefixes) 指定搜寻的条件：<strong>url:</strong>, <strong>name:</strong>, <strong>desc:</strong>, <strong>all:</strong>。预设的前缀是<strong>name:</strong>。如果系统找到符合搜寻条件的链接或文件夹时，该链接或文件夹会被颜色标亮，而且会有一个伴带着一些数据的 javascript 确认窗口。用户可以选择继续或停止搜寻。

<p><strong>标亮</strong> - 与搜寻一样，不过没有 javascript 告示。

<p><strong>全部收缩 / 展开</strong> - 收缩 / 展开所有节点。当这项目第二次被按时 (当时所有节点已经收缩)，节点就会展开。

<p><strong>重新加载</strong> - 由服务器重新加载所有链接。
_P;

$help['200'] = <<<_P
指令已分类到几个合理的群组。请从群组中选择以得到指令的说明。
_P;

$help['210'] = <<<_P
<p><strong>登入</strong> - 登入用户到系统，cookies 会记住用户的登入状态。您可以指定 cookies 的期满时间。

<p><strong>注销</strong> - 从系统注销用户。使用公共计算机时必须注销系统。在登入系统时选择「直至我关闭浏览器」时，浏览器关闭后会自行注销系统。

<p><strong>新用户登记</strong> - 允许访客登记以使用系统。系统会根据电子邮件去规定用户是否合格参加一些群组。在这个情况下，用户的电邮地址需要被系统验证。验证电邮会自动寄到用户登记的电邮地址当中。系统管理员可以随时停止新用户登记。
_P;

$help['220'] = <<<_P
<p><strong>设定</strong> - 这是 SiteBar 安装过程中，设定好数据库以后，第一个管理员见到的指令。系统会新增一个管理员账户和设定好 SiteBar 的一些基本参数。当「个人模式」启动后，只有一部分的功能可以设定。

<p><strong>SiteBar 选项</strong> - 管理员可以稍后设定的选项。管理员是管理员群组的其中一员，是在系统安装过程中「设定」指令新增的用户。您可以查阅「设定」说明了解电邮功能。日后的版本将会有更多电邮功能。

<p><strong>新增树状目录</strong> - 视乎 SiteBar 选项中设定，只有管理员和/或电邮已受验证的用户可以新增树状目录。当新增一个树状目录后，该目录必须同现有的用户联系在一起 (只有管理员可以为其它用户新增树状目录)。新增一个团体书签的标准方法，就是新增一个树状目录，然后将之分派到控制该群组的用户，该群组可以在「新增群组」中新增。如此这个用户就可以拥有已新增树状目录的权限，和将用户加入该群组的能力。
_P;

$help['230'] = <<<_P
<p><strong>用户设定</strong> - 变更用户选项。当「External Commander」选项被去除后，指令窗口会在 SiteBar 同一窗口中开启，而不会另开新窗口。有些指令会永远在同一窗口中开启 (「登入」、「注销」、「新用户登记」和「用户设定」)。当「略过系统执行讯息」选项被选中后，指令执行成功后将不会有确认画面显示。这个项目会减慢 SiteBar 的显示。

<p><strong>会员资格</strong> - 用户可以退出任何群组和加入开放的群组。不过如果用户是最后一位操作员的话，将不能退出该群组。在这情况下，用户需要联络管理员删除该群组。

<p><strong>验证电邮</strong> - 允许用户验证电邮以使用其它的系统功能。
_P;

$help['240'] = <<<_P
<p><strong>管理用户事项</strong> - 显示一个用户列表框和允许以下命令被执行。

<p><strong>修改用户</strong> - 目前修复一个忘记的密码唯一的方法，是在此设定一个暂时密码，将之寄到该用户再要求用户更改。管理员可以标记账户成示范用账户，示范用账户不允许用户更改某些选项，特别是密码。

<p><strong>删除用户</strong> - 删除用户和他的会员资格。属于该会员的树状目录会被重新分派到另一个用户。系统不能删除群组唯一操作员的账户。

<p><strong>新增用户</strong> - 和「新用户登记」一样，不过这是为管理员而设。由这选项新增的用户，其电邮地址会被当作已验证。
_P;

$help['250'] = <<<_P
<p><strong>管理群组事项</strong> - 显示一个群组列表框和允许以下命令被执行。

<p><strong>群组选项</strong> - 群组操作员能够进入这个选项。允许更改群组名称注释与 Auto Join E-Mail 正规形式。当「Auto Join E-Mail RegExp」被选取而新登记的电邮地址又符合指定形式时，系统会自动寄出一封验证电邮到新登记用户的电邮户口当中，验证后该用户就自动成为群组的一员。当「允许管理员新增任何用户」被选中时，电邮是不须被验证而用户可以自动成为会员。

<p><strong>群组用户</strong> - 只有操作员才可以选择那一个用户成为群组的会员。其它操作员无法不被选取，操作员的身份先要用以下的指令除去。

<p><strong>群组操作员</strong> - 群组操作员能够进入这个选项。每一个群组最少要有一位群组操作员。

<p><strong>删除群组</strong> - 只有管理员才能够进入这个选项，删除其中一个群组和属于该群组的所有会员资格。

<p><strong>新增群组</strong> - 只有管理员才能够进入这个选项，新增一个群组和指定第一位群组操作员。
_P;

$help['270'] = <<<_P
<p><strong>电邮这个链接书签</strong> - 允许电邮一个书签 (链接)到另一位朋友。已验证电邮的用户，内部电邮系统可能被运用，否则外部电邮系统就会被启动。

<p><strong>复制链接</strong> - 复制链接到内部剪贴簿。在文件夹使用「贴上」指令以复制 / 移动链接到节点上。

<p><strong>删除链接</strong> - 从节点上删除链接。已删除的链接可以在主目录上使用「反删除」指令反删除您的链接。


<p><strong>选项</strong> - 修改链接的选项。允许用户设定成私人的链接。
_P;

$help['301'] = <<<_P
SiteBar 已经在以下浏览器中成功测试过：

<ul>
    <li>Mozilla 1.4, 1.5a
    <li>Mozilla Firebird 0.61, 0.7
    <li>Galeon 1.3.7
    <li>Internet Explorer 6.0
    <li>Opera 7.11, 7.21
</ul>

而使用以下浏览器只允许读取 (read-only)：

<ul>
    <li>Pocket Internet Explorer 2002
    <li>Netscape Navigator 4.78
</ul>
_P;

?>
