<?php

$para = array();

$para['index::tip'] = <<<_P
Spuštění a instalační stránka pro běžící instanci SiteBar bookmark serveru.
Doporučujeme vytvořit si odkaz na jeden z odkazů označených "*" místo vytváření
odkazu na tuto stránku. Tato stránka může být kdykoliv otevřena ze SiteBar okna
kliknutím na úvodní logo.
_P;

$para['index::any_browser'] = <<<_P
Zobrazit <a title="SiteBar" href="%s/sitebar.php">SiteBar</a>*
v aktuálním okně - nebo otevřít ve vyskakovacím
<a title="SiteBar" href="%s">SiteBar</a>* podobném okně.
_P;

$para['index::ie_install'] = <<<_P
<a href="?install=1">Instalovat</a> / <a href="?install=0">odinstalovat</a>
SiteBar do "panelu aplikace explorer" a kontextového menu - vyžaduje změnu v registrech Windows
a případně restart systému pro úplnou funkčnost. V závislosti na uživatelských právech
je možné, že pouze některé funkce budou dostupné.
<p class='comment'>SiteBar lze otevřít z panely aplikace explorer v menu Zobrazit nebo jej pomocí
funkce pro úpravu panelů přidat mezi ostatní tlačítka.
Pravým kliknutím kdekoliv na stránce nebo na na odkazu lze vyvolat kontextové menu a z něj
přidat stránku či odkaz do SiteBaru.
</p>
_P;

$para['index::ie_search'] = <<<_P
Přidat <a title="SiteBar" href="javascript:void(_search=open('%s/sitebar.php','_search'))">
SiteBar</a>* dočasně do vyhledávacího panelu.
<p class='comment'>Vhodné pro použití při nedostatku práv použít instalaci do panelu.
_P;

$para['index::mozilla'] = <<<_P
Přidat do
<a title="SiteBar"
href="javascript:sidebar.addPanel('SiteBar','%s/sitebar.php','')">
sidebar</a> pro prohlížeče kompatibilní s Mozillou/Netscapem.
Zobrazení/schování se provádí klávesou F9.
<p class='comment'>Uživatelé prohlížeče Mozilla Firefox mohou použít výše uvedený link pro
přidání odkazu mezi vlastní stránky. Při kliknutí na takto vytvořený odkaz se SiteBar zobrazí
v postranním panelu. V <a href="http://forums.mozillazine.org/viewtopic.php?t=36166">článku</a>
na serveru Mozillazine jsou uvedeny informace pro použití 
<a href="http://www.sitebar.org/plugin/firefox/SiteBar.xpi?url=%s">SiteBar</a> rozšíření pro
postranní lištu a <a href="http://www.sitebar.org/plugin/firefox/WebLinks_for_SiteBar.xpi?url=%s">WebLinks</a>
rozšíření pro menu.

</p>
_P;

$para['index::opera'] = <<<_P
Přidat do <a title="SiteBar" rel="sidebar" href="%s/sitebar.php">Hotlistu</a> Opery jako postranní panel.
<p class='comment'>Místo pravého tlačítka myši pro vyvolání kontextového menu musí uživatelé
Opery použít levé tlačítko se stisknutou klávesou Ctrl. Případně v "Nastavení" zvolit "Zobrazit
menu ikony" a použít tyto.
</p>
_P;

$para['index::myie2_install'] = <<<_P
Stáhnout přizpůsobený plugin pro
<a href="http://www.sitebar.org/plugin/myie2/?sidebar=%s">sidebar/postranní lištu</a>
a/nebo plugin 'Add Current Tab to SiteBar' pro
<a href="http://www.sitebar.org/plugin/myie2/?toolbar=%s">toolbar/nástrojovou lištu</a>.
_P;

$para['index::bookmarklet'] = <<<_P
<a href="javascript:%s">Přidat stránku do SiteBaru</a>* - vytvořením odkazu na tento odkaz
(například stisknutím pravého tlačítka myši a výběrem z menu) je možné v budoucnu přidat
právě zobrazenou stránku jedním kliknutím do SiteBaru. Uživatelé MS IE mohou místo tohoto
řešení používat instalátor a kontextové menu.
_P;

$para['index::copyright2'] = <<<_P
Copyright &copy; 2003,2004 <a href='http://brablc.com/'>Ondřej Brablc</a> a <a href='http://www.sitebar.org/team.php'>SiteBar tým</a>. <a href='http://sourceforge.net/forum/forum.php?forum_id=261003'>Fórum</a> uživatelské podpory.
_P;

$para['command::contact'] = <<<_P
Zpráva:

%s


--
SiteBar instalace na adrese %s.
_P;

$para['command::contact_group'] = <<<_P
Skupina: %s
Zpráva:

%s


--
SiteBar instalace na adrese %s.
_P;

$para['command::delete_account'] = <<<_P
<h3>Skutečně smazat účet?</h3>

Neexistuje možnost jeho obnovení!<p>
Všechny nesmazané stromy budou převedeny na administrátora.
_P;

$para['command::email_link_href'] = <<<_P
<p>Poslat e-mail lokálním
<a href='mailto:?subject=Webova stranka: %s&amp;body=Tato webova stranka stoji za shlednuti.
 Adresa: %s
 --
 Odeslano z aplikace SiteBar na adrese %s
 Open Source Bookmark Server http://www.sitebar.org
'>poštovním programem</a>
_P;

$para['command::email_link'] = <<<_P
Tato webova stranka stoji za shlédnutí.
Adresa:

    "%s" %s

%s

--
Odesláno z aplikace SiteBar na adrese %s
Open Source Bookmark Server http://www.sitebar.org
_P;

$para['command::verify_email'] = <<<_P
Bylo vyžádáno ověření e-mailové adresy na kterou byl zaslán tento dopis.
Ověčení umožňuje získání členství v některých skupinách na základě regularního
výrazu. Dále ověření umožňuje uživateli využívat funkce spojené se
zasíláním e-mailů.

Kliknutím na následující odkaz dojde k ověření e-mailové adresy:

    %s
_P;

$para['command::import_bk'] = <<<_P
<br>
Lokalní "Oblíbené" odkazy mohou být exportovány do lokálního souboru
pomocí následující javascript
<a href='javascript:window.external.ImportExportFavorites(false,"")'>funkce</a>.
_P;

$para['command::export_bk'] = <<<_P
<br>
"Oblíbené" odkazy mohou být importovány do lokalních "Oblíbených" odkazů
pomocí následující javascript
<a href='javascript:window.external.ImportExportFavorites(true,"")'>funce</a>.
_P;

$para['command::noiconv'] = <<<_P
<br>
Konverze znakových stránek není na této instalaci SiteBaru dostupná.
<br>
_P;

$para['command::security_legend'] = <<<_P
Práva:
<strong>Č</strong>íst,
<strong>P</strong>řidat,
<strong>Z</strong>měnit,
<strong>S</strong>mazat,
<strong>V</strong>ysypat,
<strong>G</strong>arantovat
_P;

$para['command::purge_cache'] = <<<_P
<h3>Skutečně vymazat mezipaměť ikon odkazů?</h3>
_P;

$para['usermanager::auto_verify_email'] = <<<_P
E-mailová adresa na kterou přišel tento dopis splňuje pravidla
pro automaticke členství v následujících uzaveřených skupinách:
    %s.

Pro potvrzení členství v těchto (této) skupině je nutné ověřit
e-mailovou adresu. Kliknutím na následující odkaz dojde k ověření
e-mailove adresy:

    %s
_P;

$para['usermanager::signup_info'] = <<<_P
Uživatel "%s" <%s> si vytvořil účet v SiteBar instalaci na adrese %s.
_P;

$para['hook::statistics'] = <<<_P
Stromů {roots_total}. Složek {nodes_shown}/{nodes_total}. Odkazů {links_shown}/{links_total}. Uživatelů {users}. Skupin {groups}. SQL dotazů {queries}. DB/Celkový čas {time_db}/{time_total} sec ({time_pct}%).
_P;

?>
