<?php

$text = array
(
'The Bookmark Server for Personal and Team Use' => 'El Servidor de Tus Favoritos para uso Personal y en Equipo',
'SiteBar Homepage' => 'Página Principal de SiteBar',
'SiteBar Installation & Launcher' => 'Instalación y ejecución de SiteBar',
'Any Browser' => 'Cualquier Navegador',
'Content Bookmarklets' => 'Añade la página que estás visitando a SiteBar ',
'Bookmarklet' => 'Marcador',
'Your Language' => 'Español',
'Charset in MS Windows' => 'ISO-8859-1',
'Add Link to SiteBar' => 'Agregar Enlace a SiteBar',
'Add Page to SiteBar' => 'Agregar Web a SiteBar',
'Error' => 'Error',
'Warning' => 'Advertencia',
'Unknown' => 'Desconocido',
'Search' => 'Buscar',
'Highlight' => 'Resaltar',
'Collapse/Expand All' => 'Comprimir/Expandir Todos',
'Reload' => 'Actualizar',
'Reload with Hidden Folders' => 'Actualizar con las carpetas ocultas',
'Backup Log In' => 'Entrar a Copia Seguridad',
'Backup Log Out' => 'Salir de Copia Seguridad',
'Commander' => 'Comandante',
'Add Folder' => 'Añadir Carpeta',
'Add Link' => 'Añadir Enlace',
'Contact Admin' => 'Contactar con Administrador',
'Contact Moderator' => 'Contactar con Moderador',
'Copy' => 'Copiar',
'Copy Link' => 'Copiar Enlace',
'Create Group' => 'Crear Grupo',
'Create Tree' => 'Crear Árbol',
'Create User' => 'Crear Usuario',
'Custom Order' => 'Petición del Cliente',
'Delete Folder' => 'Borrar Carpeta',
'Delete Group' => 'Borrar Grupo',
'Delete Link' => 'Borrar Enlace',
'Delete Account' => 'Borrar Cuenta',
'Delete User' => 'Borrar Usuario',
'Delete Tree' => 'Borrar Arbol',
'Display Topic' => 'Mostrar Tópico',
'Email Link' => 'Enviar Enlace por Email',
'Export Bookmarks' => 'Exportar Favoritos',
'Export Description' => 'Exportar Descripción',
'Favicon Management' => 'Administración de Favicones',
'Folder Properties' => 'Propiedades de la Carpeta',
'Group Members' => 'Miembros del Grupo',
'Group Moderators' => 'Moderadores del Grupo',
'Group Properties' => 'Propiedades del Grupo',
'Help' => 'Ayuda',
'Hide Folder' => 'Ocultar Carpeta',
'Import Bookmarks' => 'Importar Favoritos',
'Import Description' => 'Importar Descripción',
'Log In' => 'Entrar',
'Log Out' => 'Salir',
'Maintain Groups' => 'Mantenimiento de Grupos',
'Maintain Users' => 'Mantenimiento de Usuarios',
'Maintain Trees' => 'Mantenimiento de Arboles',
'Membership' => 'Membresía',
'Modify User' => 'Modificar Usuario',
'Order of Trees' => 'Orden de los Arboles',
'Paste' => 'Pegar',
'Properties' => 'Propiedades',
'Purge Cache' => 'Purgar la Cache',
'Purge Folder' => 'Purgar Carpeta',
'Retrieve Link Information' => 'Recuperar Información de los Enlaces',
'Security' => 'Seguridad',
'Send Email to Members' => 'Enviar Email a los Miembros',
'Send Email to Moderators' => 'Enviar Email a los Moderadores',
'Send Email to User' => 'Enviar Email al Usuario',
'Send Email to All' => 'Enviar Email a Todos',
'Show All Icons' => 'Mostrar todos los iconos',
'Set Up' => 'Establecer',
'Sign Up' => 'Darse de Alta',
'SiteBar Settings' => 'Preferencias de SiteBar',
'Undelete' => 'Restaurar',
'Unhide Trees' => 'Mostrar Arboles',
'Unhide Subfolders' => 'MostrarSubcarpetas',
'User Settings' => 'Preferencias de Usuario',
'Personal Data' => 'Datos Personales',
'Verify Email' => 'Verificar Email',
'Verify Email Code' => 'Verificar Código de Email',
'Admin Password' => 'Administrar Clave',
'Allow Anonymous Contact' => 'Permitir Contacto Anónimo',
'Allow Contact' => 'Permitir Contactar',
'Allow Given Membership' => 'Permitir dar Membresía',
'Allow Info Mail' => 'Permitir Información por Email',
'Allow Noninteractive Mode' => 'Permitir Modo no Interactivo',
'Allow Self Add' => 'Permitir Auto Añadir',
'Allow Sign Up' => 'Permitir Inscribirse',
'Auto Join E-Mail RegExp' => 'Auto Unirse E-Mail RegExp',
'Auto Retrieve Favicon' => 'Auto Recuperar Favicon',
'Bookmark File' => 'Archivo Favoritos',
'Codepage' => 'Página de Código',
'Comment' => 'Comentario',
'Content Only' => 'Contenido Solamente',
'Create New Sub Folder' => 'Crear Nueva Subcarpeta',
'Decode Using' => 'Decodificar Usando',
'Decorate ACL Folders' => 'Decorar Carpetas ACL',
'Default Search In' => 'Búqueda por Defecto',
'Default Skin' => 'Skin por Defecto',
'Default Language' => 'Idioma Predeterminado',
'Delete Content Only' => 'Borrar contenido Solamente',
'Demo Account' => 'Cuenta Demo',
'Description File' => 'Descripción Archivo',
'Description Import/Export' => 'Descripción Importar/Exportar',
'Description' => 'Descripción',
'E-mail Verified' => 'E-mail Verificado',
'E-mail' => 'E-mail',
'Encode Using' => 'Codificar Usando',
'Extern Commander' => 'Comandante Externo',
'Favicon' => 'Favicon',
'Feedback or Other Comment' => 'Sugerencias y Comentarios',
'File Type' => 'Tipo de Archivo',
'Folder Name' => 'Nombre de Carpeta',
'From' => 'Desde',
'Group Name' => 'Nombre del Grupo',
'Help Topic' => 'Ayuda Temática',
'Keep In Cache' => 'Mantener en Cache',
'Language' => 'Idioma',
'Link Description Length' => 'Enlazar Descripción Longitud ',
'Link Name' => 'Enlazar Nombre',
'Maximal Icons per User' => 'Iconos máximos por Usuario',
'Maximal Icons Total' => 'Iconos máximos en Total',
'Maximal Icon Size' => 'Tamaño máximo de los Iconos',
'Maximal Icon Age' => 'Antigüedad máxima de los iconos',
'Mode' => 'Modo',
'Moderator' => 'Moderador',
'New Tree Owner' => 'Nuevo Propietario de Árbol',
'Old Password' => 'Clave Antigua',
'Only to Verified Emails' => 'Solamente para Email verificados',
'Owner' => 'Propietario',
'Parent Folder' => 'Carpeta Raíz',
'Password' => 'Clave',
'Paste Mode' => 'Modo de Pegar',
'Personal Mode' => 'Modo Personal',
'Private' => 'Privado',
'Publish Folder' => 'Carpeta Pública',
'Real Name' => 'Nombre Real',
'Remember Me' => 'Recuérdame',
'Remember as Default' => 'Recuerda por Defecto',
'Rename Duplicate Links' => 'Renombrar Enlaces Duplicados',
'Repeat Admin Password' => 'Repita Clave Administrador',
'Repeat Password' => 'Repite Clave',
'Respect Allow Info Mail' => 'Considerar Permitir Información por Email',
'Select Group' => 'Selecciona Grupo',
'Select User' => 'Selecciona Usuario',
'Sender E-mail' => 'E-mail del Remitente',
'Show Logo' => 'Muestra Logo',
'Show Menu Icon' => 'Muestra Icono Menú',
'Show Public Bookmarks' => 'Mostrar Favoritos Públicos',
'Show Sponsor' => 'Mostrar Patrocinador',
'Skin' => 'Tema',
'Skip Execution Messages' => 'Saltar Ejecución de Mensajes',
'Source Folder Name' => 'Nombre de la Carpeta Fuente',
'Source Link Name' => 'Nombre del Enlace Fuente',
'Target Folder Name' => 'Nombre de la Carpeta Destino',
'To' => 'A',
'Topic' => 'Tópico',
'Tree Name' => 'Nombre del Árbol',
'Tree Owner' => 'Propietario del Árbol',
'URL' => 'URL',
'Use Compression' => 'Usar Compresión',
'Use Conversion Engine' => 'Usar Motor de Conversión',
'Use E-mail Features' => 'Usar características de E-mail',
'Use Favicons' => 'Usar Favicones',
'Use Folder Hiding' => 'Usar Carpeta Oculta',
'Use Hit Counter' => 'Usar Contador de Visitas',
'Use Outbound Connection' => 'Usar Conexión Saliente',
'Use the Favicon Cache' => 'Usar el Favicon de la Cache',
'Users Can Create Trees' => 'Usuarios Pueden Crear Árboles',
'Your E-mail' => 'Tú E-mail',
'Until I close browser' => 'Hasta que yo Cierre el Navegador',
'12 hours' => '12 horas',
'6 days' => '6 días',
'1 month' => '1 mes',
'No caching' => 'Sin Cache',
'Order of Folders v. Links' => 'Orden de Carpetas v. Enlaces',
'Links first' => 'Enlaces primero',
'Folders first' => 'Carpetas primero',
'Default Link Sort Mode' => 'Modo por defecto de Clasificar los Enlaces',
'Sort Mode' => 'Modo de Clasificación',
'User default' => 'Usar los valores por defecto',
'Custom order' => 'Orden Customizada',
'Alphabetically' => 'Alfabeticamente',
'Most clicked first' => 'Los más usados primero',
'New/changed links first' => 'Enlaces Nuevos/cambiados primero',
'Waiting for visit' => 'Esperar para visitar',
'Anonymous Guest' => 'Invitado anónimo',
'Guest' => 'Invitado',
'Message' => 'Mensaje',
'SiteBar Server' => 'Servidor SiteBar',
'%s - ok.' => '%s -De Acuerdo',
'%s - error!' => '%s - ¡error!',
'SiteBar: Contact Admin' => 'SiteBar: Contactar con Administrador',
'SiteBar: Contact Group Moderator' => 'SiteBar: Contactar con el Moderador del Grupo',
'SiteBar: Email to all SiteBar Users' => 'SiteBAr: Mandar Email a todos los usuarios de SiteBar',
'SiteBar: Email to Group Members' => 'SiteBar: Mandar Email a todos los Miembros del Grupo',
'SiteBar: Email to Group Moderators' => 'SiteBar: Mandar Email al Grupo de Moderadores',
'SiteBar: Email to SiteBar User' => 'SiteBar: Mandar Email al Usuario',
'SiteBar: Email Verification' => 'SiteBar: Verificación del Email',
'SiteBar: New SiteBar User' => 'SiteBar: Nuevo Usuario de SiteBar',
'SiteBar: Web site' => 'SiteBar: Página Web',
'Group' => 'Grupo',
'R' => 'L',
'A' => 'A',
'M' => 'M',
'D' => 'B',
'P' => 'P',
'G' => 'G',
'Ask' => 'Preguntar',
'Move or Copy' => 'Mover o Copiar',
'Copy (Keep Source)' => 'Copiar (Mantener el original)',
'Move (Delete Source)' => 'Mover (Borrar el original)',
'Auto detection' => 'Auto detección',
'Netscape/Mozilla/MS IE' => 'Netscape/Mozilla/MS IE',
'Netscape/Mozilla' => 'Netscape/Mozilla',
'MS Internet Explorer' => 'Ms Internet Explorer',
'Opera Hotlist version 2.0' => 'Favoritos de Opera  version 2.0',
'Admins' => 'Administradores',
'Everyone' => 'Todos',
'%s&#39;s Bookmarks' => '%s&#39;s Favoritos',
'Deleted root %s of %s at %s' => 'Borrado raíz %s de %s a %s',
'All' => 'Todos',
'Name' => 'Nombre',
'Access denied!' => '¡Acceso Denegado!',
'Cannot delete built in group!' => '¡No puedo Borrrar el Grupo Integrado!',
'Cannot delete user because he is the only moderator of the following group(s): %s!' => 'No puedo borrar usuario porque él es el único moderador de el siguiente grupo(s): %s!',
'Cannot export empty description!' => '¡No puedo exportar una descripción vacía!',
'Cannot remove all moderators from a group!' => '¡No puedo quitar todos los moderadores de un grupo!',
'Cannot send email!' => '¡No puedo enviar email!',
'Database corrupted - missing anonymous account!' => '¡Base de datos corrupta - perdida cuenta anónima!',
'Duplicate folder name "%s"!' => '¡Nombre de Carpeta Duplicado "%s"!',
'Duplicate folder name!' => '¡Nombre de Carpeta Duplicado!',
'Duplicate name "%s" in the target folder!' => '¡Nombre Duplicado "%s" en la Carpeta Destino',
'Duplicate name "%s"!' => '¡Nombre Duplicado "%s"!',
'Expected field %s was not filled!' => '¡Campo Esperado%s no fue completado',
'Favicon <img src="%s"> found at url %s.' => 'Favicon <img src="%s">encontrado en %s.',
'Favicon not found!' => '¡No se ha encontrado Favicon!',
'Field %s must be filled!' => '¡El campo %s debe de ser completado!',
'Folder has already been deleted!' => '¡La carpeta ya ha sido borrada!',
'Folder with id %s does not exist!' => '¡La carpeta con %s no existe!',
'Group has already been deleted!' => '¡El Grupo ya ha sido borrado!',
'Group name "%s" is already used!' => '¡El Grupo denominado  "%s" ya está en uso!',
'Invalid code, verification disabled!' => '¡Código inválido, verificación desabilitada!',
'Invalid regular expresssion!' => '¡Expresión regular inválida!',
'Invalid filename or other upload related problem: %s!' => '¡Nombre inválido u otro problema relacionado con Subir: %s!',
'Link already is in the target folder!' => '¡El enlace ya está en la carpeta destino!',
'Link has already been deleted!' => '¡El enlace ya ha sido borrado!',
'Missing command!' => '¡Falta Comando!',
'No user was selected!' => '¡No se ha seleccionado Usuario!',
'Node number %s has ACL record but does not exist!' => '¡El número de nodo %s tiene registro ACL pero no existe!',
'Old password is invalid!' => '¡La clave antigua es inválida!',
'Purge folder to remove it permanently!' => '¡Purgar la carpeta para borrarla permanentemente!',
'The description length exceeds maximum length of %s bytes!' => '¡La longitud de la descripción excede la longitud máxima permitidad de %s biytes!',
'The e-mail %s does not look correct!' => '¡El e-amail %s no parece correcto!',
'The password was not repeated correctly!' => '¡La clave no fue repetida correctamente!',
'There is no content to be deleted!' => '¡No hay contenido para ser borrado!',
'There is nothing to be undeleted!' => '¡No hay nada para ser restaurado!',
'This email is already used. Did you forget your password?' => '¿Este email ya está en uso. Olvidaste tu clave?',
'Tree has already been deleted!' => '¡El árbol ya ha sido borrado!',
'Use "%s" command to delete own account!' => '¡Usar el comando "%s" para borrar tu cuenta!',
'Unknown command!' => '¡Comando Desconocido!',
'Unknown username or wrong password!' => '¡Usuario desconocido o clave incorrecta!',
'Verification e-mail has been sent to your e-mail address!' => '¡Un e-mail de verificación ha sido enviado a tu dirección de e-mail!',
'You have been left as group moderator!' => '¡Tu has sido nombrado moderador de grupo!',
'You are the last moderator of used group(s): %s. Account cannot be deleted!' => 'Tú eres el último moderador del grupo(s): %s. ¡La cuenta no puede ser borrada!',
'%s, welcome to the SiteBar!<p>You have been already logged in.' => '¡%s, bienvenido a SiteBar!!<p> Tú ya has entrado.',
'E-mail %s verified! Any pending memberships were approved.' => '¡E-mail %s verificado! Cualquier membresía pendiente fue aprobada.',
'Link has been added.<p>You must reload your SiteBar in order to see added link!' => 'El enlace ha sido añadido. <p>Tu debes actualizar tu SiteBar para ver el enlace añadido!',
'Imported %s link(s) into %s folder(s) from the bookmark file.' => 'Importados %s enlace(s) en %s carpeta(s) desde el archivo de favoritos.',
'Successful execution!' => '¡Ejecución con éxito!',
'Submit' => 'Enviar',
'Reset' => 'Restablecer',
'Reload SiteBar' => 'Actualizar SiteBar',
'Close' => 'Cerrar',
'Return' => 'Volver',
'Backup Return to SiteBar' => 'Restaura copia de Seguridad en SiteBar',
'Cannot open file!' => '¡No puedo abrir el archivo!',
'Unknown bookmark file format!' => '¡Formato de Favoritos desconocido!',
'File is empty!' => '¡El archivo está vacío!',
'Character set overriden from document to %s!' => '¡Conjunto de Caracteres del documento anulados  %s!',
'There is no conversion engine available to convert from %s character set!' => 'No hay motor de conversión disponible para convertir desde el conjunto de caracteres  %s',
'Powered by %s ver. %s' => 'Suministrado por %s ver. %s',
'Skin created by' => 'Tema creado por',
'Skin designed by' => 'Tema diseñado por',
'Folder found' => 'Carpeta encontrada',
'Link found' => 'Enlace Encontrado',
'Desc' => 'Desc',
'Find next?' => '¿Encontar Siguiente?',
);

?>
