<?php

$text = array
(
'The Bookmark Server for Personal and Team Use' => 'Bogmærke serveren for personlig og gruppe brug',
'SiteBar Homepage' => 'SiteBar hjemmeside',
'SiteBar Installation & Launcher' => 'SiteBar installation & vælger',
'Any Browser' => 'Alle web browsere',
'Content Bookmarklets' => 'Indholds bookmarklets',
'Bookmarklet' => 'Bookmarklet',
'Your Language' => 'Dansk',
'Charset in MS Windows' => 'ISO-8859-1',
'Add Link to SiteBar' => 'Tilføj henvisning til SiteBar',
'Add Page to SiteBar' => 'Tilføj web-side til SiteBar',
'Error' => 'Fejl',
'Warning' => 'Advarsel',
'Unknown' => 'Ukendt',
'Search' => 'Søg',
'Highlight' => 'Afmærk',
'Collapse/Expand All' => 'Sammenklap/Udvid alt',
'Reload' => 'Opdatér',
'Reload with Hidden Folders' => 'Opdatér med skjulte mapper',
'Backup Log In' => 'Backup log ind ',
'Backup Log Out' => 'Backup log out',
'Commander' => 'Kommando håndtering',
'Add Folder' => 'Tilføj mappe',
'Add Link' => 'Tilføj henvisning',
'Contact Admin' => 'Kontakt administrator',
'Contact Moderator' => 'Kontakt moderator',
'Copy' => 'Kopiér',
'Copy Link' => 'Kopiér henvisning',
'Create Group' => 'Opret gruppe',
'Create Tree' => 'Opret struktur',
'Create User' => 'Opret bruger',
'Custom Order' => 'Tilpas rækkefølge',
'Delete Folder' => 'Slet mappe',
'Delete Group' => 'Slet gruppe',
'Delete Link' => 'Slet henvisning',
'Delete Account' => 'Fjern konto',
'Delete User' => 'Fjern bruger',
'Delete Tree' => 'Slet hieraki',
'Display Topic' => 'Vis emne',
'Email Link' => 'E-post adresse',
'Export Bookmarks' => 'Eksportér bogmærker',
'Export Description' => 'Eksportér beskrivelse',
'Favicon Management' => 'Favorit ikon administration',
'Folder Properties' => 'Mappe indstillinger',
'Group Members' => 'Gruppe medlemmer',
'Group Moderators' => 'Gruppe overvågere',
'Group Properties' => 'Gruppe egenskaber',
'Help' => 'Hjælp',
'Hide Folder' => 'Skjul mappe',
'Import Bookmarks' => 'Importér bogmærker',
'Import Description' => 'Importér beskrivelse',
'Log In' => 'Log ind',
'Log Out' => 'Log ud',
'Maintain Groups' => 'Vedligehold grupper',
'Maintain Users' => 'Vedligehold brugere',
'Maintain Trees' => 'Vedligehold hieraki',
'Membership' => 'Medlemsskab',
'Modify User' => 'Ændre bruger',
'Order of Trees' => 'Rækkefølge af hierakier',
'Paste' => 'Klistr',
'Properties' => 'Egenskaber',
'Purge Cache' => 'Ryd op i mellemlager (cache)',
'Purge Folder' => 'Fjern slettede mapper',
'Retrieve Link Information' => 'Hent henvisnings information',
'Security' => 'Sikkerhed',
'Send Email to Members' => 'Send e-post til brugere',
'Send Email to Moderators' => 'Send e-post til redaktør',
'Send Email to User' => 'Send e-post til bruger',
'Send Email to All' => 'Send e-post til alle',
'Show All Icons' => 'Vis alle ikoner',
'Set Up' => 'Opsætning',
'Sign Up' => 'Meld dig til',
'SiteBar Settings' => 'SiteBar indstillinger',
'Undelete' => 'Fortryd',
'Unhide Trees' => 'Genvis hieraki',
'Unhide Subfolders' => 'Genvis under mapper',
'User Settings' => 'Bruger indstillinger',
'Personal Data' => 'Personlig information',
'Validate Links' => 'Validér henvisninger',
'Validation' => 'Validéring',
'Verify Email' => 'Check e-post',
'Verify Email Code' => 'Check e-post adresse',
'Admin Password' => 'Administrator kodeord',
'Allow Anonymous Contact' => 'TIllad anonyme brugere',
'Allow Contact' => 'Tillad kontakt',
'Allow Given Membership' => 'Tillad valgt medlemsskab',
'Allow Info Mail' => 'Tillad informations e-post',
'Allow Noninteractive Mode' => 'TIllad ikke-interaktiv operation',
'Allow Self Add' => 'Tillad ',
'Allow Sign Up' => 'Tillad selv registrering',
'Auto Join E-Mail RegExp' => 'Automatisk deltag i e-post RegExp',
'Auto Retrieve Favicon' => 'Hent automatisk favorit ikon',
'Bookmark File' => 'Bogmærke fil',
'Cached: ' => 'Mellemlager (cache):',
'Codepage' => 'Tegnsæts tabel',
'Comment' => 'Kommentar',
'Content Only' => 'Kun indhold',
'Create New Sub Folder' => 'Opret ny undermappe',
'Dead Link' => 'Død henvisning',
'Decode Using' => 'Benyt afkodning',
'Decorate ACL Folders' => 'Dekorer ACL mapper',
'Default Language' => 'Standard sprog',
'Default Search In' => 'Søg standard i',
'Default Skin' => 'Standard udseende',
'Delete Content Only' => 'Slet kun indholdet',
'Delete Invalid Favicons' => 'Slet ugyldige favorit ikoner',
'Demo Account' => 'Demo konto',
'Description' => 'Beskrivelse',
'Description File' => 'Beskrivelses fil',
'Description Import/Export' => 'Beskrivelse Import/Eksport',
'Discover Missing Favicons' => 'Gendan mistede favorit ikoner',
'E-mail' => 'E-post',
'E-mail Verified' => 'E-post afprøvning',
'Encode Using' => 'Benyt kodning',
'Exclude From Validation' => 'Undlad at validere',
'Extern Commander' => 'Ekstern kommando håndtering',
'Favicon' => 'Favorit ikon',
'Feedback or Other Comment' => 'Tilbagemelding eller kommentar',
'File Type' => 'Fil type',
'Folder Name' => 'Mappe navn',
'From' => 'Fra',
'Group Name' => 'Gruppe navn',
'Help Topic' => 'Hjælpe emne',
'Ignore Recently Tested' => 'Udelad senest testede',
'Include Subfolders' => 'Inkludér undermapper',
'Keep In Cache' => 'Behold i mellemlager (cache)',
'Language' => 'Sprog',
'Link Description Length' => 'Beskrivelse af henvisning',
'Link Name' => 'Navn på henvisning',
'Maximal Icon Age' => 'Maksimal ikon alder',
'Maximal Icon Size' => 'Maksimal ikon størrelse',
'Maximal Icons per User' => 'Maksimum ikoner per bruger',
'Maximal Icons Total' => 'Maksimum ikoner ialt',
'Mode' => 'Mode',
'Moderator' => 'Moderator',
'New Tree Owner' => 'Ny struktur ejer',
'Old Password' => 'Nuværende kodeord',
'Only to Verified Emails' => 'Kun til afprøvede e-post adresser',
'Original: ' => 'Oprindelig:',
'Owner' => 'Ejer',
'Parent Folder' => 'Overliggende mappe',
'Password' => 'Kodeord',
'Paste Mode' => 'Klistr ind metode',
'Personal Mode' => 'Personlig',
'Private' => 'Privat',
'Publish Folder' => 'Udgiv mappe',
'Real Name' => 'Navn',
'Recent Time Expressed in Seconds' => 'Seneste tid udtrykt i sekunder',
'Remember as Default' => 'Husk som standard',
'Remember Me' => 'Husk mig',
'Rename Duplicate Links' => 'Ømdøb dobbelt henvisninger',
'Repeat Admin Password' => 'Gentag admin kodeord',
'Repeat Password' => 'Gentag kodeord',
'Respect Allow Info Mail' => 'Respektér "tillad informations e-post"',
'Select Group' => 'Vælg gruppe',
'Select User' => 'Vælg bruger',
'Sender E-mail' => 'Afsender e-post',
'Show Logo' => 'Vis logo',
'Show Menu Icon' => 'Vis menu ikon',
'Show Public Bookmarks' => 'Vis bogmærker',
'Show Sponsor' => 'Vis sponsor',
'Skin' => 'Udseende',
'Skip Execution Messages' => 'Vis ikke udførsels meddelelser',
'Source Folder Name' => 'Kilde mappe navn',
'Source Link Name' => 'Kilde henvisnings navn',
'Target Folder Name' => 'Navn på destinations mappe',
'To' => 'Til',
'Topic' => 'Emne',
'Tree Name' => 'Hieraki navn',
'Tree Owner' => 'Hieraki ejer',
'URL' => 'URL',
'Use Compression' => 'Brug komprimering',
'Use Conversion Engine' => 'Brig konverterings mekanisme',
'Use E-mail Features' => 'Brug e-post muligheder',
'Use Favicons' => 'Brug favorit ikoner',
'Use Folder Hiding' => 'Brug mappe skjulning',
'Use Hit Counter' => 'Brug hit tæller',
'Use Outbound Connection' => 'Brug udgående forbindelse',
'Use the Favicon Cache' => 'Brug favorit ikon mellemlager (cache)',
'Users Can Create Trees' => 'Brugere kan oprette strukturer',
'Your E-mail' => 'Din e-post adresse',
'Until I close browser' => 'I denne session',
'12 hours' => 'Tolv timer',
'6 days' => 'Seks dage',
'1 month' => 'En måned',
'No caching' => 'Ingen mellemlager (cache)',
'Order of Folders v. Links' => 'Rækkefølge af mapper m/links',
'Links first' => 'Henvisninger først',
'Folders first' => 'Mapper først',
'Default Link Sort Mode' => 'Standard sortering af henvisninger',
'Sort Mode' => 'Sorterings orden',
'User default' => 'Bruger standard',
'Custom order' => 'Tilpasset rækkefølge',
'Alphabetically' => 'Alfabetisk',
'Most clicked first' => 'Seneste benyttede først',
'New/changed links first' => 'Nye/ændrede henvisninger først',
'Waiting for visit' => 'Venter på besøg',
'Anonymous Guest' => 'Anonym gæst',
'Guest' => 'Gæst',
'Message' => 'Meddelelse',
'SiteBar Server' => 'SiteBar server',
'%s - ok.' => '%s - ok.',
'%s - error!' => '%s - fejl !',
'SiteBar: Contact Admin' => 'SIteBar: Kontakt admin',
'SiteBar: Contact Group Moderator' => 'SIteBar: Kontakt gruppe moderator',
'SiteBar: Email to all SiteBar Users' => 'SIteBar: E-Post til alle SiteBar brugere',
'SiteBar: Email to Group Members' => 'SIteBar: E-Post til alle gruppe medlemmer',
'SiteBar: Email to Group Moderators' => 'SIteBar: E-Post til gruppe moderatorer',
'SiteBar: Email to SiteBar User' => 'SIteBar: E-Post til SiteBar bruger',
'SiteBar: Email Verification' => 'SIteBar: E-post test',
'SiteBar: New SiteBar User' => 'SIteBar: Ny SiteBar bruger',
'SiteBar: Web site' => 'SIteBar: Web sted',
'Group' => 'Gruppe',
'R' => 'R',
'A' => 'A',
'M' => 'M',
'D' => 'D',
'P' => 'P',
'G' => 'G',
'Ask' => 'Spørg',
'Move or Copy' => 'Flyt eller kopiér',
'Copy (Keep Source)' => 'Kopiér (bevar original)',
'Move (Delete Source)' => 'Flyt (Fjern original)',
'Auto detection' => 'Automatisk detektion',
'Netscape/Mozilla/MS IE' => 'Netscape/Mozilla/MS IE',
'Netscape/Mozilla' => 'Netscape/Mozilla',
'MS Internet Explorer' => 'MS Internet Explorer',
'Opera Hotlist version 2.0' => 'Opera Hotlist version 2.0',
'Admins' => 'Administratorer',
'Everyone' => 'Alle og enhver',
'%s&#39;s Bookmarks' => '%s&#39;s Bogmærker',
'Deleted root %s of %s at %s' => 'Slettet roden %s af %s ved %s',
'All' => 'Alt',
'Name' => 'Navn',
'Access denied!' => 'Adgang ikke tilladt !',
'All links recently validated!' => 'Alle henvisninger valideret for nyligt !',
'Cannot connect to http://%s:%s!' => 'Kan ikke forbinde til http://%s:%s !',
'Cannot delete built in group!' => 'Kan ikke slette indbyggede grupper!',
'Cannot delete user because he is the only moderator of the following group(s): %s!' => 'Kan ikke slette bruger pga. at vedkommende er den eneste moderator af den følgende gruppe: %s!',
'Cannot download %s using https, will try http!' => 'Kan ikke hente %s med &#39;https&#39;, vil nu prøve &#39;http&#39; !',
'Cannot export empty description!' => 'Kan ikke eksportere en tom beskrivelse!',
'Cannot handle %s protocol!' => 'Kan ikke håndtere %s protokol !',
'Cannot remove all moderators from a group!' => 'Kan ikke fjerne alle moderatorer fra en gruppe!',
'Cannot send email!' => 'Kan ikke sende e-post!',
'Connection timed out!' => 'Forbindelse rindede ud !',
'Database corrupted - missing anonymous account!' => 'Databasen er i stykker - anonym konto mangler!',
'Duplicate folder name "%s"!' => 'Folder "%s" findes allerede!',
'Duplicate folder name!' => 'Folder findes allerede!',
'Duplicate name "%s" in the target folder!' => 'Navn "%s" findes allerede i mappe !',
'Duplicate name "%s"!' => 'Navn "%s" findes allerede !',
'Expected field %s was not filled!' => 'Forventede felt %s var ikke udfyldt !',
'Favicon <img src="%s"> found at url %s.' => 'Favorit ikon <img src="%s"> findes på url %s.',
'Favicon not found!' => 'Favorit ikon findes ikke',
'Field %s must be filled!' => 'Feltet "%s" skal udfyldes !',
'Folder has already been deleted!' => 'Mappen er allerede slettet !',
'Folder with id %s does not exist!' => 'Mappe med id %s findes ikke !',
'Group has already been deleted!' => 'Gruppen er allerede blevet slettet !',
'Group name "%s" is already used!' => 'Gruppe navn "%s" findes allerede !',
'Head of the HTML page was not found!' => 'Begyndelsen af HTML siden fandtes ikke !',
'HEAD unsupported, trying GET!' => '&#39;HEAD&#39; er ikke supporteret, prøver &#39;GET&#39; !',
'Host or port undefined!' => 'Netværks endepunkt (port) er udefineret !',
'Icon size %s exceeds maximal size %s!' => 'Ikon størrelse %s overstiger maksimal størrelse %s !',
'Incomplete HTTP response!' => 'HTTP svaret er ikke komplet !',
'Invalid code, verification disabled!' => 'Ugyldig kode, test er ikke slået til !',
'Invalid regular expresssion!' => 'Ugyldigt udtryk (re) !',
'Invalid filename or other upload related problem: %s!' => 'Ugyldigt arkivnavn eller andet overførings problem: %s !',
'Link already is in the target folder!' => 'Henvisning findes allerede i mappe !',
'Link has already been deleted!' => 'Henvisning er allerede slettet !',
'Missing command!' => 'Manglende kommando !',
'No links in the folder!' => 'Ingen henvisninger i mappen !',
'No more than %s redirections allowed!' => 'Det er ikke tilladt at have mere end %s omstillinger (redirects) !',
'No user was selected!' => 'Ingen bruger var valgt !',
'Node number %s has ACL record but does not exist!' => 'Knude nummer %s har ACL; men oplysninger findes ikke !',
'Old password is invalid!' => 'Nyværende kodeord er ugyldigt !',
'Page not found!' => 'Side ikke fundet !',
'Page redirected to %s!' => 'Side omstillet til %s !',
'Purge folder to remove it permanently!' => 'Fjern eller slet mappe permament !',
'Shortcut icon not found! Trying default favicon location %s.' => 'Henvisning til ikon ikke fundet ! - Prøver standard favicon lokation %s.',
'The description length exceeds maximum length of %s bytes!' => 'Længden af beskrivelsen overstiger den maksimalt tilladte på %s tegn !',
'The e-mail %s does not look correct!' => 'E-post adressen ser forkert ud!',
'The password was not repeated correctly!' => 'Kodeordet var ikke gentaget korrekt!',
'There is no content to be deleted!' => 'Der er ikke noget at slette!',
'There is nothing to be undeleted!' => 'Der er intet at fortryde!',
'This email is already used. Did you forget your password?' => 'Denne e-post adresse er allerede i brug. Har du glemt dit kodeord ?',
'Tree has already been deleted!' => 'Struktur er allerede blevet slettet!',
'Use "%s" command to delete own account!' => 'Brug "%s" operationen til at slette egen konto !',
'Unknown command!' => 'Ukendt kommando!',
'Unknown username or wrong password!' => 'Ukendt brugernavn (e-post) eller gelt kodeord!',
'Verification e-mail has been sent to your e-mail address!' => 'En e-post besked er blevet afsendt til din e-post adresse!',
'Wrong favicon type/format "%s"!' => 'Forkert favorit ikon type/format "%s" !',
'You have been left as group moderator!' => 'Du er nu blevet gruppe moderator!',
'You are the last moderator of used group(s): %s. Account cannot be deleted!' => 'Du er den sidste moderator af følgende grupper: %s. Konto kan ikke slettes!',
'%s, welcome to the SiteBar!<p>You have been already logged in.' => '%s, velkommen til SiteBar ! <p>Du er allerede logget ind.',
'E-mail %s verified! Any pending memberships were approved.' => 'E-post adressen %s er blevet testet ! - Medlemsskab er godkendt.',
'Link has been added.<p>You must reload your SiteBar in order to see added link!' => 'Henvisning er blevet tilføjet. <p>Det er nødvendigt at opdatere din SiteBar for at se den tilføjede henvisning!',
'Imported %s link(s) into %s folder(s) from the bookmark file.' => 'Har importeret %s henvisning(er) ind i %s mappen fra bogmærke arkivet.',
'Successful execution!' => 'Blev udført uden fejl!',
'Submit' => 'Opdatér',
'Reset' => 'Genskab',
'Reload SiteBar' => 'Opdatér SiteBar',
'Close' => 'Luk',
'Return' => 'Tilbage',
'Backup Return to SiteBar' => 'Backup - returnér til SiteBar',
'Cannot open file!' => 'Kan ikke åbne arkiv !',
'Unknown bookmark file format!' => 'Ukendt bogmærke arkiv format!',
'File is empty!' => 'Arkiv indeholder ikke noget!',
'Character set overriden from document to %s!' => 'Tegnsæt overskrevet fra dokument til %s!',
'There is no conversion engine available to convert from %s character set!' => 'Der er ingen oversættelses mekanisme til stede der kan konvertere fra %s tegnsættet!',
'Powered by %s ver. %s' => 'Leveret af %s version %s',
'Skin created by' => 'Udseende oprettet af',
'Skin designed by' => 'Udseende designet af',
'Folder found' => 'Mappe fundet',
'Link found' => 'Henvisning fundet',
'Desc' => 'Beskrivelse',
'Find next?' => 'Finde næste ?',
);

?>
