<?php

$text = array
(
'The Bookmark Server for Personal and Team Use' => '个人及团队使用的书签（收藏夹）服务器',
'SiteBar Homepage' => 'SiteBar主页',
'SiteBar Installation & Launcher' => 'SiteBar安装和运行',
'Any Browser' => '任何浏览器',
'Content Bookmarklets' => '内容书签集',
'Bookmarklet' => '书签集',
'Charset in MS Windows' => 'GB2312',
'Add Link to SiteBar' => '增加链接',
'Add Page to SiteBar' => '增加页面',
'Error' => '错误',
'Warning' => '警告',
'Unknown' => '未知',
'Search' => '搜索',
'Highlight' => '高亮显示',
'Collapse/Expand All' => '收缩/扩展 全部',
'Reload' => '刷新',
'Backup Log In' => '备份 登陆',
'Backup Log Out' => '备份 登出',
'Commander' => '命令',
'Add Folder' => '增加目录',
'Add Link' => '增加链接',
'Contact Admin' => '联系管理员',
'Contact Moderator' => '联系操作员',
'Copy' => '拷贝',
'Copy Link' => '拷贝链接',
'Create Group' => '创建组',
'Create Tree' => '创建树',
'Create User' => '创建用户',
'Delete Folder' => '删除目录',
'Delete Group' => '删除组',
'Delete Link' => '删除链接',
'Delete Account' => '删除账号',
'Delete User' => '删除用户',
'Display Topic' => '显示主题',
'Email Link' => 'Email链接',
'Export Bookmarks' => '导出书签',
'Export Description' => '导出描述',
'Folder Properties' => '目录属性',
'Group Members' => '组成员',
'Group Moderators' => '组操作员',
'Group Properties' => '祖属性',
'Help' => '帮助',
'Import Bookmarks' => '导入书签',
'Import Description' => '导入描述',
'Log In' => '登入',
'Log Out' => '登出',
'Maintain Groups' => '维护组',
'Maintain Users' => '维护用户',
'Membership' => '成员身份',
'Modify User' => '修改用户',
'Paste' => '粘贴',
'Properties' => '属性',
'Purge Folder' => '清除目录',
'Security' => '安全',
'Send Email to Members' => '发送Email给会员',
'Send Email to Moderators' => '发送Email给操作员',
'Send Email to User' => '发送Emai给用户',
'Send Email to All' => '发送Email给所有',
'Set Up' => '建立',
'Sign Up' => '注册',
'SiteBar Settings' => 'SiteBar设置',
'Undelete' => '反删除',
'User Settings' => '用户设置',
'Verify Email' => '验证Email',
'Verify Email Code' => '验证Email代码',
'Admin Password' => '管理密码',
'Allow Anonymous Contact' => '允许匿名联系',
'Allow Contact' => '允许联系',
'Allow Given Membership' => '允许给予成员身份',
'Allow Info Mail' => '允许信息Mail',
'Allow Noninteractive Mode' => '允许非互动模式',
'Allow Self Add' => '允许自己添加',
'Allow Sign Up' => '允许注册',
'Auto Join E-Mail RegExp' => '自动合并E-Mail',
'Bookmark File' => '书签文件',
'Codepage' => '代码页',
'Comment' => '注释',
'Content Only' => '只有内容',
'Create New Sub Folder' => '建立新子目录',
'Decode Using' => '编码',
'Decorate ACL Folders' => '装饰ACL目录',
'Default Search In' => '默认收缩',
'Default Skin' => '默认皮肤',
'Default Language' => '默认语言',
'Delete Content Only' => '只删除内容',
'Demo Account' => '演示账号',
'Description File' => '描述文件',
'Description Import/Export' => '描述导入/导出',
'Description' => '描述',
'E-mail Verified' => 'E-mail有效',
'E-mail' => 'E-mail',
'Encode Using' => '解码',
'Extern Commander' => '外部命令',
'Favicon' => '图标',
'Feedback or Other Comment' => '回馈或注释',
'File Type' => '文件类型',
'Folder Name' => '目录名',
'From' => '从',
'Group Name' => '组名',
'Help Topic' => '帮助标题',
'Hide Folders with ID' => '隐藏ID目录',
'Language' => '语言',
'Link Description Length' => '链接描述长度',
'Link Name' => '链接名',
'Mode' => '模式',
'Moderator' => '操作员',
'New Tree Owner' => '新的目录树所有者',
'Old Password' => '旧密码',
'Only to Verified Emails' => '只对有效Email',
'Owner' => '所有者',
'Parent Folder' => '上级目录',
'Password' => '密码',
'Paste Mode' => '粘贴模式',
'Personal Mode' => '个人模式',
'Private' => '私有',
'Publish Folder' => '发表目录',
'Real Name' => '真实姓名',
'Remember Me' => '记忆登陆',
'Remember as Default' => '作为默认记忆',
'Repeat Admin Password' => '重复管理密码',
'Repeat Password' => '重复密码',
'Select Group' => '选择组',
'Select User' => '选择用户',
'Show Logo' => '显示LOGO',
'Show Menu Icon' => '显示菜单图标',
'Show Public Bookmarks' => '显示公用书签',
'Show Sponsor' => '显示赞助人',
'Show Trees with ID' => '显示ID树',
'Skin' => '皮肤',
'Skip Execution Messages' => '跳过执行消息',
'Source Folder Name' => '源目录名',
'Source Link Name' => '源链接名',
'Target Folder Name' => '目标目录名',
'To' => '到',
'Topic' => '主题',
'Tree Name' => '树名',
'Tree Owner' => '树所有者',
'URL' => 'URL',
'Use Compression' => '使用压缩',
'Use E-mail Features' => '使用E-mail',
'Use Favicons' => '使用图标',
'Users Can Create Trees' => '用户可以创建树',
'Your E-mail' => '你的E-mail',
'Until I close browser' => '直到关闭浏览器 ',
'12 hours' => '12小时',
'6 days' => '6天',
'1 month' => '1个月',
'Anonymous Guest' => '匿名用户',
'Guest' => '游客',
'Message' => '消息',
'SiteBar Server' => 'SiteBar服务器',
'%s - ok.' => '%s - 完毕.',
'%s - error!' => '%s -  错误！',
'SiteBar: Contact Admin' => 'SiteBar: 联系管理员',
'SiteBar: Contact Group Moderator' => 'SiteBar: 联系组操作员',
'SiteBar: Email to all SiteBar Users' => 'SiteBar: 给所有用户Email',
'SiteBar: Email to Group Members' => 'SiteBar: 给组用户Email',
'SiteBar: Email to Group Moderators' => 'SiteBar: 给组操作员Email',
'SiteBar: Email to SiteBar User' => 'SiteBar: 给SiteBar用户Email',
'SiteBar: Email Verification' => 'SiteBar: 验证Email',
'SiteBar: New SiteBar User' => 'SiteBar: 新的SiteBar用户',
'SiteBar: Web site' => 'SiteBar: 网站',
'Group' => '组',
'Ask' => '询问',
'Move or Copy' => '移动或拷贝',
'Copy (Keep Source)' => '拷贝（保留源）',
'Move (Delete Source)' => '拷贝（删除源）',
'Auto detection' => '自动检测',
'Admins' => '管理员',
'Everyone' => '所有人',
'%s&#39;s Bookmarks' => '%s 的书签',
'All' => '所有',
'Name' => '姓名',
'Access denied!' => '拒绝访问!',
'Cannot delete built in group!' => '不能删除内置组!',
'Cannot export empty description!' => '不能导出空描述!',
'Cannot remove all moderators from a group!' => '不能删除组里所有操作员!',
'Cannot send email!' => '不能发送emai!',
'Database corrupted - missing anonymous account!' => '数据库错误-无匿名账号！',
'Duplicate folder name "%s"!' => '重复的目录名"%s"!',
'Duplicate folder name!' => '重复的目录名',
'Duplicate name "%s" in the target folder!' => '目标目录重复的名字"%s" ！',
'Duplicate name "%s"!' => '重复名字"%s" ！',
'Expected field %s was not filled!' => '%S没有填写！',
'Field %s must be filled!' => '%S必须填写！',
'Folder has already been deleted!' => '目录已经删除！',
'Folder with id %s does not exist!' => '目录%s不存在！',
'Group has already been deleted!' => '组已经删除！',
'Group name "%s" is already used!' => '组%s已经存在！',
'Invalid code, verification disabled!' => '无效代码，验证失败！',
'Invalid filename or other upload related problem: %s!' => '无效文件名%s或其他问题!',
'Link already is in the target folder!' => '目录中已有此链接！',
'Link has already been deleted!' => '链接已经删除！',
'Missing command!' => '无此命令！',
'No user was selected!' => '未选中任何用户！',
'Node number %s has ACL record but does not exist!' => '%s有ACL记录但不存在！',
'Old password is invalid!' => '旧密码无效！',
'Purge folder to remove it permanently!' => '永远删除目录！',
'The description length exceeds maximum length of %s bytes!' => '描述超过最大长度%s!',
'The password was not repeated correctly!' => '密码重复不正确！',
'There is no content to be deleted!' => '没有可以删除的内容！',
'There is nothing to be undeleted!' => '没有可以恢复的内容！',
'This email is already used. Did you forget your password?' => 'email已经使用。您是否忘记密码？',
'Tree has already been deleted!' => '树已经删除！',
'Unknown command!' => '未知命令！',
'Unknown username or wrong password!' => '未知的用户名或者错误密码！',
'Verification e-mail has been sent to your e-mail address!' => 'e-mail验证已经发往信箱！',
'You have been left as group moderator!' => '您已经成为组操作员！',
'%s, welcome to the SiteBar!<p>You have been already logged in.' => '%s，欢迎到SiteBar!<p>您已经登入',
'E-mail %s verified! Any pending memberships were approved.' => 'E-mail %s 验证通过！用户身份确认。',
'Link has been added.<p>You must reload your SiteBar in order to see added link!' => '链接增加成功。<p>您必须刷新SiteBare才能看到。',
'Imported %s link(s) into %s folder(s) from the bookmark file.' => '从书签文件导入%s链接到%s目录。',
'Successful execution!' => '成功执行！',
'Submit' => '提交',
'Reset' => '重置',
'Reload SiteBar' => '刷新SiteBar',
'Close' => '关闭',
'Return' => '返回',
'Cannot open file!' => '不能打开文件！',
'Unknown bookmark file format!' => '未知的书签文件格式！',
'File is empty!' => '文件是空的！',
'Folder found' => '已找到目录',
'Link found' => '已找到链接',
'Find next?' => '搜寻下一个？',
);

?>
