body
{
    font-family: Verdana, Tahoma, Geneva, Arial, Helvetica, sans-serif;
    font-size: x-small;
    background: ButtonFace;
    margin: 0px 2px;
}

img
{
    border: 0;
}

span.red
{
    color: red;
    font-weight: bold;
}

#logo
{
    width: 181px;
    margin-left: 3px;
    margin-top: 1px;
}

#userCtxMenu
{
    margin-top: 10px;
    border: 1px groove ButtonHighlight;
    width: 179px;
    z-index: 0;
}

#linkCtxMenu, #nodeCtxMenu
{
    display: none;
    width: 150px;
    position: absolute;
    top: 0;
    left: 0;
    z-index: 1;
}

#toolbar
{
    height: 23px;
    width: 185px;
    background: ButtonFace;
    border: 2px groove ButtonHighlight;
    margin-top: 5px;
    margin-bottom: 10px;
}

#toolbar input
{
    vertical-align: top;
    margin-right: 1px;
    border: 2px outset ButtonHighlight;
}

#toolbar div
{
    margin-top: 1px;
}

#toolbar img
{
    height: 16px;
    width: 16px;
    border: 1px solid ButtonFace;
}

#toolbar img.raised
{
    border: 1px outset black;
}

#toolbar img.pressed
{
    border: 1px inset gray;
}

#toolbar #tlbSearch
{
    margin: 1px 1px;
    float: left;
}

#toolbar #tlbOther
{
    margin: 1px 1px;
    text-align: right;
}
#toolbar #fldSearch
{
    font-size: 7pt;
    background: Window;
    width: 7em;
}

#powered
{
    text-align: center;
    width: 179px;
    padding: 1px 3px;
    margin-top: 5px;
    height: 20px;
}

#powered #by
{
    margin-bottom: 3px;
    font-size: 0.81em;
}

#powered #design
{
    font-size: 0.81em;
}

#stat
{
    text-align: center;
    border: 1px dotted black;
    font-size: 6pt;
    color: gray;
    margin-top: 10px;
    width: 179px;
}

div.sponsor a
{
    text-decoration: none;
}

div.sponsor img
{
    width: 125px;
    height: 37px;
    border: 0;
}

table.sponsor
{
    width: 100%;
}

table.sponsor td
{
    text-align: right;
}

div.menu
{
    cursor: default;
    font : menu;
    overflow: hidden;

    border: 2px outset ButtonHighlight;
    background: ButtonFace ;
    padding: 3px;
}

div.menu .off
{
    padding-left: 15px;
    padding-right: 15px;
}

div.menu .on
{
    padding-left: 15px;
    padding-right: 15px;
    color: HighlightText;
    background: Highlight;
}

div.menu .disabled
{
    padding-left: 15px;
    padding-right: 15px;
    color: GrayText ;
}

div.menu .separator
{
    margin-top: 3px;
    border-top: ButtonShadow  solid 1px;
    border-bottom: ButtonHighlight  solid 1px;
}

div.tree
{
    margin: 0;
    color: ButtonText ;
}

div.root
{
    margin-bottom: 2px;
    left: 0;
}

div.root img
{
    position: relative;
    left: 0;
}

div.tree div
{
    white-space: nowrap;
}

div.tree div.node
{
    display: block;
    cursor : default;
}

div.tree div.node div.childrenCollapsed
{
    display: none;
}

div.tree div.node div.childrenExpanded
{
    display: block;
}

div.tree div.link
{
    height: 18px;
}

div.tree img
{
    height: 18px;
    vertical-align: text-bottom;
    margin: 0;
}

div.tree img.favicon
{
    height: 16px;
    width: 16px;
    margin-right: 2px;
}

div.tree span.menu img
{
    height: 16px;
}

div.tree a
{
    text-decoration: none;
    color: ButtonText ;
}

div.tree a.private
{
    font-style: italic;
}

div.tree a.dead
{
    text-decoration: line-through;
}

div.tree a.acl
{
    text-decoration: underline;
}

div.tree a:hover
{
    color: black;
    background: #DDDFFF;
}

div.tree a:hover .selected
{
    color: yellow;
    background: #AAAFFF;
}

div.tree a.highlight
{
    background-color: InfoBackground ;
    color : InfoText;
    border: ButtonShadow  solid 1px;
}

div.hidden
{
    display: none;
}

/*** Command Window ***/

.cmdWin
{
    margin: 0;
    background: ButtonFace ;
}

#commandHead
{
    background: #807AD6;
    color: #D5D7FD;
    font-size: 14pt;
    text-align: center;
    font-weight: bold;
}

#errorHead
{
    background: red;
    color: yellow;
    font-size: 14pt;
    text-align: center;
    font-weight: bold;
}

#warnHead
{
    background: blue;
    color: yellow;
    font-size: 14pt;
    text-align: center;
    font-weight: bold;
}

#commandBody, #errorBody, #warnBody
{
    margin: 5px;
    width: 179px;
}

body.cmdWin .label
{
    font-weight: bold;
}

body.cmdWin .data
{
    font-size: x-small;
    text-align: left;
}

body.cmdWin .data input,
body.cmdWin .data textarea
{
    width: 97%;
}

body.cmdWin .buttons
{
    margin-top: 5px;
    text-align: right;
}

body.cmdWin input.button
{
    font-size: x-small;
    margin-top: 2px;
}

body.cmdWin input.customButton,
body.cmdWin select.language,
body.cmdWin select.help
{
    font-size: x-small;
    width: 100%;
}

body.cmdWin img.favicon
{
    width: 16px;
    height: 16px;
    border: 0;
}

body.cmdWin table
{
    margin-top: 5px;
    width: 100%;
    border-collapse: collapse;
    font-size: x-small;
}

body.cmdWin table tr.group td
{
    border-top: gray solid 1px;
}

body.cmdWin table th
{
    background: #807AD6;
    color: #D5D7FD;
    font-size: x-small;
}

body.cmdWin table .group
{
    width: 100%;
    text-align: left;
}

body.cmdWin table .right
{
    text-align: center;
}

body.cmdWin table input.order
{
    font-size: 7pt;
    width: 3em;
    margin-bottom: 1px;
}

body.cmdWin select option.noinsert
{
    background: gray;
}

body.cmdWin div.legend
{
    text-align: center;
    color: gray;
}

.fixed
{
    font-family: courier;
    font-size: small;
}

#foot
{
    text-align: right;
    width: 179px;
}

/*** Launcher window ***/

#home
{
    margin-bottom: 10px;
    width: 190px;
    text-align: center;
    float: left;
}

#tip
{
    height: 7em;
    margin-left: 200px;
}

#launcher
{
    border: 1px groove #807AD6;
    padding: 2px;
    width: 55em;
    margin-top: 1px;
}

#launcher h2
{
    font-size: larger;
    color: ButtonText;
    margin-bottom: 1px;
    margin-top: 2px;
}

#launcher p
{
    margin-left: 3px;
}

#launcher table
{
    text-align: left;
}

#launcher table th
{
    background: #807AD6;
    color: #D5D7FD;
    vertical-align: top;
    font-size: x-small;
}

#launcher table td
{
    font-size: x-small;
    vertical-align: top;
}

#launcher td p.comment
{
    margin-top: 1px;
    margin-bottom: 0;
    margin-left: 1px;
    font-style: italic;
}

#trailer
{
    margin-left: 4px;
    font-style: italic;
    font-size: 8pt;
}

span.compatibleNo
{
    color: #dddddd;
}

span.compatibleYes
{
    color: white;
    font-weight: bold;
}
