<?php 

$help = array();

$help['100'] = <<<_P
Le funzioni di SiteBar sono accesibili dal <strong>menu utente</strong> e dal
<strong>menu contestuale</strong> delle cartelle e dei collegamenti.
Il <strong>menu utente</strong> si trova nella parte bassa del monitor, mentre
il <strong>menu contestuale</strong> &#232; accessibile premendo il tasto destro
del mouse sulle cartelle o sui link. Gli utenti che utilizzano Opera o computers
Apple possono usare la sequenza di tasti Ctrl-click.

_P;

?>
