<?php

$text = array
(
'The Bookmark Server for Personal and Team Use' => 'Bookmark server pro osobní a týmové použití',
'SiteBar Homepage' => 'Domovská stránka SiteBar',
'SiteBar Installation & Launcher' => 'SiteBar instalace nebo spuštění',
'Any Browser' => 'Libovolný prohlížeč',
'Content Bookmarklets' => 'Bookmarklety pro ovládání obsahu',
'Bookmarklet' => 'Bookmarklet',
'Your Language' => 'Česky',
'Charset in MS Windows' => 'windows-1250',
'Add Link to SiteBar' => 'Přidat odkaz do SiteBaru',
'Add Page to SiteBar' => 'Přidat stránku do SiteBaru',
'Error' => 'Chyba',
'Warning' => 'Varování',
'Unknown' => 'Neznámý status',
'Search' => 'Hledat',
'Highlight' => 'Zvýraznit',
'Collapse/Expand All' => 'Zabalit/rozbalit vše',
'Reload' => 'Znovu načíst',
'Reload with Hidden Folders' => 'Znovu načíst se skrytými složkami',
'Backup Log In' => 'Záložní přihlášení',
'Backup Log Out' => 'Záložní odhlášení',
'Commander' => 'Příkazové okno',
'Add Folder' => 'Přidat složku',
'Add Link' => 'Přidat odkaz',
'Contact Admin' => 'Kontaktovat admina',
'Contact Moderator' => 'Kontaktovat moderátora',
'Copy' => 'Kopírovat',
'Copy Link' => 'Kopírovat odkaz',
'Create Group' => 'Vytvořit skupinu',
'Create Tree' => 'Vytvořit strom',
'Create User' => 'Vytvořit uživatele',
'Custom Order' => 'Vlastní pořadí',
'Delete Folder' => 'Smazat složku',
'Delete Group' => 'Smazat skupinu',
'Delete Link' => 'Smazat odkaz',
'Delete Account' => 'Smazat účet',
'Delete User' => 'Smazat uživatele',
'Delete Tree' => 'Smazat strom',
'Display Topic' => 'Zobraz téma',
'Email Link' => 'Poslat odkaz',
'Export Bookmarks' => 'Exportovat odkazy',
'Export Description' => 'Exportovat popis',
'Favicon Management' => 'Správa ikon odkazů',
'Folder Properties' => 'Vlastnosti složky',
'Group Members' => 'Členové skupiny',
'Group Moderators' => 'Moderátoři skupiny',
'Group Properties' => 'Vlastnosti skupiny',
'Help' => 'Nápověda',
'Hide Folder' => 'Skrýt složku',
'Import Bookmarks' => 'Importovat odkazy',
'Import Description' => 'Importovat popis',
'Log In' => 'Přihlásit',
'Log Out' => 'Odhlásit',
'Maintain Groups' => 'Správa skupin',
'Maintain Users' => 'Správa uživatelů',
'Maintain Trees' => 'Správa stromů',
'Membership' => 'Členství ve skupinách',
'Modify User' => 'Upravit uživatele',
'Order of Trees' => 'Pořadí stromů',
'Paste' => 'Vložit',
'Properties' => 'Vlastnosti',
'Purge Cache' => 'Vyprázdnit skladiště',
'Purge Folder' => 'Vysypat smazané',
'Retrieve Link Information' => 'Získat informace o odkazu',
'Security' => 'Zabezpečení',
'Send Email to Members' => 'Poslat e-mail členům',
'Send Email to Moderators' => 'Poslat e-mail moderátorům',
'Send Email to User' => 'Poslat e-mail uživateli',
'Send Email to All' => 'Poslat e-mail všem',
'Show All Icons' => 'Zobrazit všechny ikony odkazů',
'Set Up' => 'Nastavit',
'Sign Up' => 'Založit účet',
'SiteBar Settings' => 'SiteBar nastavení',
'Undelete' => 'Obnovit smazané',
'Unhide Trees' => 'Odhalit stromy',
'Unhide Subfolders' => 'Odhalit podsložky',
'User Settings' => 'Nastavení',
'Personal Data' => 'Osobní data',
'Validate Links' => 'Ověřit odkazy',
'Validation' => 'Ověřování',
'Verify Email' => 'Ověřit e-mail',
'Verify Email Code' => 'Kód ověření e-mailu',
'Admin Password' => 'Heslo administrátora',
'Allow Anonymous Contact' => 'Povolit anonymní kontakt',
'Allow Contact' => 'Povolit kontakt',
'Allow Given Membership' => 'Povolit přidání členství',
'Allow Info Mail' => 'Povolit informační e-mail',
'Allow Noninteractive Mode' => 'Povolit neinteraktivní mód',
'Allow Self Add' => 'Povolit osobní přihlášení',
'Allow Sign Up' => 'Povolit vytvoření účtu',
'Auto Join E-Mail RegExp' => 'Regulární výraz pro automatické členství na základě e-mailové adresy',
'Auto Retrieve Favicon' => 'Automaticky získat ikonu odkazu',
'Bookmark File' => 'Soubor s odkazy',
'Cached: ' => 'Uložená: ',
'Codepage' => 'Kódová stránka',
'Comment' => 'Komentář',
'Content Only' => 'Pouze obsah',
'Create New Sub Folder' => 'Vytvořit novou podsložku',
'Dead Link' => 'Nefukční odkaz',
'Decode Using' => 'Dekódovat pomocí',
'Decorate ACL Folders' => 'Označit zabezpečené složky',
'Default Language' => 'Výchozí jazyk',
'Default Search In' => 'Implictně prohledat',
'Default Skin' => 'Základní téma',
'Delete Content Only' => 'Smazat pouze obsah',
'Delete Invalid Favicons' => 'Smazat neplatné ikony odkazů',
'Demo Account' => 'Demo účet',
'Description' => 'Popis',
'Description File' => 'Soubor s popisem',
'Description Import/Export' => 'Import/export popisu',
'Discover Missing Favicons' => 'Zjistit chybějící ikony odkazů',
'E-mail' => 'E-mail',
'E-mail Verified' => 'E-mail ověřen',
'Encode Using' => 'Zakódovat pomocí',
'Exclude From Validation' => 'Neprovádět ověření',
'Extern Commander' => 'Externí příkazové okno',
'Favicon' => 'Soubor s ikonou',
'Feedback or Other Comment' => 'Odezva nebo jiný komentář',
'File Type' => 'Typ souboru',
'Folder Name' => 'Název složky',
'From' => 'Od',
'Group Name' => 'Název skupiny',
'Help Topic' => 'Témata nápovědy',
'Ignore Recently Tested' => 'Ignorovat odkazy nedávno testované',
'Include Subfolders' => 'Včetně podadresářů',
'Keep In Cache' => 'Uchovat v mezipaměti prohlížeče',
'Language' => 'Jazyk',
'Link Description Length' => 'Délka popisku odkazu',
'Link Name' => 'Název odkazu',
'Maximal Icon Age' => 'Maximální stáří ikony',
'Maximal Icon Size' => 'Maximální velikost ikony',
'Maximal Icons per User' => 'Maximum ikon na uživatele',
'Maximal Icons Total' => 'Maximum ikon celkem',
'Mode' => 'Mód',
'Moderator' => 'Moderátor',
'New Tree Owner' => 'Nový vlastník stromu',
'Old Password' => 'Staré heslo',
'Only to Verified Emails' => 'Pouze na ověřené adresy',
'Original: ' => 'Původní: ',
'Owner' => 'Vlastník',
'Parent Folder' => 'Mateřská složka',
'Password' => 'Heslo',
'Paste Mode' => 'Způsob vložení',
'Personal Mode' => 'Osobní mód',
'Private' => 'Soukromé',
'Publish Folder' => 'Zveřejnit složku',
'Real Name' => 'Skutečné jméno',
'Recent Time Expressed in Seconds' => 'Definice nedávného času v sekundách',
'Remember as Default' => 'Zapamatovat jako implicitní',
'Remember Me' => 'Zapamatovat přihlášení',
'Rename Duplicate Links' => 'Přejmenovávat duplicitní odkazy',
'Repeat Admin Password' => 'Zopakovat adminovo heslo',
'Repeat Password' => 'Zopakovat heslo',
'Respect Allow Info Mail' => 'Respektovat povolení informačního e-mailu',
'Select Group' => 'Vybrat skupinu',
'Select User' => 'Vybrat uživatele',
'Select Tree' => 'Vybrat strom',
'Sender E-mail' => 'Odesílatel odchozích e-mailů',
'Show Logo' => 'Zobrazit logo',
'Show Menu Icon' => 'Zobrazit menu ikonu',
'Show Public Bookmarks' => 'Zobrazit veřejné odkazy',
'Show Sponsor' => 'Zobrazit sponzora',
'Show Statistics' => 'Zobrazit statistiku',
'Skin' => 'Téma',
'Skip Execution Messages' => 'Ignorovat zprávy o vykonání',
'Source Folder Name' => 'Název zdrojové složky',
'Source Link Name' => 'Název zdrojového odkazu',
'Target Folder Name' => 'Název cílové složky',
'To' => 'Komu',
'Topic' => 'Téma',
'Tree Name' => 'Název stromu',
'Tree Owner' => 'Vlastník stromu',
'URL' => 'URL',
'Use Compression' => 'Používat kompresi',
'Use Conversion Engine' => 'Používat konverzní funkce',
'Use E-mail Features' => 'Používat e-mail funkce',
'Use Favicons' => 'Zobrazit ikony odkazů',
'Use Folder Hiding' => 'Používat skrývání složek',
'Use Hit Counter' => 'Používat počítadlo zásahů',
'Use Outbound Connection' => 'Používat odchozí spojení',
'Use the Favicon Cache' => 'Používat mezipaměť ikon odkazů',
'Users Can Create Trees' => 'Uživatelé mohou vytvářet stromy',
'Users Can Delete Trees' => 'Uživatelé mohou mazat stromy',
'Your E-mail' => 'Vlastní e-mail',
'Until I close browser' => 'Dokud je otevřen prohlížeč',
'12 hours' => '12 hodin',
'6 days' => '6 dnů',
'1 month' => '1 měsíc',
'No caching' => 'Nepoužívat mezipaměť',
'Order of Folders v. Links' => 'Řazení složek a odkazů',
'Links first' => 'Odkazy první',
'Folders first' => 'Složky první',
'Default Link Sort Mode' => 'Implicitní způsob řazení',
'Sort Mode' => 'Způsob řazení',
'User default' => 'Podle preferencí uživatele',
'Custom order' => 'Vlastní pořadí',
'Alphabetically' => 'Abecedně',
'Most clicked first' => 'Nejvíce používané první',
'New/changed links first' => 'Nové/změněné první',
'Waiting for visit' => 'Čekající nejdéle na použití',
'Anonymous Guest' => 'Anonymní host',
'Guest' => 'Host',
'Message' => 'Zpráva',
'SiteBar Server' => 'SiteBar server',
'%s - ok.' => '%s - ok.',
'%s - error!' => '%s - chyba.',
'SiteBar: Contact Admin' => 'SiteBar: Kontaktování administrátora',
'SiteBar: Contact Group Moderator' => 'SiteBar: Kontaktovaní moderátorů skupiny',
'SiteBar: Email to all SiteBar Users' => 'SiteBar: E-mail všem uživatelům SiteBaru',
'SiteBar: Email to Group Members' => 'SiteBar: E-mail členům skupiny',
'SiteBar: Email to Group Moderators' => 'SiteBar: E-mail moderátorům skupiny',
'SiteBar: Email to SiteBar User' => 'SiteBar: E-mail uživateli SiteBaru',
'SiteBar: Email Verification' => 'SiteBar: Ověření e-mailu',
'SiteBar: New SiteBar User' => 'SiteBar: Nový uživatel',
'SiteBar: Web site' => 'SiteBar: Webová stránka',
'Group' => 'Skupina',
'R' => 'Č',
'A' => 'P',
'M' => 'Z',
'D' => 'S',
'P' => 'V',
'G' => 'G',
'Ask' => 'Zeptat se',
'Move or Copy' => 'Přesunout  nebo kopírovat',
'Copy (Keep Source)' => 'Kopírovat (ponechat zdroj)',
'Move (Delete Source)' => 'Přesunout (smazat zdroj)',
'Auto detection' => 'Automatická detekce',
'Netscape/Mozilla/MS IE' => 'Netscape/Mozilla/MS IE',
'Netscape/Mozilla' => 'Netscape/Mozilla',
'MS Internet Explorer' => 'MS Internet Explorer',
'Opera Hotlist version 2.0' => 'Opera Hotlist verze 2.0',
'Admins' => 'Adminové',
'Everyone' => 'Kdokoliv',
'%s&#39;s Bookmarks' => '%s',
'Deleted root %s of %s at %s' => 'Smazaný strom %s uživatele %s v %s',
'All' => 'Všechno',
'Name' => 'Název',
'Access denied!' => 'Přístup odepřen!',
'All links recently validated!' => 'Všechny odkazy byly nedávno ověřeny!',
'Cannot connect to http://%s:%s!' => 'Připojení k http://%s:%s selhalo!',
'Cannot delete built in group!' => 'Nelze smazat vestavěnou skupinu!',
'Cannot delete user because he is the only moderator of the following group(s): %s!' => 'Uživatele nelze smazat, protože je jediným moderátorem následujících skupin: %s!',
'Cannot download %s using https, will try http!' => 'Stránku %s nelze stáhnout https protokolem! Pokus bude proveden http protokolem.',
'Cannot export empty description!' => 'Nelze exportovat prázný popis!',
'Cannot handle %s protocol!' => 'Protokol % nelze zpracovat!',
'Cannot move folder to its subfolder!' => 'Nelze přesunout složku do její podsložky!',
'Cannot remove all moderators from a group!' => 'Nelze odstranit všechny moderátory ze skupiny!',
'Cannot send email!' => 'Chyba při odesílání e-mailu!',
'Connection timed out!' => 'Připojení vypršelo!',
'Database corrupted - missing anonymous account!' => 'Databáza poškozena - chybí anonymní účet!',
'Duplicate folder name "%s"!' => 'Duplikátní jméno složky "%s"!',
'Duplicate folder name!' => 'Duplikátní jméno složky!',
'Duplicate name "%s" in the target folder!' => 'Duplikátní název "%s" v cílové složce!',
'Duplicate name "%s"!' => 'Duplikátní název "%s"!',
'Expected field %s was not filled!' => 'Povinné pole %s nebylo vyplněno!',
'Favicon <img src="%s"> found at url %s.' => 'Ikona odkazu <img src="%s"> nalezena na adrese %s.',
'Favicon not found!' => 'Ikona odkazu nebyla nalezena!',
'Field %s must be filled!' => 'Povinné pole %s musí být vyplněno!',
'Folder has already been deleted!' => 'Složka již byla smazána!',
'Folder with id %s does not exist!' => 'Složka s id %s neexistuje!',
'Group has already been deleted!' => 'Skupina již byla smazána!',
'Group name "%s" is already used!' => 'Název skupiny "%s" je již použit!',
'Head of the HTML page was not found!' => 'Hlavička HTML stránky nebyla nalezena!',
'HEAD unsupported, trying GET!' => 'HEAD požadavek nepodporován, pokus bude proveden pomocí GET!',
'Host or port undefined!' => 'Cílový server nebo port nebyl definován!',
'Icon size %s exceeds maximal size %s!' => 'Velikost ikony %s překračuje limit %s!',
'Incomplete HTTP response!' => 'Nekompletní HTTP odpověď!',
'Invalid code, verification disabled!' => 'Neplatný kód, verifikace znemožněna!',
'Invalid regular expresssion!' => 'Neplatný regulární výraz!',
'Invalid filename or other upload related problem: %s!' => 'Neplatný název souboru nebo jiný problém s nahraním souboru: %s!',
'Link already is in the target folder!' => 'Odkaz se již nalézá v cílové složce!',
'Link has already been deleted!' => 'Odkaz byl již smazán!',
'Missing command!' => 'Chybějící příkaz!',
'No links in the folder!' => 'Žádné odkazy ve složce!',
'No more than %s redirections allowed!' => 'Více než %s přesměrování není dovoleno!',
'No user was selected!' => 'Žádný uživatel nebyl vybrán!',
'Node number %s has ACL record but does not exist!' => 'Složka číslo %s má ACL záznam ale neexistuje!',
'Old password is invalid!' => 'Staré heslo je neplatné!',
'Page not found!' => 'Stránka nenalezena!',
'Page redirected to %s!' => 'Stránka přesměrována na %s!',
'Purge folder to remove it permanently!' => 'Vysypat složku pro konečné smazání!',
'Shortcut icon not found! Trying default favicon location %s.' => 'Ikona odkazu nenalezena! Bude proveden pokus o nalezení na standardní adrese %s.',
'The description length exceeds maximum length of %s bytes!' => 'Délka popisku přesahuje maximální povolenou délku %s bajtů!',
'The e-mail %s does not look correct!' => 'E-mailová adresa %s je neplatná!',
'The password was not repeated correctly!' => 'Heslo nebylo zopakováno správně!',
'There is no content to be deleted!' => 'Žádný obsah pro smazání!',
'There is nothing to be undeleted!' => 'Žádný obsah pro obnovení!',
'This email is already used. Did you forget your password?' => 'Tento e-mail je již použit. Zapomenuté heslo?',
'Tree has already been deleted!' => 'Strom byl již vymazán!',
'Use "%s" command to delete own account!' => 'Pro smazání vlastního účtu použijte příkaz "%s"!',
'Unknown command!' => 'Neznámý příkaz!',
'Unknown username or wrong password!' => 'Špatné uživatelské jméno nebo heslo!',
'Verification e-mail has been sent to your e-mail address!' => 'Ověžovací e-mail byl zaslán na zadanou e-mailovou adresu!',
'Wrong favicon type/format "%s"!' => 'Špatný typ nebo formát ikony odkazu "%s"!',
'You have been left as group moderator!' => 'Moderátorsví skupiny ponecháno!',
'You are the last moderator of used group(s): %s. Account cannot be deleted!' => 'Účet nelze smazat, protože jste jediným moderátorem následujících skupin: %s!',
'%s, welcome to the SiteBar!<p>You have been already logged in.' => '%s, vítejte v SiteBaru!<p>Přihlášení do systému již proběhlo.',
'E-mail %s verified! Any pending memberships were approved.' => 'E-mail %s byl ověřen! Případná čekající členství byla schválena.',
'Link has been added.<p>You must reload your SiteBar in order to see added link!' => 'Odkaz byl přidán.<p>SiteBar musí být znovu načten pro jeho zobrazení!',
'Imported %s link(s) into %s folder(s) from the bookmark file.' => 'Naimportováno %s odkazů do %s složek ze souboru s odkazy.',
'Successful execution!' => 'Úspěšné vykonání!',
'Submit' => 'Provést',
'Reset' => 'Původní',
'Reload SiteBar' => 'Znovu načíst SiteBar',
'Close' => 'Zavřít',
'Return' => 'Návrat',
'Backup Return to SiteBar' => 'Záložní návrat do SiteBaru',
'Cannot open file!' => 'Chyba při otevírání souboru!',
'Unknown bookmark file format!' => 'Neznámý formát souboru!',
'File is empty!' => 'Prázdný soubor!',
'Character set overriden from document to %s!' => 'Znaková sada předefinována dokumentem na %s!',
'There is no conversion engine available to convert from %s character set!' => 'Není dostupná knihovna pro konverzi ze znakové sady %s!',
'Powered by %s ver. %s' => 'Běží na %s verze %s',
'Skin created by' => 'Téma vytvořil(a)',
'Skin designed by' => 'Téma navrhl(a)',
'Folder found' => 'Složka nalezena',
'Link found' => 'Odkaz nalezen',
'Desc' => 'Popis',
'Find next?' => 'Hledat další?',
);

?>
