<?php

class Hook
{
    function head()
    {
?>
<div id='logo'><a href="index.php" <?php echo Page::target()?> title='SiteBar Startpage'><?php echo Skin::img('logo')?></a></div>
<?php
    }

    function foot($version, $show_sponsor, $statistics)
    {
?>
<div id='powered'>
    <div id='by'>
        <?php echo T('Powered by %s ver. %s', array("<strong><a href='http://www.sitebar.org/' ".Page::target().">SiteBar</a></strong>",$version))?>
    </div>
<?php
        if ($show_sponsor)
        {
            Hook::sponsor();
        }
?>
    <div id='design'>
        <?php echo T("Skin designed by")?> <a href='http://www.alexisisaac.net/' <?php echo Page::target()?>>Alexis Isaac</a>
    </div>
<?php
        if ($statistics)
        {
?>
    <div id='stat'>
        <?php echo A('hook::statistics', $statistics) ?>
    </div>
<?php
        }
?>
</div>
<?php
    }

    function sponsor()
    {
?>
    <div class='sponsor'>
        <a href="http://sourceforge.net/" <?php echo Page::target()?>>
            <img src="http://sourceforge.net/sflogo.php?group_id=76467&amp;type=2"
                 alt="SourceForge.net Logo">
        </a>
    </div>
<?php
    }
}
?>
