<?php

$para = array();

$para['index::tip'] = <<<_P
Utilisé cette page pour lancer ou installer sur votre navigateur ce serveur de favoris. Il est recommandé de mettre en favori l un de ces liens identifié par "*" et non la présente page. Cette page peut être ouverte à partir de la fenêtre SiteBar en cliquant sur le logo.
_P;

$para['index::any_browser'] = <<<_P
Utiliser <a title="SiteBar" href="%s/sitebar.php">SiteBar</a>* dans cette fenêtre - ou l'ouvrir dans un popup <a title="SiteBar" href="%s">SiteBar</a>-comme* une fenêtre.
_P;

$para['index::ie_install'] = <<<_P
<a href="?install=1">Installation</a> / <a href="?install=0">Desisntallation</a> de dans le volet d'exploraiton  - ceci nécéssite un changement dans la base de registre ainsi qu'un redemarrage du système. Selon vos droits, seulement certaines fonctions peuvent être actives.
<p class='comment'>Ouvrir lvolet d'exploration SiteBar à partir du menu Afficher/Volet d'exploration ou utiliser <b>Personnaliser</b> dans la fonction barre d'outils pour avoir le bouton de SiteBar sur la barre d'outils. Cliquez n'importe ou sur la page ou sur un lien pour ajouter la page ou le lien à SiteBar.</p>
_P;

$para['index::ie_search'] = <<<_P
Ajouter <a title="SiteBar" href="javascript:void(_search=open('%s/sitebar.php','_search'))"> SiteBar</a>* temporairement dans le volet de recherche d'explorer.
<p class='comment'>Utiliser quand vous ne possédez pas suffisament de droit pour effectuer l'installation decrite précédement.
_P;

$para['index::mozilla'] = <<<_P
Ajouter à Mozilla/Netscape ou compatible
<a title="SiteBar" href="javascript:sidebar.addPanel('SiteBar','%s/sitebar.php','')"> sidebar</a> - affichage en utilissant la touche F9.
<p class='comment'>Les utilisateurs de Mozilla Firefox devraient utiliser le lien ci-dessus pour créer un lien bookmark qui ouvrira sitebar lorsque celui-ci sera séléctionné. 
Mozillazine <a href="http://forums.mozillazine.org/viewtopic.php?t=36166">sujet</a> décrit comme utiliser [anglais] <a href="http://www.sitebar.org/plugin/firefox/SiteBar.xpi?url=%s">SiteBar</a> l'extension sidebar et le menu d'extension <a href="http://www.sitebar.org/plugin/firefox/WebLinks_for_SiteBar.xpi?url=%s">WebLinks</a> avec SiteBar. </p>
_P;

$para['index::opera'] = <<<_P
Ajouter à la <a title="SiteBar" rel="sidebar" href="%s/sitebar.php">Hotlist</a> d'Opéra.
<p class='comment'>Utiliser Ctrl+clique au lien du  clique droit pour afficher le répertoire ou le lien dans le menu contextuel.</p>
_P;

$para['index::myie2_install'] = <<<_P
Téléchargement personnalisé
<a href="http://www.sitebar.org/plugin/myie2/?sidebar=%s">sidebar</a>
et/ou
a href="http://www.sitebar.org/plugin/myie2/?toolbar=%s">Ajouter l'onglet courant à SiteBar</a>
toolbar plugin
_P;

$para['index::bookmarklet'] = <<<_P
<a href="javascript:%s">Ajouter la page à SiteBar</a>* - clique droit sur ce lien et ajouter le à votre barre de favoris. Ceci vous permettra plus tard d'ajouter le lien à la page courante dans le navigateur SiteBar. Les utilisateurs Microsoft IE peuvent utiliser l'installateur et le menu contextuel également.
_P;

$para['index::copyright2'] = <<<_P
Copyright &copy; 2003,2004 <a href='http://brablc.com/'>Ondřej Brablc</a> and the <a href='http://www.sitebar.org/team.php'>SiteBar Team</a>. Support <a href='http://sourceforge.net/forum/forum.php?forum_id=261003'>forum</a>.
_P;

$para['command::contact'] = <<<_P
Message:

%s


--
Serveur SiteBar à %s
_P;

$para['command::contact_group'] = <<<_P
Groupe: %s
MEssage:

%s


--Serveur SiteBar à %s
_P;

$para['command::delete_account'] = <<<_P
<h3>Voulez-vous réellement supprimer votre compte ?</h3>
Ceci est une opération irréversible!<p>
Toutes les hierarchies seront attribuées aux administrateurs du système.
_P;

$para['command::email_link_href'] = <<<_P
<p>eNvoyer un email via votre <a href='mailto:?subject=Site Internet: %s&amp;body=J ai trouvé ce site internet qui serait suceptible de t interesser. Va voir à: %s -- Message envoyé via SiteBar à %s Serveur de favoris OpenSource http://www.sitebar.org '>logiciel d'email</a>
_P;

$para['command::email_link'] = <<<_P
J trouvé un site internet qui serait suceptible de t'interesser.
Va voir à:

   "%s"  %s

%s

--
Envoyer via SiteBar à %s
Serveur de favoris Open Source http://www.sitebar.org
_P;

$para['command::verify_email'] = <<<_P
Vous avez demandé une vérification d'email, qui permet l'ajout automatique aux groupes grace aux règles Regexp et vous permet l'utilsiation des fonctionalités email de SiteBar.
_P;

$para['command::import_bk'] = <<<_P
<br>
Les favoris locaux peuvent être exportés dans un fichier local en utilisant <a href='javascript:window.external.ImportExportFavorites(false,"")'>la fonction javascript suivante</a>.
_P;

$para['command::export_bk'] = <<<_P
<br>
Les favoris exportés peuvent être importés dans les favoris locaux en utilisant l <a href='javascript:window.external.ImportExportFavorites(true,"")'>function javascript suivante</a>.
_P;

$para['command::noiconv'] = <<<_P
<br>
La convertion du Codepage n'a pas été installé sur ce serveur SiteBar.
_P;

$para['command::security_legend'] = <<<_P
Droits:
<strong>L</strong>ecture, <strong>A</strong>jout, <strong>M</strong>odifier, <strong>S</strong>upprimer, <strong>P</strong>urger, <strong>P</strong>ermettre
_P;

$para['command::purge_cache'] = <<<_P
<h3>Voulez-vous réellement supprimer tous les favicon du cache ?</h3>
_P;

$para['usermanager::auto_verify_email'] = <<<_P
Votre adresse email correspond aux règles d'ajout automatique des groupes fermés suivant:
    %s.

De ce fait pour autoriser votre adhésion, votre adresse email doit être verifiée. Merci de cliquer sur le lien suivant afin de la verifier.
   %s
_P;

$para['usermanager::signup_info'] = <<<_P
L'utilisateur "%s" <%s> c'est inscrit à votre serveur SiteBar à %s.
_P;

$para['hook::statistics'] = <<<_P
Racines {roots_total}.
Repertoires {nodes_shown}/{nodes_total}.
Liens {links_shown}/{links_total}.
Utilisateurs {users}.
Groupes {groups}.
Requêtes SQL {queries}.
DB/Temps total {time_db}/{time_total} sec ({time_pct}%).
_P;

?>
