<?php

$text = array
(
'The Bookmark Server for Personal and Team Use' => 'Bokmärkesserver för personlig användning och teamanvändning',
'SiteBar Homepage' => 'SiteBar Hemsida',
'SiteBar Installation & Launcher' => 'SiteBar Installation & Användning',
'Any Browser' => 'Valfri Webbläsare',
'Content Bookmarklets' => 'Innehållsbookmarklets',
'Bookmarklet' => 'Bookmarklet',
'Your Language' => 'Svenska',
'Charset in MS Windows' => 'ISO-8859-1',
'Add Link to SiteBar' => 'Lägg Till Länk i SiteBar',
'Add Page to SiteBar' => 'Lägg Till Sida i SiteBar',
'Error' => 'Fel',
'Warning' => 'Varning',
'Unknown' => 'Okänd',
'Search' => 'Sök',
'Highlight' => 'Markera',
'Collapse/Expand All' => 'Kollapsa/Expandera Alla',
'Reload' => 'Uppdatera',
'Reload with Hidden Folders' => 'Uppdatera med Gömda Mappar',
'Backup Log In' => 'Backup Logga In',
'Backup Log Out' => 'Backup Logga Ut',
'Commander' => 'Kommandohanterare',
'Add Folder' => 'Lägg Till Mapp',
'Add Link' => 'Lägg Till Länk',
'Contact Admin' => 'Kontakta Administratör',
'Contact Moderator' => 'Kontakta Moderator',
'Copy' => 'Kopiera',
'Copy Link' => 'Kopiera Länk',
'Create Group' => 'Skapa Grupp',
'Create Tree' => 'Skapa Träd',
'Create User' => 'Skapa Användare',
'Custom Order' => 'Egendefinierad Ordning',
'Delete Folder' => 'Ta Bort Mapp',
'Delete Group' => 'Ta Bort Grupp',
'Delete Link' => 'Ta Bort Länk',
'Delete Account' => 'Ta Bort Konto',
'Delete User' => 'Ta Bort Användare',
'Delete Tree' => 'Ta Bort Träd',
'Display Topic' => 'Visa Ämne',
'Email Link' => 'Eposta Länk',
'Export Bookmarks' => 'Exportera Bokmärken',
'Export Description' => 'Exportera Beskrivning',
'Favicon Management' => 'Favicon Hantering',
'Folder Properties' => 'Mappegenskaper',
'Group Members' => 'Gruppmedlemmar',
'Group Moderators' => 'Gruppmoderatorer',
'Group Properties' => 'Gruppegenskaper',
'Help' => 'Hjälp',
'Hide Folder' => 'Göm Mapp',
'Import Bookmarks' => 'Importera Bokmärken',
'Import Description' => 'Importera Beskrivning',
'Log In' => 'Logga In',
'Log Out' => 'Logga Ut',
'Maintain Groups' => 'Hantera Grupper',
'Maintain Users' => 'Hantera Användare',
'Maintain Trees' => 'Hantera Träd',
'Membership' => 'Medlemskap',
'Modify User' => 'Modifiera Användare',
'Order of Trees' => 'Trädordning',
'Paste' => 'Klistra In',
'Properties' => 'Egenskaper',
'Purge Cache' => 'Rensa Cache',
'Purge Folder' => 'Rensa Mapp',
'Retrieve Link Information' => 'Hämta Länkinformation',
'Security' => 'Säkerhet',
'Send Email to Members' => 'Sänd Epost till Medlemmar',
'Send Email to Moderators' => 'Sänd Epost till Moderatorer',
'Send Email to User' => 'Sänd Epost till Användare',
'Send Email to All' => 'Sänd Epost till Alla',
'Show All Icons' => 'Visa Alla Ikoner',
'Set Up' => 'Ställ In',
'Sign Up' => 'Registrera Dig',
'SiteBar Settings' => 'SiteBarinställningar',
'Undelete' => 'Ångra Ta Bort',
'Unhide Trees' => 'Ångra Göm Träd',
'Unhide Subfolders' => 'Ångra Göm Undermappar',
'User Settings' => 'Användarinställningar',
'Personal Data' => 'Personlig Data',
'Validate Links' => 'Validera Länkar',
'Validation' => 'Validering',
'Verify Email' => 'Verifiera Epost',
'Verify Email Code' => 'Verifiera Epostkod',
'Admin Password' => 'Administratörslösenord',
'Allow Anonymous Contact' => 'Tillåt Anonym Kontakt',
'Allow Contact' => 'Tillåt Kontakt',
'Allow Given Membership' => 'Tillåt Beviljat Medlemskap',
'Allow Info Mail' => 'Tillåt Information Via Epost',
'Allow Noninteractive Mode' => 'Tillåt Icke-Interaktivt Mode',
'Allow Self Add' => 'Tillåt Lägga Till Sig Själv',
'Allow Sign Up' => 'Tillåt Användarregistrering',
'Auto Join E-Mail RegExp' => 'Reguljärt Uttryck av Epostadress för Automatiskt Deltagande',
'Auto Retrieve Favicon' => 'Hämta Favicon Automatiskt',
'Bookmark File' => 'Bokmärkesfil',
'Cached: ' => 'Cacheat:',
'Codepage' => 'Codepage',
'Comment' => 'Kommentar',
'Content Only' => 'Endast Innehåll',
'Create New Sub Folder' => 'Skapa Ny Undermapp',
'Dead Link' => 'Död Länk',
'Decode Using' => 'Avkoda Med',
'Decorate ACL Folders' => 'Dekorera ACL Mappar',
'Default Language' => 'Standardspråk',
'Default Search In' => 'Standard Sök i',
'Default Skin' => 'Standardutseende',
'Delete Content Only' => 'Ta Endast Bort Innehåll',
'Delete Invalid Favicons' => 'Ta Bort Ogiltiga Faviconer',
'Demo Account' => 'Demokonto',
'Description' => 'Beskrivning',
'Description File' => 'Beskrivningsfil',
'Description Import/Export' => 'Importera/Exportera Beskrivning',
'Discover Missing Favicons' => 'Upptäck Saknade Faviconer',
'E-mail' => 'Epostadress',
'E-mail Verified' => 'Epostadress Verifierad',
'Encode Using' => 'Koda Med',
'Exclude From Validation' => 'Exkludera Från Validering',
'Extern Commander' => 'Extern Kommandohanterare',
'Favicon' => 'Favicon',
'Feedback or Other Comment' => 'Feedback eller Övriga Kommentarer',
'File Type' => 'Filtyp',
'Folder Name' => 'Mappnamn',
'From' => 'Från',
'Group Name' => 'Gruppnamn',
'Help Topic' => 'Hjälpämne',
'Ignore Recently Tested' => 'Ignorera Nyligen Testade',
'Include Subfolders' => 'Inkludera Undermappar',
'Keep In Cache' => 'Behåll i Cache',
'Language' => 'Språk',
'Link Description Length' => 'Längd På Länkbeskrivning',
'Link Name' => 'Länknamn',
'Maximal Icon Age' => 'Maximal Ikonålder',
'Maximal Icon Size' => 'Maximal Ikonstorlek',
'Maximal Icons per User' => 'Maximalt Antal Ikoner per Användare',
'Maximal Icons Total' => 'Maximalt Antal Ikoner Totalt',
'Mode' => 'Mode',
'Moderator' => 'Moderator',
'New Tree Owner' => 'Ny Trädägare',
'Old Password' => 'Gammalt Lösenord',
'Only to Verified Emails' => 'Endast till Verifierade Epostadresser',
'Original: ' => 'Original:',
'Owner' => 'Ägare',
'Parent Folder' => 'Föregående Mapp',
'Password' => 'Lösenord',
'Paste Mode' => 'Klistra In Läge',
'Personal Mode' => 'Personligt Läge',
'Private' => 'Privat',
'Publish Folder' => 'Publicera Mapp',
'Real Name' => 'Namn',
'Recent Time Expressed in Seconds' => 'Senaste Tiden Uttryckt i Sekunder',
'Remember as Default' => 'Kom Ihåg Som Standard',
'Remember Me' => 'Kom Ihåg Mig',
'Rename Duplicate Links' => 'Byt Namn på Dublettlänkar',
'Repeat Admin Password' => 'Repetera Administratörslösenord',
'Repeat Password' => 'Repetera Lösenord',
'Respect Allow Info Mail' => 'Respektera Tillåt Information Via Epost',
'Select Group' => 'Välj Grupp',
'Select User' => 'Välj Användare',
'Sender E-mail' => 'Avsändarens Epostadress',
'Show Logo' => 'Visa Logotyp',
'Show Menu Icon' => 'Visa Menyikon',
'Show Public Bookmarks' => 'Visa Publika Bokmärken',
'Show Sponsor' => 'Visa Sponsor',
'Show Statistics' => 'Visa Statistik',
'Skin' => 'Utseende',
'Skip Execution Messages' => 'Skippa Exekveringsmeddelanden',
'Source Folder Name' => 'Namn På Källmapp',
'Source Link Name' => 'Namn På Källänk',
'Target Folder Name' => 'Namn På Målmapp',
'To' => 'Till',
'Topic' => 'Ämne',
'Tree Name' => 'Trädnamn',
'Tree Owner' => 'Trädägare',
'URL' => 'URL',
'Use Compression' => 'Använd Komprimering',
'Use Conversion Engine' => 'Använd Konverteringsmotorn',
'Use E-mail Features' => 'Använd Epostegenskaper',
'Use Favicons' => 'Använd Favicon',
'Use Folder Hiding' => 'Använd Gömma Mappar',
'Use Hit Counter' => 'Använd Besöksräknare',
'Use Outbound Connection' => 'Använd Utgående Uppkoppling',
'Use the Favicon Cache' => 'Använd Favicon Cache',
'Users Can Create Trees' => 'Användare Kan Skapa Träd',
'Users Can Delete Trees' => 'Användare Kan Ta Bort Träd',
'Your E-mail' => 'Din Epostadress',
'Until I close browser' => 'Tills jag stänger webbläsaren',
'12 hours' => '12 timmar',
'6 days' => '6 dagar',
'1 month' => '1 månad',
'No caching' => 'Ingen Cachning',
'Order of Folders v. Links' => 'Ordning på Mappar relativt Länkar',
'Links first' => 'Länkar först',
'Folders first' => 'Mappar först',
'Default Link Sort Mode' => 'Standardläge för Länksortering',
'Sort Mode' => 'Länksorteringsläge',
'User default' => 'Standardanvändare',
'Custom order' => 'Egendefinierad ordning',
'Alphabetically' => 'Alfabetiskt',
'Most clicked first' => 'Flest klickade på först',
'New/changed links first' => 'Nya/ändrade länkar först',
'Waiting for visit' => 'Väntar på besök',
'Anonymous Guest' => 'Anonym Gäst',
'Guest' => 'Gäst',
'Message' => 'Meddelande',
'SiteBar Server' => 'SiteBar Server',
'%s - ok.' => '%s - ok.',
'%s - error!' => '%s - fel!',
'SiteBar: Contact Admin' => 'SiteBar: Kontakta Administratören',
'SiteBar: Contact Group Moderator' => 'SiteBar: Kontakta Gruppmoderatorn',
'SiteBar: Email to all SiteBar Users' => 'SiteBar: Skicka Epost till alla SiteBar-Användare',
'SiteBar: Email to Group Members' => 'SiteBar: Skicka Epost till Gruppmedlemmar',
'SiteBar: Email to Group Moderators' => 'SiteBar: Skicka Epost till Gruppmoderatorer',
'SiteBar: Email to SiteBar User' => 'SiteBar: Skicka Epost till SiteBar-Användare',
'SiteBar: Email Verification' => 'SiteBar: Epostadressverifiering',
'SiteBar: New SiteBar User' => 'SiteBar: Ny SiteBar Användare',
'SiteBar: Web site' => 'SiteBar: Webbsida',
'Group' => 'Grupp',
'R' => 'L',
'A' => 'A',
'M' => 'M',
'D' => 'T',
'P' => 'R',
'G' => 'B',
'Ask' => 'Fråga',
'Move or Copy' => 'Flytta eller Kopiera',
'Copy (Keep Source)' => 'Kopiera (Behåll Original)',
'Move (Delete Source)' => 'Flytta (Ta Bort Original)',
'Auto detection' => 'Automatisk detektering',
'Netscape/Mozilla/MS IE' => 'Netscape/Mozilla/MS IE',
'Netscape/Mozilla' => 'Netscape/Mozilla',
'MS Internet Explorer' => 'MS Internet Explorer',
'Opera Hotlist version 2.0' => 'Opera Hotlist version 2.0',
'Admins' => 'Administratörer',
'Everyone' => 'Alla',
'%s&#39;s Bookmarks' => '%s&#39;s Bokmärken',
'Deleted root %s of %s at %s' => 'Tog bort rot %s av %s vid %s',
'All' => 'Alla',
'Name' => 'Namn',
'Access denied!' => 'Tillträde förnekas!',
'All links recently validated!' => 'Alla länkar har nyligen validerats!',
'Cannot connect to http://%s:%s!' => 'Kan inte kontakta http://%s:%s!',
'Cannot delete built in group!' => 'Kan inte ta bort inbyggd grupp!',
'Cannot delete user because he is the only moderator of the following group(s): %s!' => 'Kan inte ta bort användare eftersom hon/han är den enda moderatorn i följande grupp(er): %s!',
'Cannot download %s using https, will try http!' => 'Kan inte ladda ned %s genom https, försöker med http!',
'Cannot export empty description!' => 'Kan inte exportera tom beskrivning!',
'Cannot handle %s protocol!' => 'Kan inte hantera protokollet %s!',
'Cannot move folder to its subfolder!' => 'Kan inte flytta mappen till dess undermapp!',
'Cannot remove all moderators from a group!' => 'Kan inte ta bort alla moderatorer från en grupp!',
'Cannot send email!' => 'Kan inte skicka epost!',
'Connection timed out!' => 'Uppkopplingstimeout!',
'Database corrupted - missing anonymous account!' => 'Databasen är korrupt - det anonyma kontot saknas!',
'Duplicate folder name "%s"!' => 'Mappnamnet "%s" finns redan!',
'Duplicate folder name!' => 'Mappnamnet finns redan!',
'Duplicate name "%s" in the target folder!' => 'Namnet "%s" finns redan i målmappen!',
'Duplicate name "%s"!' => 'Namnet "%s" finns redan!',
'Expected field %s was not filled!' => 'Förväntat fält %s var inte ifyllt',
'Favicon <img src="%s"> found at url %s.' => 'Favicon <img src="%s"> funnen på URL %s.',
'Favicon not found!' => 'Favicon hittades inte!',
'Field %s must be filled!' => 'Fältet %s måste fyllas i!',
'Folder has already been deleted!' => 'Mappen har redan tagits bort!',
'Folder with id %s does not exist!' => 'Mappen med id %s existerar inte!',
'Group has already been deleted!' => 'Gruppen har redan tagits bort!',
'Group name "%s" is already used!' => 'Gruppnamnet "%s" finns redan!',
'Head of the HTML page was not found!' => 'Huvudet på HTML-sidan hittades inte!',
'HEAD unsupported, trying GET!' => 'Huvudet stöds inte, försöker med GET!',
'Host or port undefined!' => 'Värd eller port odefinierad!',
'Icon size %s exceeds maximal size %s!' => 'Ikonstorlek %s överskrider maximal storlek %s!',
'Incomplete HTTP response!' => 'Icke komplett HTTP svar!',
'Invalid code, verification disabled!' => 'Ogiltig kod, verifiering avslagen!',
'Invalid regular expresssion!' => 'Ogiltigt reguljärt uttryck!',
'Invalid filename or other upload related problem: %s!' => 'Ogiltigt filnamn eller annat uppladdningsrelaterat problem: %s!',
'Link already is in the target folder!' => 'Länken finns redan i målmappen!',
'Link has already been deleted!' => 'Länken har redan tagits bort!',
'Missing command!' => 'Saknat kommando!',
'No links in the folder!' => 'Inga länkar i mappen!',
'No more than %s redirections allowed!' => 'Inte fler än %s omdirigeringar tillåtna!',
'No user was selected!' => 'Ingen användare valdes!',
'Node number %s has ACL record but does not exist!' => 'Nod nummer %s har ACL register men existerar inte!',
'Old password is invalid!' => 'Gammalt lösenord är ogiltigt!',
'Page not found!' => 'Sidan hittades inte!',
'Page redirected to %s!' => 'Omdirigering av sida till %s!',
'Purge folder to remove it permanently!' => 'Rensa mapp för att ta bort den permanent!',
'Shortcut icon not found! Trying default favicon location %s.' => 'Genvägsikon hittades inte! Försöker med standardfavicon sökväg %s.',
'The description length exceeds maximum length of %s bytes!' => 'Längden på beskrivningen överskrider maximala längden på %s byte!',
'The e-mail %s does not look correct!' => 'Epostadressen %s ser inte korrekt ut!',
'The password was not repeated correctly!' => 'Lösenordet repeterades inte korrekt!',
'There is no content to be deleted!' => 'Det finns inget innehåll att ta bort!',
'There is nothing to be undeleted!' => 'Det finns ingenting att ångra ta bort!',
'This email is already used. Did you forget your password?' => 'Denna epostadress används redan. Har du glömt ditt lösenord?',
'Tree has already been deleted!' => 'Trädet har redan tagits bort!',
'Use "%s" command to delete own account!' => 'Använd kommandot "%s" för att ta bort ett konto!',
'Unknown command!' => 'Okänt kommando!',
'Unknown username or wrong password!' => 'Okänt användarnamn eller fel lösenord!',
'Verification e-mail has been sent to your e-mail address!' => 'Ett verifikationsmeddelande har skickats till din epostadress!',
'Wrong favicon type/format "%s"!' => 'Fel favicon-typ/format "%s"!',
'You have been left as group moderator!' => 'Du har blivit gruppmoderator!',
'You are the last moderator of used group(s): %s. Account cannot be deleted!' => 'Du är den sista moderatorn i grupp(erna): %s. Kontot kan inte tas bort!',
'%s, welcome to the SiteBar!<p>You have been already logged in.' => '%s, välkommen till SiteBar!<p>Du har redan loggats in.',
'E-mail %s verified! Any pending memberships were approved.' => 'Epostadress %s är verifierad! Eventuella avvaktande medlemskap är godkända.',
'Link has been added.<p>You must reload your SiteBar in order to see added link!' => 'Länken har lagts till.<p>Du måste ladda om din SiteBar för att kunna se länken!',
'Imported %s link(s) into %s folder(s) from the bookmark file.' => 'Importerade %s länk(ar) till %s mapp(ar) från bokmärkesfilen.',
'Successful execution!' => 'Framgångsrik exekvering',
'Submit' => 'Skicka',
'Reset' => 'Återställ',
'Reload SiteBar' => 'Uppdatera SiteBar',
'Close' => 'Stäng',
'Return' => 'Tillbaka',
'Backup Return to SiteBar' => 'Backup Tillbaka till SiteBar',
'Cannot open file!' => 'Kan inte öppna filen!',
'Unknown bookmark file format!' => 'Okänt bokmärkesfilformat!',
'File is empty!' => 'Filen är tom!',
'Character set overriden from document to %s!' => 'Teckenuppsättning har åsidosatts från dokument till %s!',
'There is no conversion engine available to convert from %s character set!' => 'Det finns ingen konverteringsmotor tillgänglig för att konvertera från teckenuppsättningen %s!',
'Powered by %s ver. %s' => 'Driven av %s version %s',
'Skin created by' => 'Utseende skapat av',
'Skin designed by' => 'Utseende designat av',
'Folder found' => 'Mapp hittades',
'Link found' => 'Länk hittades',
'Desc' => 'Beskrivning',
'Find next?' => 'Finn nästa?',
);

?>
